@@ -15,11 +15,11 @@
 
 """Handles all requests to the conductor service."""
 
-from oslo.config import cfg
+from oslo_config import cfg
+from oslo_log import log as logging
 
 from sahara.conductor import manager
 from sahara.conductor import resource as r
-from sahara.openstack.common import log as logging
 
 
 conductor_opts = [
@@ -62,9 +62,10 @@ class LocalApi(object):
     # Cluster ops
 
     @r.wrap(r.ClusterResource)
-    def cluster_get(self, context, cluster):
+    def cluster_get(self, context, cluster, show_progress=False):
         """Return the cluster or None if it does not exist."""
-        return self._manager.cluster_get(context, _get_id(cluster))
+        return self._manager.cluster_get(
+            context, _get_id(cluster), show_progress)
 
     @r.wrap(r.ClusterResource)
     def cluster_get_all(self, context, **kwargs):
@@ -163,9 +164,13 @@ class LocalApi(object):
                                                   _get_id(cluster_template))
 
     @r.wrap(r.ClusterTemplateResource)
-    def cluster_template_get_all(self, context):
-        """Get all cluster templates."""
-        return self._manager.cluster_template_get_all(context)
+    def cluster_template_get_all(self, context, **kwargs):
+        """Get all cluster templates filtered by **kwargs.
+
+        e.g.  cluster_template_get_all(plugin_name='vanilla',
+                                       hadoop_version='1.1')
+        """
+        return self._manager.cluster_template_get_all(context, **kwargs)
 
     @r.wrap(r.ClusterTemplateResource)
     def cluster_template_create(self, context, values):
@@ -175,13 +180,27 @@ class LocalApi(object):
         """
         return self._manager.cluster_template_create(context, values)
 
-    def cluster_template_destroy(self, context, cluster_template):
+    def cluster_template_destroy(self, context, cluster_template,
+                                 ignore_default=False):
         """Destroy the cluster template or raise if it does not exist.
 
         :returns: None
         """
         self._manager.cluster_template_destroy(context,
-                                               _get_id(cluster_template))
+                                               _get_id(cluster_template),
+                                               ignore_default)
+
+    @r.wrap(r.ClusterTemplateResource)
+    def cluster_template_update(self, context, id, cluster_template,
+                                ignore_default=False):
+        """Update the cluster template or raise if it does not exist.
+
+        :returns: the updated cluster template
+        """
+        return self._manager.cluster_template_update(context,
+                                                     id,
+                                                     cluster_template,
+                                                     ignore_default)
 
     # Node Group Template ops
 
@@ -192,9 +211,13 @@ class LocalApi(object):
             context, _get_id(node_group_template))
 
     @r.wrap(r.NodeGroupTemplateResource)
-    def node_group_template_get_all(self, context):
-        """Get all node group templates."""
-        return self._manager.node_group_template_get_all(context)
+    def node_group_template_get_all(self, context, **kwargs):
+        """Get all node group templates filtered by **kwargs.
+
+        e.g.  node_group_template_get_all(plugin_name='vanilla',
+                                          hadoop_version='1.1')
+        """
+        return self._manager.node_group_template_get_all(context, **kwargs)
 
     @r.wrap(r.NodeGroupTemplateResource)
     def node_group_template_create(self, context, values):
@@ -204,13 +227,25 @@ class LocalApi(object):
         """
         return self._manager.node_group_template_create(context, values)
 
-    def node_group_template_destroy(self, context, node_group_template):
+    def node_group_template_destroy(self, context, node_group_template,
+                                    ignore_default=False):
         """Destroy the node group template or raise if it does not exist.
 
         :returns: None
         """
         self._manager.node_group_template_destroy(context,
-                                                  _get_id(node_group_template))
+                                                  _get_id(node_group_template),
+                                                  ignore_default)
+
+    @r.wrap(r.NodeGroupTemplateResource)
+    def node_group_template_update(self, context, id, values,
+                                   ignore_default=False):
+        """Update a node group template from the values dictionary.
+
+        :returns: the updated node group template
+        """
+        return self._manager.node_group_template_update(context, id, values,
+                                                        ignore_default)
 
     # Data Source ops
 
@@ -220,9 +255,20 @@ class LocalApi(object):
         return self._manager.data_source_get(context, _get_id(data_source))
 
     @r.wrap(r.DataSource)
-    def data_source_get_all(self, context):
-        """Get all Data Sources."""
-        return self._manager.data_source_get_all(context)
+    def data_source_get_all(self, context, **kwargs):
+        """Get all Data Sources filtered by **kwargs.
+
+        e.g.  data_source_get_all(name='myfile', type='swift')
+        """
+        return self._manager.data_source_get_all(context, **kwargs)
+
+    def data_source_count(self, context, **kwargs):
+        """Count Data Sources filtered by **kwargs.
+
+        Uses sqlalchemy "in_" clause for any tuple values
+        Uses sqlalchemy "like" clause for any string values containing %
+        """
+        return self._manager.data_source_count(context, **kwargs)
 
     @r.wrap(r.DataSource)
     def data_source_create(self, context, values):
@@ -245,7 +291,16 @@ class LocalApi(object):
     def job_execution_get_all(self, context, **kwargs):
         """Get all JobExecutions filtered by **kwargs.
 
+        kwargs key values may be the names of fields in a JobExecution
+        plus the following special values with the indicated meaning:
+
+        'cluster.name' -- name of the Cluster referenced by the JobExecution
+        'job.name' -- name of the Job referenced by the JobExecution
+        'status' -- JobExecution['info']['status']
+
         e.g. job_execution_get_all(cluster_id=12, input_id=123)
+             job_execution_get_all(**{'cluster.name': 'test',
+                                      'job.name': 'wordcount'})
         """
         return self._manager.job_execution_get_all(context, **kwargs)
 
@@ -280,9 +335,12 @@ class LocalApi(object):
         return self._manager.job_get(context, _get_id(job))
 
     @r.wrap(r.Job)
-    def job_get_all(self, context):
-        """Get all Jobs."""
-        return self._manager.job_get_all(context)
+    def job_get_all(self, context, **kwargs):
+        """Get all Jobs filtered by **kwargs.
+
+        e.g.  job_get_all(name='myjob', type='MapReduce')
+        """
+        return self._manager.job_get_all(context, **kwargs)
 
     @r.wrap(r.Job)
     def job_create(self, context, values):
@@ -313,12 +371,24 @@ class LocalApi(object):
                 return binary["name"]
         return None
 
+    def job_lib_names(self, context, job):
+        """Return the name of all job lib binaries or an empty list.
+
+        :param job: This is expected to be a Job object
+        """
+        lib_ids = job.libs or []
+        binaries = (self.job_binary_get(context, lib_id) for lib_id in lib_ids)
+        return [binary["name"] for binary in binaries if binary is not None]
+
     # JobBinary ops
 
     @r.wrap(r.JobBinary)
-    def job_binary_get_all(self, context):
-        """Get all JobBinarys."""
-        return self._manager.job_binary_get_all(context)
+    def job_binary_get_all(self, context, **kwargs):
+        """Get all JobBinarys filtered by **kwargs.
+
+        e.g.  job_binary_get_all(name='wordcount.jar')
+        """
+        return self._manager.job_binary_get_all(context, **kwargs)
 
     @r.wrap(r.JobBinary)
     def job_binary_get(self, context, job_binary):
@@ -337,9 +407,12 @@ class LocalApi(object):
     # JobBinaryInternal ops
 
     @r.wrap(r.JobBinaryInternal)
-    def job_binary_internal_get_all(self, context):
-        """Get all JobBinaryInternals."""
-        return self._manager.job_binary_internal_get_all(context)
+    def job_binary_internal_get_all(self, context, **kwargs):
+        """Get all JobBinaryInternals filtered by **kwargs.
+
+        e.g.  cluster_get_all(name='wordcount.jar')
+        """
+        return self._manager.job_binary_internal_get_all(context, **kwargs)
 
     @r.wrap(r.JobBinaryInternal)
     def job_binary_internal_get(self, context, job_binary_internal):
@@ -366,6 +439,28 @@ class LocalApi(object):
             context,
             job_binary_internal_id)
 
+    # Events ops
+
+    def cluster_provision_step_add(self, context, cluster_id, values):
+        """Create a provisioning step assigned to cluster from values dict."""
+        return self._manager.cluster_provision_step_add(
+            context, cluster_id, values)
+
+    def cluster_provision_step_update(self, context, provision_step):
+        """Update the cluster provisioning step."""
+        return self._manager.cluster_provision_step_update(
+            context, provision_step)
+
+    def cluster_provision_progress_update(self, context, cluster_id):
+        """Return cluster with provision progress updated field."""
+        return self._manager.cluster_provision_progress_update(
+            context, cluster_id)
+
+    def cluster_event_add(self, context, provision_step, values):
+        """Assign new event to the specified provision step."""
+        return self._manager.cluster_event_add(
+            context, provision_step, values)
+
 
 class RemoteApi(LocalApi):
     """Conductor API that does updates via RPC to the ConductorManager."""
