@@ -28,6 +28,8 @@ CLUSTER_DEFAULTS = {
     "anti_affinity": [],
     "status_description": "",
     "info": {},
+    "rollback_info": {},
+    "sahara_info": {},
 }
 
 NODE_GROUP_DEFAULTS = {
@@ -35,8 +37,15 @@ NODE_GROUP_DEFAULTS = {
     "node_configs": {},
     "volumes_per_node": 0,
     "volumes_size": 0,
+    "volumes_availability_zone": None,
     "volume_mount_prefix": "/volumes/disk",
-    "floating_ip_pool": None
+    "volume_type": None,
+    "floating_ip_pool": None,
+    "security_groups": None,
+    "auto_security_group": False,
+    "availability_zone": None,
+    "is_proxy_gateway": False,
+    "volume_local_to_instance": False,
 }
 
 INSTANCE_DEFAULTS = {
@@ -67,7 +76,7 @@ class ConductorManager(db_base.Base):
     def __init__(self):
         super(ConductorManager, self).__init__()
 
-    ## Common helpers
+    # Common helpers
 
     def _populate_node_groups(self, context, cluster):
         node_groups = cluster.get('node_groups')
@@ -110,22 +119,23 @@ class ConductorManager(db_base.Base):
 
         return node_group_merged
 
-    ## Cluster ops
+    # Cluster ops
 
-    def cluster_get(self, context, cluster):
+    def cluster_get(self, context, cluster, show_progress=False):
         """Return the cluster or None if it does not exist."""
-        return self.db.cluster_get(context, cluster)
+        return self.db.cluster_get(context, cluster, show_progress)
 
     def cluster_get_all(self, context, **kwargs):
-        """Get all clusters filtered by **kwargs  e.g.
-            cluster_get_all(plugin_name='vanilla', hadoop_version='1.1')
-            """
+        """Get all clusters filtered by **kwargs.
+
+        e.g. cluster_get_all(plugin_name='vanilla', hadoop_version='1.1')
+        """
         return self.db.cluster_get_all(context, **kwargs)
 
     def cluster_create(self, context, values):
         """Create a cluster from the values dictionary."""
 
-        #loading defaults
+        # loading defaults
         merged_values = copy.deepcopy(CLUSTER_DEFAULTS)
         merged_values['tenant_id'] = context.tenant_id
 
@@ -143,10 +153,10 @@ class ConductorManager(db_base.Base):
             del c_tmpl['updated_at']
             del c_tmpl['id']
 
-            #updating with cluster_template values
+            # updating with cluster_template values
             merged_values.update(c_tmpl)
 
-        #updating with values provided in request
+        # updating with values provided in request
         merged_values.update(values)
 
         if c_tmpl:
@@ -154,8 +164,8 @@ class ConductorManager(db_base.Base):
                 c_tmpl.get('cluster_configs'),
                 values.get('cluster_configs'))
 
-        merged_values['node_groups'] = \
-            self._populate_node_groups(context, merged_values)
+        merged_values['node_groups'] = self._populate_node_groups(
+            context, merged_values)
 
         return self.db.cluster_create(context, merged_values)
 
@@ -168,7 +178,7 @@ class ConductorManager(db_base.Base):
         """Destroy the cluster or raise if it does not exist."""
         self.db.cluster_destroy(context, cluster)
 
-    ## Node Group ops
+    # Node Group ops
 
     def node_group_add(self, context, cluster, values):
         """Create a Node Group from the values dictionary."""
@@ -186,7 +196,7 @@ class ConductorManager(db_base.Base):
         """Destroy the node_group or raise if it does not exist."""
         self.db.node_group_remove(context, node_group)
 
-    ## Instance ops
+    # Instance ops
 
     def instance_add(self, context, node_group, values):
         """Create an Instance from the values dictionary."""
@@ -204,7 +214,7 @@ class ConductorManager(db_base.Base):
         """Destroy the Instance or raise if it does not exist."""
         self.db.instance_remove(context, instance)
 
-    ## Volumes ops
+    # Volumes ops
 
     def append_volume(self, context, instance, volume_id):
         """Append volume_id to instance."""
@@ -214,15 +224,19 @@ class ConductorManager(db_base.Base):
         """Remove volume_id in instance."""
         self.db.remove_volume(context, instance, volume_id)
 
-    ## Cluster Template ops
+    # Cluster Template ops
 
     def cluster_template_get(self, context, cluster_template):
         """Return the cluster_template or None if it does not exist."""
         return self.db.cluster_template_get(context, cluster_template)
 
-    def cluster_template_get_all(self, context):
-        """Get all cluster_templates."""
-        return self.db.cluster_template_get_all(context)
+    def cluster_template_get_all(self, context, **kwargs):
+        """Get all cluster templates filtered by **kwargs.
+
+        e.g.  cluster_template_get_all(plugin_name='vanilla',
+                                       hadoop_version='1.1')
+        """
+        return self.db.cluster_template_get_all(context, **kwargs)
 
     def cluster_template_create(self, context, values):
         """Create a cluster_template from the values dictionary."""
@@ -234,19 +248,37 @@ class ConductorManager(db_base.Base):
 
         return self.db.cluster_template_create(context, values)
 
-    def cluster_template_destroy(self, context, cluster_template):
+    def cluster_template_destroy(self, context, cluster_template,
+                                 ignore_default=False):
         """Destroy the cluster_template or raise if it does not exist."""
-        self.db.cluster_template_destroy(context, cluster_template)
+        self.db.cluster_template_destroy(context, cluster_template,
+                                         ignore_default)
 
-    ## Node Group Template ops
+    def cluster_template_update(self, context, id, values,
+                                ignore_default=False):
+        """Update a cluster_template from the values dictionary."""
+        values = copy.deepcopy(values)
+        values = _apply_defaults(values, CLUSTER_DEFAULTS)
+        values['tenant_id'] = context.tenant_id
+        values['id'] = id
+
+        values['node_groups'] = self._populate_node_groups(context, values)
+
+        return self.db.cluster_template_update(context, values, ignore_default)
+
+    # Node Group Template ops
 
     def node_group_template_get(self, context, node_group_template):
         """Return the Node Group Template or None if it does not exist."""
         return self.db.node_group_template_get(context, node_group_template)
 
-    def node_group_template_get_all(self, context):
-        """Get all Node Group Templates."""
-        return self.db.node_group_template_get_all(context)
+    def node_group_template_get_all(self, context, **kwargs):
+        """Get all NodeGroupTemplates filtered by **kwargs.
+
+        e.g.  node_group_template_get_all(plugin_name='vanilla',
+                                          hadoop_version='1.1')
+        """
+        return self.db.node_group_template_get_all(context, **kwargs)
 
     def node_group_template_create(self, context, values):
         """Create a Node Group Template from the values dictionary."""
@@ -256,19 +288,42 @@ class ConductorManager(db_base.Base):
 
         return self.db.node_group_template_create(context, values)
 
-    def node_group_template_destroy(self, context, node_group_template):
+    def node_group_template_destroy(self, context, node_group_template,
+                                    ignore_default=False):
         """Destroy the Node Group Template or raise if it does not exist."""
-        self.db.node_group_template_destroy(context, node_group_template)
+        self.db.node_group_template_destroy(context, node_group_template,
+                                            ignore_default)
 
-    ## Data Source ops
+    def node_group_template_update(self, context, id, values,
+                                   ignore_default=False):
+        """Update a Node Group Template from the values dictionary."""
+        values = copy.deepcopy(values)
+        values['tenant_id'] = context.tenant_id
+        values['id'] = id
+
+        return self.db.node_group_template_update(context, values,
+                                                  ignore_default)
+
+    # Data Source ops
 
     def data_source_get(self, context, data_source):
         """Return the Data Source or None if it does not exist."""
         return self.db.data_source_get(context, data_source)
 
-    def data_source_get_all(self, context):
-        """Get all Data Sources."""
-        return self.db.data_source_get_all(context)
+    def data_source_get_all(self, context, **kwargs):
+        """Get all Data Sources filtered by **kwargs.
+
+        e.g.  data_source_get_all(name='myfile', type='swift')
+        """
+        return self.db.data_source_get_all(context, **kwargs)
+
+    def data_source_count(self, context, **kwargs):
+        """Count Data Sources filtered by **kwargs.
+
+        Uses sqlalchemy "in_" clause for any tuple values
+        Uses sqlalchemy "like" clause for any string values containing %
+        """
+        return self.db.data_source_count(context, **kwargs)
 
     def data_source_create(self, context, values):
         """Create a Data Source from the values dictionary."""
@@ -282,21 +337,32 @@ class ConductorManager(db_base.Base):
         """Destroy the Data Source or raise if it does not exist."""
         return self.db.data_source_destroy(context, data_source)
 
-    ##JobExecution ops
+    # JobExecution ops
 
     def job_execution_get(self, context, job_execution):
         """Return the JobExecution or None if it does not exist."""
         return self.db.job_execution_get(context, job_execution)
 
     def job_execution_get_all(self, context, **kwargs):
-        """Get all JobExecutions filtered by **kwargs  e.g.
-            job_execution_get_all(cluster_id=12, input_id=123)
+        """Get all JobExecutions filtered by **kwargs.
+
+        kwargs key values may be the names of fields in a JobExecution
+        plus the following special values with the indicated meaning:
+
+        'cluster.name' -- name of the Cluster referenced by the JobExecution
+        'job.name' -- name of the Job referenced by the JobExecution
+        'status' -- JobExecution['info']['status']
+
+        e.g. job_execution_get_all(cluster_id=12, input_id=123)
+             job_execution_get_all(**{'cluster.name': 'test',
+                                      'job.name': 'wordcount'})
         """
         return self.db.job_execution_get_all(context, **kwargs)
 
     def job_execution_count(self, context, **kwargs):
-        """Count number of JobExecutions filtered by **kwargs  e.g.
-            job_execution_count(cluster_id=12, input_id=123)
+        """Count number of JobExecutions filtered by **kwargs.
+
+        e.g. job_execution_count(cluster_id=12, input_id=123)
         """
         return self.db.job_execution_count(context, **kwargs)
 
@@ -314,15 +380,18 @@ class ConductorManager(db_base.Base):
         """Destroy the JobExecution or raise if it does not exist."""
         return self.db.job_execution_destroy(context, job_execution)
 
-    ## Job ops
+    # Job ops
 
     def job_get(self, context, job):
         """Return the Job or None if it does not exist."""
         return self.db.job_get(context, job)
 
-    def job_get_all(self, context):
-        """Get all Jobs."""
-        return self.db.job_get_all(context)
+    def job_get_all(self, context, **kwargs):
+        """Get all Jobs filtered by **kwargs.
+
+        e.g.  job_get_all(name='myjob', type='MapReduce')
+        """
+        return self.db.job_get_all(context, **kwargs)
 
     def job_create(self, context, values):
         """Create a Job from the values dictionary."""
@@ -338,11 +407,14 @@ class ConductorManager(db_base.Base):
         """Destroy the Job or raise if it does not exist."""
         self.db.job_destroy(context, job)
 
-    ## JobBinary ops
+    # JobBinary ops
 
-    def job_binary_get_all(self, context):
-        """Get all JobBinaries."""
-        return self.db.job_binary_get_all(context)
+    def job_binary_get_all(self, context, **kwargs):
+        """Get all JobBinarys filtered by **kwargs.
+
+        e.g.  job_binary_get_all(name='wordcount.jar')
+        """
+        return self.db.job_binary_get_all(context, **kwargs)
 
     def job_binary_get(self, context, job_binary_id):
         """Return the JobBinary or None if it does not exist."""
@@ -359,14 +431,16 @@ class ConductorManager(db_base.Base):
         """Destroy the JobBinary or raise if it does not exist."""
         self.db.job_binary_destroy(context, job_binary)
 
-    ## JobBinaryInternal ops
+    # JobBinaryInternal ops
 
-    def job_binary_internal_get_all(self, context):
-        """Get all JobBinaryInternals
+    def job_binary_internal_get_all(self, context, **kwargs):
+        """Get all JobBinaryInternals filtered by **kwargs.
+
+        e.g.  cluster_get_all(name='wordcount.jar')
 
         The JobBinaryInternals returned do not contain a data field.
         """
-        return self.db.job_binary_internal_get_all(context)
+        return self.db.job_binary_internal_get_all(context, **kwargs)
 
     def job_binary_internal_get(self, context, job_binary_internal_id):
         """Return the JobBinaryInternal or None if it does not exist
@@ -395,3 +469,21 @@ class ConductorManager(db_base.Base):
         return self.db.job_binary_internal_get_raw_data(
             context,
             job_binary_internal_id)
+
+    # Events ops
+
+    def cluster_provision_step_add(self, context, cluster_id, values):
+        """Create a provisioning step assigned to cluster from values dict."""
+        return self.db.cluster_provision_step_add(context, cluster_id, values)
+
+    def cluster_provision_step_update(self, context, provision_step):
+        """Update the cluster provisioning step."""
+        return self.db.cluster_provision_step_update(context, provision_step)
+
+    def cluster_provision_progress_update(self, context, cluster_id):
+        """Return cluster with provision progress updated field."""
+        return self.db.cluster_provision_progress_update(context, cluster_id)
+
+    def cluster_event_add(self, context, provision_step, values):
+        """Assign new event to the specified provision step."""
+        return self.db.cluster_event_add(context, provision_step, values)
