@@ -21,7 +21,9 @@ is to hide some necessary magic. Current module describes objects
 fields via docstrings and contains implementation of helper methods.
 """
 
-from oslo.config import cfg
+import random
+
+from oslo_config import cfg
 
 from sahara.utils import configs
 from sahara.utils import remote
@@ -55,11 +57,28 @@ class Cluster(object):
     extra
     rollback_info - internal information required for rollback
     sahara_info - internal information about sahara settings
+    provision_progress - list of ProvisionStep objects
     node_groups - list of NodeGroup objects
     cluster_template_id
     cluster_template - ClusterTemplate object
     """
 
+    def has_proxy_gateway(self):
+        for ng in self.node_groups:
+            if ng.is_proxy_gateway:
+                return True
+
+    def get_proxy_gateway_node(self):
+        proxies = []
+        for ng in self.node_groups:
+            if ng.is_proxy_gateway and ng.instances:
+                proxies += ng.instances
+
+        if proxies:
+            return random.choice(proxies)
+
+        return None
+
 
 class NodeGroup(object):
     """An object representing Node Group.
@@ -74,14 +93,22 @@ class NodeGroup(object):
                    see the docs for details
     volumes_per_node
     volumes_size
+    volumes_availability_zone - name of Cinder availability zone
+                                where to spawn volumes
     volume_mount_prefix
+    volume_type
     floating_ip_pool - Floating IP Pool name used to assign Floating IPs to
                        instances in this Node Group
     security_groups - List of security groups for instances in this Node Group
     auto_security_group - indicates if Sahara should create additional
                           security group for the Node Group
+    availability_zone - name of Nova availability zone where to spawn instances
     open_ports - List of ports that will be opened if auto_security_group is
                  True
+    is_proxy_gateway - indicates if nodes from this node group should be used
+                       as proxy to access other cluster nodes
+    volume_local_to_instance - indicates if volumes and instances should be
+                               created on the same physical host
 
     count
     instances - list of Instance objects
@@ -173,10 +200,15 @@ class NodeGroupTemplate(object):
                    see the docs for details
     volumes_per_node
     volumes_size
+    volumes_availability_zone
     volume_mount_prefix
+    volume_type
     floating_ip_pool
     security_groups
     auto_security_group
+    availability_zone
+    is_proxy_gateway
+    volume_local_to_instance
     """
 
 
@@ -207,7 +239,6 @@ class JobExecution(object):
     end_time
     cluster_id
     info
-    progress
     oozie_job_id
     return_code
     """
@@ -250,3 +281,32 @@ class JobBinaryInternal(object):
     name
     datasize
     """
+
+# Events ops
+
+
+class ClusterProvisionStep(object):
+    """An object representing cluster ProvisionStep
+
+    id
+    cluster_id
+    tenant_id
+    step_name
+    step_type
+    total
+    successful
+    events - list of Events objects assigned to the cluster
+    """
+
+
+class ClusterEvent(object):
+    """An object representing events about cluster provision
+
+    id
+    node_group_id
+    instance_id
+    instance_name
+    event_info
+    successful
+    step_id
+    """
