@@ -18,25 +18,24 @@ from eventlet.green import threading
 from eventlet.green import time
 from eventlet import greenpool
 from eventlet import semaphore
-from oslo.config import cfg
+from oslo_config import cfg
+from oslo_context import context
+from oslo_log import log as logging
 
 from sahara import exceptions as ex
 from sahara.i18n import _
-from sahara.i18n import _LE
 from sahara.i18n import _LW
-from sahara.openstack.common import log as logging
 
 
 CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
 
 
-# TODO(slukjanov): it'll be better to use common_context.RequestContext as base
-class Context(object):
+class Context(context.RequestContext):
     def __init__(self,
                  user_id=None,
                  tenant_id=None,
-                 token=None,
+                 auth_token=None,
                  service_catalog=None,
                  username=None,
                  tenant_name=None,
@@ -44,18 +43,22 @@ class Context(object):
                  is_admin=None,
                  remote_semaphore=None,
                  auth_uri=None,
+                 resource_uuid=None,
+                 current_instance_info=None,
+                 overwrite=True,
                  **kwargs):
         if kwargs:
-            LOG.warn(_LW('Arguments dropped when creating context: %s'),
-                     kwargs)
+            LOG.warning(_LW('Arguments dropped when creating context: '
+                            '{args}').format(args=kwargs))
 
-        self.user_id = user_id
-        self.tenant_id = tenant_id
-        self.token = token
+        super(Context, self).__init__(auth_token=auth_token,
+                                      user=user_id,
+                                      tenant=tenant_id,
+                                      is_admin=is_admin,
+                                      resource_uuid=resource_uuid)
         self.service_catalog = service_catalog
         self.username = username
         self.tenant_name = tenant_name
-        self.is_admin = is_admin
         self.remote_semaphore = remote_semaphore or semaphore.Semaphore(
             CONF.cluster_remote_threshold)
         self.roles = roles
@@ -63,37 +66,67 @@ class Context(object):
             self.auth_uri = auth_uri
         else:
             self.auth_uri = _get_auth_uri()
+        if overwrite or not hasattr(context._request_store, 'context'):
+            self.update_store()
+
+        if current_instance_info is not None:
+            self.current_instance_info = current_instance_info
+        else:
+            self.current_instance_info = InstanceInfo()
 
     def clone(self):
         return Context(
             self.user_id,
             self.tenant_id,
-            self.token,
+            self.auth_token,
             self.service_catalog,
             self.username,
             self.tenant_name,
             self.roles,
             self.is_admin,
             self.remote_semaphore,
-            self.auth_uri)
+            self.auth_uri,
+            self.resource_uuid,
+            self.current_instance_info,
+            overwrite=False)
 
     def to_dict(self):
         return {
             'user_id': self.user_id,
             'tenant_id': self.tenant_id,
-            'token': self.token,
+            'auth_token': self.auth_token,
             'service_catalog': self.service_catalog,
             'username': self.username,
             'tenant_name': self.tenant_name,
             'is_admin': self.is_admin,
             'roles': self.roles,
             'auth_uri': self.auth_uri,
+            'resource_uuid': self.resource_uuid,
         }
 
     def is_auth_capable(self):
-        return (self.service_catalog and self.token and self.tenant_id and
+        return (self.service_catalog and self.auth_token and self.tenant and
                 self.user_id)
 
+    # NOTE(adrienverge): The Context class uses the 'user' and 'tenant'
+    # properties internally (inherited from oslo.context), but Sahara code
+    # often uses 'user_id' and 'tenant_id'.
+    @property
+    def user_id(self):
+        return self.user
+
+    @user_id.setter
+    def user_id(self, value):
+        self.user = value
+
+    @property
+    def tenant_id(self):
+        return self.tenant
+
+    @tenant_id.setter
+    def tenant_id(self, value):
+        self.tenant = value
+
 
 def get_admin_context():
     return Context(is_admin=True)
@@ -120,9 +153,12 @@ def current():
 def set_ctx(new_ctx):
     if not new_ctx and has_ctx():
         delattr(_CTX_STORE, _CTX_KEY)
+        if hasattr(context._request_store, 'context'):
+            delattr(context._request_store, 'context')
 
     if new_ctx:
         setattr(_CTX_STORE, _CTX_KEY, new_ctx)
+        setattr(context._request_store, 'context', new_ctx)
 
 
 def _get_auth_uri():
@@ -152,9 +188,9 @@ def _wrapper(ctx, thread_description, thread_group, func, *args, **kwargs):
         set_ctx(ctx)
         func(*args, **kwargs)
     except BaseException as e:
-        LOG.exception(
-            _LE("Thread '%(thread)s' fails with exception: '%(exception)s'"),
-            {'thread': thread_description, 'exception': e})
+        LOG.debug(
+            "Thread {thread} failed with exception: {exception}".format(
+                thread=thread_description, exception=e))
         if thread_group and not thread_group.exc:
             thread_group.exc = e
             thread_group.failed_thread = thread_description
@@ -234,3 +270,34 @@ class ThreadGroup(object):
 
 def sleep(seconds=0):
     time.sleep(seconds)
+
+
+class InstanceInfo(object):
+    def __init__(self, cluster_id=None, instance_id=None, instance_name=None,
+                 node_group_id=None, step_type=None, step_id=None):
+        self.cluster_id = cluster_id
+        self.instance_id = instance_id
+        self.instance_name = instance_name
+        self.node_group_id = node_group_id
+        self.step_type = step_type
+        self.step_id = step_id
+
+
+def set_step_type(step_type):
+    current().current_instance_info.step_type = step_type
+
+
+class InstanceInfoManager(object):
+    def __init__(self, instance_info):
+        self.prev_instance_info = current().current_instance_info
+        if not instance_info.step_type:
+            instance_info.step_type = self.prev_instance_info.step_type
+        if not instance_info.step_id:
+            instance_info.step_id = self.prev_instance_info.step_id
+        current().current_instance_info = instance_info
+
+    def __enter__(self):
+        pass
+
+    def __exit__(self, *args):
+        current().current_instance_info = self.prev_instance_info
