@@ -27,23 +27,24 @@ interface.
               `sqlalchemy` is the only supported backend right now.
 
 :sql_connection:  string specifying the sqlalchemy connection to use, like:
-                  `sqlite:///var/lib/sahara/sahara.sqlite`.
+                  `mysql://user:password@localhost/sahara`.
 
 """
 
-from oslo.config import cfg
-
-from sahara.openstack.common.db import api as db_api
-from sahara.openstack.common import log as logging
-
+from oslo_config import cfg
+from oslo_db import api as db_api
+from oslo_db import options
+from oslo_log import log as logging
 
 CONF = cfg.CONF
 
+options.set_defaults(CONF)
+
 _BACKEND_MAPPING = {
     'sqlalchemy': 'sahara.db.sqlalchemy.api',
 }
 
-IMPL = db_api.DBAPI(backend_mapping=_BACKEND_MAPPING)
+IMPL = db_api.DBAPI.from_config(CONF, backend_mapping=_BACKEND_MAPPING)
 LOG = logging.getLogger(__name__)
 
 
@@ -63,7 +64,7 @@ def drop_db():
     return IMPL.drop_db()
 
 
-## Helpers for building constraints / equality checks
+# Helpers for building constraints / equality checks
 
 
 def constraint(**conditions):
@@ -104,18 +105,25 @@ def to_dict(func):
     return decorator
 
 
-## Cluster ops
+# Cluster ops
 
-@to_dict
-def cluster_get(context, cluster):
+
+def cluster_get(context, cluster, show_progress=False):
     """Return the cluster or None if it does not exist."""
-    return IMPL.cluster_get(context, cluster)
+    if show_progress:
+        cluster = IMPL.cluster_provision_progress_update(context, cluster)
+    else:
+        cluster = IMPL.cluster_get(context, cluster)
+    if cluster:
+        return cluster.to_dict(show_progress)
+    return None
 
 
 @to_dict
 def cluster_get_all(context, **kwargs):
-    """Get all clusters filtered by **kwargs  e.g.
-         cluster_get_all(plugin_name='vanilla', hadoop_version='1.1')
+    """Get all clusters filtered by **kwargs.
+
+    e.g. cluster_get_all(ctx, plugin_name='vanilla', hadoop_version='1.1')
     """
     return IMPL.cluster_get_all(context, **kwargs)
 
@@ -137,7 +145,7 @@ def cluster_destroy(context, cluster):
     IMPL.cluster_destroy(context, cluster)
 
 
-## Node Group ops
+# Node Group ops
 
 def node_group_add(context, cluster, values):
     """Create a Node Group from the values dictionary."""
@@ -154,7 +162,7 @@ def node_group_remove(context, node_group):
     IMPL.node_group_remove(context, node_group)
 
 
-## Instance ops
+# Instance ops
 
 def instance_add(context, node_group, values):
     """Create an Instance from the values dictionary."""
@@ -171,7 +179,7 @@ def instance_remove(context, instance):
     IMPL.instance_remove(context, instance)
 
 
-## Volumes ops
+# Volumes ops
 
 def append_volume(context, instance, volume_id):
     """Append volume_id to instance."""
@@ -183,7 +191,7 @@ def remove_volume(context, instance, volume_id):
     IMPL.remove_volume(context, instance, volume_id)
 
 
-## Cluster Template ops
+# Cluster Template ops
 
 @to_dict
 def cluster_template_get(context, cluster_template):
@@ -192,9 +200,13 @@ def cluster_template_get(context, cluster_template):
 
 
 @to_dict
-def cluster_template_get_all(context):
-    """Get all cluster_templates."""
-    return IMPL.cluster_template_get_all(context)
+def cluster_template_get_all(context, **kwargs):
+    """Get all cluster templates filtered by **kwargs.
+
+    e.g.  cluster_template_get_all(plugin_name='vanilla',
+                                   hadoop_version='1.1')
+    """
+    return IMPL.cluster_template_get_all(context, **kwargs)
 
 
 @to_dict
@@ -203,12 +215,20 @@ def cluster_template_create(context, values):
     return IMPL.cluster_template_create(context, values)
 
 
-def cluster_template_destroy(context, cluster_template):
+def cluster_template_destroy(context,
+                             cluster_template,
+                             ignore_default=False):
     """Destroy the cluster_template or raise if it does not exist."""
-    IMPL.cluster_template_destroy(context, cluster_template)
+    IMPL.cluster_template_destroy(context, cluster_template, ignore_default)
 
 
-## Node Group Template ops
+@to_dict
+def cluster_template_update(context, values, ignore_default=False):
+    """Update a cluster_template from the values dictionary."""
+    return IMPL.cluster_template_update(context, values, ignore_default)
+
+
+# Node Group Template ops
 
 @to_dict
 def node_group_template_get(context, node_group_template):
@@ -217,9 +237,13 @@ def node_group_template_get(context, node_group_template):
 
 
 @to_dict
-def node_group_template_get_all(context):
-    """Get all Node Group Templates."""
-    return IMPL.node_group_template_get_all(context)
+def node_group_template_get_all(context, **kwargs):
+    """Get all Node Group Templates filtered by **kwargs.
+
+    e.g.  node_group_template_get_all(plugin_name='vanilla',
+                                      hadoop_version='1.1')
+    """
+    return IMPL.node_group_template_get_all(context, **kwargs)
 
 
 @to_dict
@@ -228,12 +252,23 @@ def node_group_template_create(context, values):
     return IMPL.node_group_template_create(context, values)
 
 
-def node_group_template_destroy(context, node_group_template):
+def node_group_template_destroy(context,
+                                node_group_template,
+                                ignore_default=False):
     """Destroy the Node Group Template or raise if it does not exist."""
-    IMPL.node_group_template_destroy(context, node_group_template)
+    IMPL.node_group_template_destroy(context, node_group_template,
+                                     ignore_default)
 
 
-## Data Source ops
+@to_dict
+def node_group_template_update(context, node_group_template,
+                               ignore_default=False):
+    """Update a Node Group Template from the values in a dictionary."""
+    return IMPL.node_group_template_update(context, node_group_template,
+                                           ignore_default)
+
+
+# Data Source ops
 
 @to_dict
 def data_source_get(context, data_source):
@@ -242,9 +277,21 @@ def data_source_get(context, data_source):
 
 
 @to_dict
-def data_source_get_all(context):
-    """Get all Data Sources."""
-    return IMPL.data_source_get_all(context)
+def data_source_get_all(context, **kwargs):
+    """Get all Data Sources filtered by **kwargs.
+
+    e.g.  data_source_get_all(name='myfile', type='swift')
+    """
+    return IMPL.data_source_get_all(context, **kwargs)
+
+
+def data_source_count(context, **kwargs):
+    """Count Data Sources filtered by **kwargs.
+
+    Uses sqlalchemy "in_" clause for any tuple values
+    Uses sqlalchemy "like" clause for any string values containing %
+    """
+    return IMPL.data_source_count(context, **kwargs)
 
 
 @to_dict
@@ -258,7 +305,7 @@ def data_source_destroy(context, data_source):
     IMPL.data_source_destroy(context, data_source)
 
 
-## JobExecutions ops
+# JobExecutions ops
 
 @to_dict
 def job_execution_get(context, job_execution):
@@ -268,15 +315,27 @@ def job_execution_get(context, job_execution):
 
 @to_dict
 def job_execution_get_all(context, **kwargs):
-    """Get all JobExecutions filtered by **kwargs  e.g.
-        job_execution_get_all(cluster_id=12, input_id=123)
+    """Get all JobExecutions filtered by **kwargs.
+
+
+    kwargs key values may be the names of fields in a JobExecution
+    plus the following special values with the indicated meaning:
+
+    'cluster.name' -- name of the Cluster referenced by the JobExecution
+    'job.name' -- name of the Job referenced by the JobExecution
+    'status' -- JobExecution['info']['status']
+
+    e.g. job_execution_get_all(cluster_id=12, input_id=123)
+         job_execution_get_all(**{'cluster.name': 'test',
+                                  'job.name': 'wordcount'})
     """
     return IMPL.job_execution_get_all(context, **kwargs)
 
 
 def job_execution_count(context, **kwargs):
-    """Count number of JobExecutions filtered by **kwargs  e.g.
-        job_execution_count(cluster_id=12, input_id=123)
+    """Count number of JobExecutions filtered by **kwargs.
+
+    e.g. job_execution_count(cluster_id=12, input_id=123)
     """
     return IMPL.job_execution_count(context, **kwargs)
 
@@ -298,7 +357,7 @@ def job_execution_destroy(context, job_execution):
     IMPL.job_execution_destroy(context, job_execution)
 
 
-## Job ops
+# Job ops
 
 @to_dict
 def job_get(context, job):
@@ -307,9 +366,12 @@ def job_get(context, job):
 
 
 @to_dict
-def job_get_all(context):
-    """Get all Jobs."""
-    return IMPL.job_get_all(context)
+def job_get_all(context, **kwargs):
+    """Get all Jobs filtered by **kwargs.
+
+    e.g.  job_get_all(name='myjob', type='MapReduce')
+    """
+    return IMPL.job_get_all(context, **kwargs)
 
 
 @to_dict
@@ -329,9 +391,12 @@ def job_destroy(context, job):
 
 
 @to_dict
-def job_binary_get_all(context):
-    """Get all JobBinarys."""
-    return IMPL.job_binary_get_all(context)
+def job_binary_get_all(context, **kwargs):
+    """Get all JobBinarys filtered by **kwargs.
+
+    e.g.  job_binary_get_all(name='wordcount.jar')
+    """
+    return IMPL.job_binary_get_all(context, **kwargs)
 
 
 @to_dict
@@ -352,9 +417,14 @@ def job_binary_destroy(context, job_binary):
 
 
 @to_dict
-def job_binary_internal_get_all(context):
-    """Get all JobBinaryInternals."""
-    return IMPL.job_binary_internal_get_all(context)
+def job_binary_internal_get_all(context, **kwargs):
+    """Get all JobBinaryInternals filtered by **kwargs.
+
+    e.g.  job_binary_internal_get_all(ctx, name='wordcount.jar')
+
+    The JobBinaryInternals returned do not contain a data field.
+    """
+    return IMPL.job_binary_internal_get_all(context, **kwargs)
 
 
 @to_dict
@@ -378,3 +448,25 @@ def job_binary_internal_get_raw_data(context, job_binary_internal_id):
     """Return the binary data field from the specified JobBinaryInternal."""
     return IMPL.job_binary_internal_get_raw_data(context,
                                                  job_binary_internal_id)
+
+# Events ops
+
+
+def cluster_provision_step_add(context, cluster_id, values):
+    """Create a cluster assigned ProvisionStep from the values dictionary."""
+    return IMPL.cluster_provision_step_add(context, cluster_id, values)
+
+
+def cluster_provision_step_update(context, step_id):
+    """Updates provision step."""
+    return IMPL.cluster_provision_step_update(context, step_id)
+
+
+def cluster_provision_progress_update(context, cluster_id):
+    """Return cluster with provision progress updated field."""
+    return IMPL.cluster_provision_progress_update(context, cluster_id)
+
+
+def cluster_event_add(context, provision_step, values):
+    """Assign new event to the specified provision step."""
+    return IMPL.cluster_event_add(context, provision_step, values)
