@@ -13,12 +13,12 @@
 # limitations under the License.
 
 import copy
+import json
 import os
+import uuid
 
 import jsonschema
 from oslo_config import cfg
-from oslo_serialization import jsonutils as json
-from oslo_utils import uuidutils
 import six
 
 from sahara import conductor
@@ -43,7 +43,6 @@ def set_conf(conf):
     global CONF
     CONF = conf
 
-
 ng_validator = api_validator.ApiValidator(ngt.NODE_GROUP_TEMPLATE_SCHEMA)
 ct_validator = api_validator.ApiValidator(clt.CLUSTER_TEMPLATE_SCHEMA)
 
@@ -56,14 +55,8 @@ node_group_template_opts = [
                help='Flavor id field for a node group template.'),
 
     cfg.StrOpt('floating_ip_pool',
-               help='Floating ip pool field for a node group template.'),
-    cfg.BoolOpt('auto_security_group',
-                default=False,
-                help='Auto security group field for node group template.'),
-    cfg.ListOpt('security_groups',
-                default=[],
-                help='Security group field for node group template.')
-]
+               help='Floating ip pool field for a node group template.')
+    ]
 
 # Options that we allow to be replaced in a cluster template
 cluster_template_opts = [
@@ -168,7 +161,7 @@ def check_cluster_templates_valid(ng_templates, cl_templates):
     # passes JSON validation. We don't have the real uuid yet,
     # but this will allow the validation test.
     if ng_templates:
-        dummy_uuid = uuidutils.generate_uuid()
+        dummy_uuid = uuid.uuid4()
         ng_ids = {ng["template"]["name"]: dummy_uuid for ng in ng_templates}
     else:
         ng_ids = {}
@@ -267,7 +260,18 @@ def substitute_config_values(configs, template, path):
 
     for opt, value in six.iteritems(configs):
         if opt in opt_names and opt in template:
-            template[opt] = value
+            if value is None:
+                # TODO(tmckay): someday if we support 'null' in JSON
+                # we should replace this value with None. json.load
+                # will replace 'null' with None, and sqlalchemy will
+                # accept None as a value for a nullable field.
+                del template[opt]
+                LOG.debug("No replacement value specified for {opt} in "
+                          "{path}, removing".format(opt=opt, path=path))
+            else:
+                # Use args to allow for keyword arguments to format
+                args = {opt: value}
+                template[opt] = template[opt].format(**args)
 
 
 def get_configs(section):
@@ -296,11 +300,10 @@ def process_files(dirname, files):
                 fpath = os.path.join(dirname, fname)
                 with open(fpath, 'r') as fp:
                     try:
-                        data = fp.read()
-                        template = json.loads(data)
+                        template = json.load(fp)
                     except ValueError as e:
-                        LOG.warning("Error processing {path}, "
-                                    "{reason}".format(path=fpath, reason=e))
+                        LOG.warning("Error processing {path}, {reason}".format(
+                            path=fpath, reason=e))
                         raise Handled("error processing files")
 
                     # If this file doesn't contain basic fields, skip it.
@@ -346,7 +349,7 @@ def process_files(dirname, files):
                                   "files".format(path=fpath))
 
     except Handled as e:
-        log_skipping_dir(dirname, str(e))
+        log_skipping_dir(dirname, e.message)
         node_groups = []
         clusters = []
 
@@ -389,13 +392,12 @@ def delete_node_group_template(ctx, template, rollback=False):
 
     try:
         conductor.API.node_group_template_destroy(ctx, template["id"],
-                                                  ignore_prot_on_def=True)
+                                                  ignore_default=True)
     except Exception as e:
-        LOG.warning("Deletion of node group template {info} "
-                    "failed{rollback}, {reason}".format(
-                        info=u.name_and_id(template),
-                        reason=e,
-                        rollback=rollback_msg))
+        LOG.warning("Deletion of node group template {info} failed{rollback}"
+                    ", {reason}".format(info=u.name_and_id(template),
+                                        reason=e,
+                                        rollback=rollback_msg))
     else:
         LOG.info("Deleted node group template {info}{rollback}".format(
             info=u.name_and_id(template), rollback=rollback_msg))
@@ -412,15 +414,16 @@ def reverse_node_group_template_updates(ctx, update_info):
         try:
             conductor.API.node_group_template_update(ctx,
                                                      template["id"], values,
-                                                     ignore_prot_on_def=True)
+                                                     ignore_default=True)
         except Exception as e:
             LOG.warning("Rollback of update for node group "
                         "template {info} failed, {reason}".format(
                             info=u.name_and_id(template),
                             reason=e))
         else:
-            LOG.info("Rolled back update for node group "
-                     "template {info}".format(info=u.name_and_id(template)))
+            LOG.info("Rolled back update for "
+                     "node group template {info}".format(
+                         info=u.name_and_id(template)))
 
 
 def add_node_group_templates(ctx, node_groups):
@@ -455,7 +458,7 @@ def add_node_group_templates(ctx, node_groups):
                 # mark it as updated.
                 try:
                     template = conductor.API.node_group_template_update(
-                        ctx, current['id'], template, ignore_prot_on_def=True)
+                        ctx, current['id'], template, ignore_default=True)
                 except Exception as e:
                     LOG.warning("Update of node group template {info} "
                                 "failed, {reason}".format(
@@ -466,8 +469,9 @@ def add_node_group_templates(ctx, node_groups):
                 if template['updated_at'] != current['updated_at']:
                     ng_info["updated"].append((template, updated_fields))
                     LOG.info("Updated node group template {info} "
-                             "from {path}".format(info=u.name_and_id(template),
-                                                  path=ng["path"]))
+                             "from {path}".format(
+                                 info=u.name_and_id(template),
+                                 path=ng["path"]))
                 else:
                     LOG.debug("No change to node group template {info} "
                               "from {path}".format(
@@ -489,7 +493,7 @@ def add_node_group_templates(ctx, node_groups):
                          "from {path}".format(info=u.name_and_id(template),
                                               path=ng["path"]))
 
-            # For the purposes of substitution we need a dict of id by name
+            # For the purposes of substituion we need a dict of id by name
             ng_info["ids"][template['name']] = template['id']
 
     except Handled:
@@ -526,7 +530,7 @@ def delete_cluster_template(ctx, template, rollback=False):
 
     try:
         conductor.API.cluster_template_destroy(ctx, template["id"],
-                                               ignore_prot_on_def=True)
+                                               ignore_default=True)
     except Exception as e:
         LOG.warning("Deletion of cluster template {info} failed{rollback}"
                     ", {reason}".format(info=u.name_and_id(template),
@@ -548,15 +552,16 @@ def reverse_cluster_template_updates(ctx, update_info):
         try:
             conductor.API.cluster_template_update(ctx,
                                                   template["id"], values,
-                                                  ignore_prot_on_def=True)
+                                                  ignore_default=True)
         except Exception as e:
             LOG.warning("Rollback of update for cluster "
                         "template {info} failed, {reason}".format(
                             info=u.name_and_id(template),
                             reason=e))
         else:
-            LOG.info("Rolled back update for cluster "
-                     "template {info}".format(info=u.name_and_id(template)))
+            LOG.info("Rolled back update for "
+                     "cluster template {info}".format(
+                         info=u.name_and_id(template)))
 
 
 def add_cluster_templates(ctx, clusters, ng_dict):
@@ -616,7 +621,7 @@ def add_cluster_templates(ctx, clusters, ng_dict):
                 # Probably a bug
                 try:
                     template = conductor.API.cluster_template_update(
-                        ctx, current['id'], template, ignore_prot_on_def=True)
+                        ctx, current['id'], template, ignore_default=True)
                 except Exception as e:
                     LOG.warning("Update of cluster template {info} "
                                 "failed, {reason}".format(
@@ -626,8 +631,9 @@ def add_cluster_templates(ctx, clusters, ng_dict):
                 if template['updated_at'] != current['updated_at']:
                     updated.append((template, updated_fields))
                     LOG.info("Updated cluster template {info} "
-                             "from {path}".format(info=u.name_and_id(template),
-                                                  path=cl['path']))
+                             "from {path}".format(
+                                 info=u.name_and_id(template),
+                                 path=cl['path']))
                 else:
                     LOG.debug("No change to cluster template {info} "
                               "from {path}".format(info=u.name_and_id(current),
@@ -645,9 +651,8 @@ def add_cluster_templates(ctx, clusters, ng_dict):
                     raise Handled()
 
                 created.append(template)
-                LOG.info("Created cluster template {info} "
-                         "from {path}".format(info=u.name_and_id(template),
-                                              path=cl['path']))
+                LOG.info("Created cluster template {info} from {path}".format(
+                    info=u.name_and_id(template), path=cl['path']))
 
     except Handled:
         error = do_reversals(created, updated)
@@ -747,13 +752,12 @@ def do_delete():
 def do_node_group_template_delete():
     ctx = Context(tenant_id=CONF.command.tenant_id)
 
-    template_name = CONF.command.template_name
-    t = u.find_node_group_template_by_name(ctx, template_name)
+    t = u.find_node_group_template_by_name(ctx, CONF.command.template_name)
     if t:
         delete_node_group_template(ctx, t)
     else:
         LOG.warning("Deletion of node group template {name} failed, "
-                    "no such template".format(name=template_name))
+                    "no such template".format(name=CONF.command.template_name))
 
 
 def do_node_group_template_delete_by_id():
@@ -766,8 +770,7 @@ def do_node_group_template_delete_by_id():
             delete_node_group_template(ctx, t)
         else:
             LOG.warning("Deletion of node group template {info} skipped, "
-                        "not a default template".format(
-                            info=u.name_and_id(t)))
+                        "not a default template".format(info=u.name_and_id(t)))
     else:
         LOG.warning("Deletion of node group template {id} failed, "
                     "no such template".format(id=CONF.command.id))
@@ -776,13 +779,12 @@ def do_node_group_template_delete_by_id():
 def do_cluster_template_delete():
     ctx = Context(tenant_id=CONF.command.tenant_id)
 
-    template_name = CONF.command.template_name
-    t = u.find_cluster_template_by_name(ctx, template_name)
+    t = u.find_cluster_template_by_name(ctx, CONF.command.template_name)
     if t:
         delete_cluster_template(ctx, t)
     else:
         LOG.warning("Deletion of cluster template {name} failed, "
-                    "no such template".format(name=template_name))
+                    "no such template".format(name=CONF.command.template_name))
 
 
 def do_cluster_template_delete_by_id():
@@ -795,8 +797,7 @@ def do_cluster_template_delete_by_id():
             delete_cluster_template(ctx, t)
         else:
             LOG.warning("Deletion of cluster template {info} skipped, "
-                        "not a default template".format(
-                            info=u.name_and_id(t)))
+                        "not a default template".format(info=u.name_and_id(t)))
     else:
         LOG.warning("Deletion of cluster template {id} failed, "
                     "no such template".format(id=CONF.command.id))
