@@ -14,7 +14,7 @@
 # limitations under the License.
 #
 # The contents of this file are mainly copied from cm_api sources,
-# released by Cloudera. Codes not used by Sahara CDH plugin are removed.
+# released by Cloudrea. Codes not used by Sahara CDH plugin are removed.
 # You can find the original codes at
 #
 #     https://github.com/cloudera/cm_api/tree/master/python/src/cm_api
@@ -134,12 +134,3 @@ class ApiResource(resource.Resource):
         @return: An ApiUser object
         """
         return users.update_user(self, user)
-
-    def get_service_health_status(self, cluster):
-        """Get clusters service health status
-
-        :param cluster: Cluster name.
-        :return: A dict with cluster health status
-        """
-        cluster = clusters.get_cluster(self, cluster)
-        return cluster.get_service_health_status()
