@@ -14,7 +14,7 @@
 # limitations under the License.
 
 from sahara.i18n import _
-from sahara.plugins.general import exceptions as ex
+from sahara.plugins import exceptions as ex
 
 
 def _root(remote, cmd, **kwargs):
@@ -41,12 +41,25 @@ def is_pre_installed_cdh(remote):
 
 def start_cloudera_db(remote):
     _root(remote, 'service cloudera-scm-server-db start')
+    # for Hive access
+    hive_access_param = 'host metastore hive 0.0.0.0/0 md5'
+    remote.append_to_file('/var/lib/cloudera-scm-server-db/data/pg_hba.conf',
+                          hive_access_param, run_as_root=True)
+    _root(remote, 'service cloudera-scm-server-db restart')
 
 
 def start_manager(remote):
     _root(remote, 'service cloudera-scm-server start')
 
 
+def start_ntp(remote):
+    distrib = _get_os_distrib(remote)
+    if distrib == 'centos':
+        _root(remote, 'service ntpd start')
+    elif distrib == 'ubuntu':
+        _root(remote, 'service ntp start')
+
+
 def configure_agent(remote, manager_address):
     remote.replace_remote_string('/etc/cloudera-scm-agent/config.ini',
                                  'server_host=.*',
@@ -74,6 +87,8 @@ def install_packages(remote, packages, timeout=1800):
 def update_repository(remote):
     if is_ubuntu_os(remote):
         _root(remote, 'apt-get update')
+    if is_centos_os(remote):
+        _root(remote, 'yum clean all')
 
 
 def push_remote_file(remote, src, dst):
@@ -86,6 +101,11 @@ def add_ubuntu_repository(r, repo_list_url, repo_name):
                      '/etc/apt/sources.list.d/%s.list' % repo_name)
 
 
+def write_ubuntu_repository(r, repo_content, repo_name):
+    r.write_file_to('/etc/apt/sources.list.d/%s.list' % repo_name,
+                    repo_content, run_as_root=True)
+
+
 def add_apt_key(remote, key_url):
     cmd = 'wget -qO - %s | apt-key add -' % key_url
     _root(remote, cmd)
@@ -93,3 +113,12 @@ def add_apt_key(remote, key_url):
 
 def add_centos_repository(r, repo_list_url, repo_name):
     push_remote_file(r, repo_list_url, '/etc/yum.repos.d/%s.repo' % repo_name)
+
+
+def write_centos_repository(r, repo_content, repo_name):
+    r.write_file_to('/etc/yum.repos.d/%s.repo' % repo_name,
+                    repo_content, root_as_root=True)
+
+
+def start_mysql_server(remote):
+    _root(remote, 'service mysql start')
