@@ -15,11 +15,13 @@
 
 import re
 
+from oslo_log import log as logging
+
 from sahara.i18n import _
 from sahara.i18n import _LI
-from sahara.openstack.common import log as logging
-from sahara.plugins.general import exceptions as ex
+from sahara.plugins import exceptions as ex
 from sahara.plugins.hdp import saharautils
+from sahara.utils import cluster_progress_ops as cpo
 from sahara.utils import files as f
 
 
@@ -37,7 +39,7 @@ HADOOP_SWIFT_LOCAL_RPM = ('/opt/hdp-local-repos/hadoop-swift/'
 LOG = logging.getLogger(__name__)
 
 
-class HadoopServer:
+class HadoopServer(object):
     _master_ip = None
 
     def __init__(self, instance, node_group, ambari_rpm=None):
@@ -45,6 +47,14 @@ class HadoopServer:
         self.node_group = node_group
         self.ambari_rpm = ambari_rpm or AMBARI_RPM
 
+    def get_event_info(self):
+        return self.instance
+
+    @property
+    def cluster_id(self):
+        return self.instance.cluster_id
+
+    @cpo.event_wrapper(True, param=('self', 0))
     def provision_ambari(self, ambari_info, cluster_spec):
         self.install_rpms()
         global_config = cluster_spec.configurations['global']
@@ -57,16 +67,17 @@ class HadoopServer:
 
     @saharautils.inject_remote('r')
     def rpms_installed(self, r):
-        yum_cmd = 'yum -q list installed %s' % EPEL_RELEASE_PACKAGE_NAME
-        ret_code, stdout = r.execute_command(yum_cmd,
+        rpm_cmd = 'rpm -q %s' % EPEL_RELEASE_PACKAGE_NAME
+        ret_code, stdout = r.execute_command(rpm_cmd,
                                              run_as_root=True,
                                              raise_when_error=False)
         return ret_code == 0
 
     @saharautils.inject_remote('r')
     def install_rpms(self, r):
-        LOG.info(
-            _LI("{0}: Installing rpm's ...").format(self.instance.hostname()))
+        LOG.debug(
+            "{hostname}: Installing rpm's"
+            .format(hostname=self.instance.hostname()))
 
         # TODO(jspeidel): based on image type, use correct command
         curl_cmd = ('curl -f -s -o /etc/yum.repos.d/ambari.repo %s' %
@@ -78,27 +89,28 @@ class HadoopServer:
             yum_cmd = 'yum -y install %s' % EPEL_RELEASE_PACKAGE_NAME
             r.execute_command(yum_cmd, run_as_root=True)
         else:
-            LOG.info(_LI("{0}: Unable to install rpm's from repo, "
-                         "checking for local install.")
-                     .format(self.instance.hostname()))
+            LOG.debug("{hostname}: Unable to install rpm's from repo, "
+                      "checking for local install.".format(
+                          hostname=self.instance.hostname()))
             if not self.rpms_installed():
                 raise ex.HadoopProvisionError(
                     _('Failed to install Hortonworks Ambari'))
 
+    @cpo.event_wrapper(True, param=('self', 0))
     @saharautils.inject_remote('r')
     def install_swift_integration(self, r):
-        LOG.info(
-            _LI("{0}: Installing swift integration ...")
-            .format(self.instance.hostname()))
+        LOG.debug(
+            "{hostname}: Installing swift integration"
+            .format(hostname=self.instance.hostname()))
         base_rpm_cmd = 'rpm -U --quiet '
         rpm_cmd = base_rpm_cmd + HADOOP_SWIFT_RPM
         ret_code, stdout = r.execute_command(rpm_cmd,
                                              run_as_root=True,
                                              raise_when_error=False)
         if ret_code != 0:
-            LOG.info(_LI("{0}: Unable to install swift integration from "
-                         "source, checking for local rpm.")
-                     .format(self.instance.hostname()))
+            LOG.debug("{hostname}: Unable to install swift integration from "
+                      "source, checking for local rpm.".format(
+                          hostname=self.instance.hostname()))
             ret_code, stdout = r.execute_command(
                 'ls ' + HADOOP_SWIFT_LOCAL_RPM,
                 run_as_root=True,
@@ -110,6 +122,7 @@ class HadoopServer:
                 raise ex.HadoopProvisionError(
                     _('Failed to install Hadoop Swift integration'))
 
+    @cpo.event_wrapper(True, param=('self', 0))
     @saharautils.inject_remote('r')
     def configure_topology(self, topology_str, r):
         r.write_file_to(
@@ -123,11 +136,11 @@ class HadoopServer:
 
     @saharautils.inject_remote('r')
     def _setup_and_start_ambari_server(self, port, jdk_path, r):
-        LOG.info(_LI('{0}: Installing ambari-server ...').format(
-            self.instance.hostname()))
+        LOG.debug('{hostname}: Installing ambari-server'.format(
+            hostname=self.instance.hostname()))
         r.execute_command('yum -y install ambari-server', run_as_root=True)
 
-        LOG.info(_LI('Running Ambari Server setup ...'))
+        LOG.debug('Running Ambari Server setup')
         # remove postgres data directory as a precaution since its existence
         # has prevented successful postgres installation
         r.execute_command('rm -rf /var/lib/pgsql/data', run_as_root=True)
@@ -137,8 +150,8 @@ class HadoopServer:
         return_code, stdout = r.execute_command('ls -l {jdk_location}'.format(
             jdk_location=jdk_path), raise_when_error=False)
 
-        LOG.debug('Queried for JDK location on VM instance, return code = ' +
-                  str(return_code))
+        LOG.debug('Queried for JDK location on VM instance, return code = '
+                  '{code}'.format(code=str(return_code)))
 
         # do silent setup since we only use default responses now
         # only add -j command if the JDK is configured for the template,
@@ -153,12 +166,12 @@ class HadoopServer:
 
         self._configure_ambari_server_api_port(port)
 
-        LOG.info(_LI('Starting Ambari ...'))
         # NOTE(dmitryme): Reading stdout from 'ambari-server start'
         # hangs ssh. Redirecting output to /dev/null fixes that
         r.execute_command(
             'ambari-server start > /dev/null 2>&1', run_as_root=True
         )
+        LOG.info(_LI('Ambari started'))
 
     @saharautils.inject_remote('r')
     def _configure_ambari_server_api_port(self, port, r):
@@ -167,7 +180,8 @@ class HadoopServer:
             return
 
         ambari_config_file = '/etc/ambari-server/conf/ambari.properties'
-        LOG.debug('Configuring Ambari Server API port: {0}'.format(port))
+        LOG.debug('Configuring Ambari Server API port: {port}'.format(
+                  port=port))
         # read the current contents
         data = r.read_file_from(ambari_config_file)
         data = '{0}\nclient.api.port={1}\n'.format(data, port)
@@ -177,28 +191,72 @@ class HadoopServer:
 
     @saharautils.inject_remote('r')
     def _setup_and_start_ambari_agent(self, ambari_server_ip, r):
-        LOG.info(_LI('{0}: Installing Ambari Agent ...').format(
-            self.instance.hostname()))
+        LOG.debug('{hostname}: Installing Ambari agent'.format(
+            hostname=self.instance.hostname()))
 
         r.execute_command('yum -y install ambari-agent', run_as_root=True)
         LOG.debug(
-            '{0}: setting master-ip: {1} in ambari-agent.ini'.format(
-                self.instance.hostname(), ambari_server_ip))
+            '{hostname}: setting master-ip: {ip} in ambari-agent.ini'.format(
+                hostname=self.instance.hostname(), ip=ambari_server_ip))
         r.replace_remote_string(
             '/etc/ambari-agent/conf/ambari-agent.ini', 'localhost',
             ambari_server_ip)
 
-        LOG.info(
-            _LI('{0}: Starting Ambari Agent ...').format(
-                self.instance.hostname()))
         # If the HDP 2 ambari agent is pre-installed on an image, the agent
         # will start up during instance launch and therefore the agent
         # registration will fail.  It is therefore more appropriate to call
         # restart since it will either start (if stopped) or restart (if
         # running)
         r.execute_command('ambari-agent restart', run_as_root=True)
+        LOG.info(
+            _LI('{hostname}: Ambari Agent started').format(
+                hostname=self.instance.hostname()))
+
+    @saharautils.inject_remote('r')
+    def set_namenode_safemode(self, jh, r):
+        r.execute_command("sudo su -l hdfs -c 'JAVA_HOME={0} "
+                          "hdfs dfsadmin -safemode enter'".format(jh),
+                          run_as_root=True)
+
+    @saharautils.inject_remote('r')
+    def save_namenode_namespace(self, jh, r):
+        r.execute_command("sudo su -l hdfs -c 'JAVA_HOME={0} "
+                          "hdfs dfsadmin -saveNamespace'".format(jh),
+                          run_as_root=True)
+
+    @saharautils.inject_remote('r')
+    def initialize_shared_edits(self, jh, r):
+        r.execute_command("sudo su -l hdfs -c 'JAVA_HOME={0} "
+                          "hdfs namenode -initializeSharedEdits'".format(jh),
+                          run_as_root=True)
+
+    @saharautils.inject_remote('r')
+    def format_zookeeper_fc(self, jh, r):
+        r.execute_command("sudo su -l hdfs -c 'JAVA_HOME={0} "
+                          "hdfs zkfc -formatZK'".format(jh),
+                          run_as_root=True)
+
+    @saharautils.inject_remote('r')
+    def bootstrap_standby_namenode(self, jh, r):
+        r.execute_command("sudo su -l hdfs -c 'JAVA_HOME={0} "
+                          "hdfs namenode -bootstrapStandby'".format(jh),
+                          run_as_root=True)
+
+    @saharautils.inject_remote('r')
+    def install_httpfs(self, r):
+        r.execute_command("yum -y install hadoop-httpfs", run_as_root=True)
+
+    @saharautils.inject_remote('r')
+    def start_httpfs(self, r):
+        r.execute_command("service hadoop-httpfs start", run_as_root=True)
+
+    @saharautils.inject_remote('r')
+    def write_hue_temp_file(self, filename, content, r):
+        r.execute_command("echo %s > %s" % (content, filename),
+                          run_as_root=True)
 
     def _log(self, buf):
+        # FIXME(Kezar): I don't know what's this. Will check later.
         LOG.debug(buf)
 
     def _is_component_available(self, component):
@@ -211,7 +269,7 @@ class HadoopServer:
         return self._is_component_available('GANGLIA_MONITOR')
 
 
-class DefaultPromptMatcher():
+class DefaultPromptMatcher(object):
     prompt_pattern = re.compile('(.*\()(.)(\)\?\s*$)', re.DOTALL)
 
     def __init__(self, terminal_token):
