@@ -1,4 +1,4 @@
-# Copyright (c) 2014 Hortonworks, Inc.
+# Copyright (c) 2013 Hortonworks, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,26 +14,28 @@
 # limitations under the License.
 
 import json
-import logging
 
-from oslo.config import cfg
+from oslo_config import cfg
+from oslo_log import log as logging
 import pkg_resources as pkg
 
 from sahara import context
 from sahara import exceptions as exc
 from sahara.i18n import _
-from sahara.i18n import _LC
 from sahara.i18n import _LE
 from sahara.i18n import _LI
 from sahara.i18n import _LW
-from sahara.plugins.general import exceptions as ex
+from sahara.plugins import exceptions as ex
 from sahara.plugins.hdp import clusterspec as cs
 from sahara.plugins.hdp import configprovider as cfgprov
 from sahara.plugins.hdp.versions import abstractversionhandler as avm
-from sahara.plugins.hdp.versions.version_2_0_6 import edp_engine
-from sahara.plugins.hdp.versions.version_2_0_6 import services
+from sahara.plugins.hdp.versions.version_1_3_2 import edp_engine
+from sahara.plugins.hdp.versions.version_1_3_2 import services
+from sahara.utils import cluster_progress_ops as cpo
+from sahara.utils import poll_utils
 from sahara import version
 
+
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
 
@@ -51,8 +53,9 @@ class VersionHandler(avm.AbstractVersionHandler):
             self.config_provider = cfgprov.ConfigurationProvider(
                 json.load(pkg.resource_stream(
                           version.version_info.package,
-                          'plugins/hdp/versions/version_2_0_6/resources/'
-                          'ambari-config-resource.json')))
+                          'plugins/hdp/versions/version_1_3_2/resources/'
+                          'ambari-config-resource.json')),
+                hadoop_version='1.3.2')
 
         return self.config_provider
 
@@ -74,21 +77,35 @@ class VersionHandler(avm.AbstractVersionHandler):
     def get_cluster_spec(self, cluster, user_inputs,
                          scaled_groups=None, cluster_template=None):
         if cluster_template:
-            cluster_spec = cs.ClusterSpec(cluster_template, '2.0.6')
+            cluster_spec = cs.ClusterSpec(cluster_template)
         else:
+            if scaled_groups:
+                for ng in cluster.node_groups:
+                    ng_id = ng['id']
+                    if (ng_id in scaled_groups and
+                       ng['count'] > scaled_groups[ng_id]):
+                            raise ex.ClusterCannotBeScaled(
+                                cluster.name,
+                                _('The HDP plugin does not support '
+                                  'the decommissioning of nodes '
+                                  'for HDP version 1.3.2'))
+
             cluster_spec = self.get_default_cluster_configuration()
             cluster_spec.create_operational_config(
                 cluster, user_inputs, scaled_groups)
 
+            cs.validate_number_of_datanodes(
+                cluster, scaled_groups, self.get_config_items())
+
         return cluster_spec
 
     def get_default_cluster_configuration(self):
-        return cs.ClusterSpec(self._get_default_cluster_template(), '2.0.6')
+        return cs.ClusterSpec(self._get_default_cluster_template())
 
     def _get_default_cluster_template(self):
         return pkg.resource_string(
             version.version_info.package,
-            'plugins/hdp/versions/version_2_0_6/resources/'
+            'plugins/hdp/versions/version_1_3_2/resources/'
             'default-cluster.template')
 
     def get_node_processes(self):
@@ -102,6 +119,11 @@ class VersionHandler(avm.AbstractVersionHandler):
         return node_processes
 
     def install_swift_integration(self, servers):
+        if servers:
+            cpo.add_provisioning_step(
+                servers[0].cluster_id, _("Install Swift integration"),
+                len(servers))
+
         for server in servers:
             server.install_swift_integration()
 
@@ -113,8 +135,42 @@ class VersionHandler(avm.AbstractVersionHandler):
             return edp_engine.EdpOozieEngine(cluster)
         return None
 
+    def get_edp_job_types(self):
+        return edp_engine.EdpOozieEngine.get_supported_job_types()
 
-class AmbariClient():
+    def get_edp_config_hints(self, job_type):
+        return edp_engine.EdpOozieEngine.get_possible_job_config(job_type)
+
+    def get_open_ports(self, node_group):
+        ports = [8660]  # for Ganglia
+
+        ports_map = {
+            'AMBARI_SERVER': [8080, 8440, 8441],
+            'NAMENODE': [50070, 50470, 8020, 9000],
+            'DATANODE': [50075, 50475, 50010, 50020],
+            'SECONDARY_NAMENODE': [50090],
+            'JOBTRACKER': [50030, 8021],
+            'TASKTRACKER': [50060],
+            'HISTORYSERVER': [51111],
+            'HIVE_SERVER': [10000],
+            'HIVE_METASTORE': [9083],
+            'HBASE_MASTER': [60000, 60010],
+            'HBASE_REGIONSERVER': [60020, 60030],
+            'WEBHCAT_SERVER': [50111],
+            'GANGLIA_SERVER': [8661, 8662, 8663, 8651],
+            'MYSQL_SERVER': [3306],
+            'OOZIE_SERVER': [11000, 11001],
+            'ZOOKEEPER_SERVER': [2181, 2888, 3888],
+            'NAGIOS_SERVER': [80]
+        }
+        for process in node_group.node_processes:
+            if process in ports_map:
+                ports.extend(ports_map[process])
+
+        return ports
+
+
+class AmbariClient(object):
 
     def __init__(self, handler):
         #  add an argument for neutron discovery
@@ -127,24 +183,38 @@ class AmbariClient():
         return {"X-Requested-By": "sahara"}
 
     def _post(self, url, ambari_info, data=None):
+        if data:
+            LOG.debug('AmbariClient:_post call, url = {url} data = {data}'
+                      .format(url=url, data=str(data)))
+        else:
+            LOG.debug('AmbariClient:_post call, url = {url}'.format(url=url))
+
         session = self._get_http_session(ambari_info.host, ambari_info.port)
         return session.post(url, data=data,
                             auth=(ambari_info.user, ambari_info.password),
                             headers=self._get_standard_headers())
 
     def _delete(self, url, ambari_info):
+        LOG.debug('AmbariClient:_delete call, url = {url}'.format(url=url))
         session = self._get_http_session(ambari_info.host, ambari_info.port)
         return session.delete(url,
                               auth=(ambari_info.user, ambari_info.password),
                               headers=self._get_standard_headers())
 
     def _put(self, url, ambari_info, data=None):
+        if data:
+            LOG.debug('AmbariClient:_put call, url = {url} data = {data}'
+                      .format(url=url, data=str(data)))
+        else:
+            LOG.debug('AmbariClient:_put call, url = {url}'.format(url=url))
+
         session = self._get_http_session(ambari_info.host, ambari_info.port)
         auth = (ambari_info.user, ambari_info.password)
         return session.put(url, data=data, auth=auth,
                            headers=self._get_standard_headers())
 
     def _get(self, url, ambari_info):
+        LOG.debug('AmbariClient:_get call, url = {url}'.format(url=url))
         session = self._get_http_session(ambari_info.host, ambari_info.port)
         return session.get(url, auth=(ambari_info.user, ambari_info.password),
                            headers=self._get_standard_headers())
@@ -157,10 +227,13 @@ class AmbariClient():
                             self.handler.get_version() + '"}}')
 
         if result.status_code != 201:
-            LOG.error(_LE('Create cluster command failed. %s'), result.text)
+            LOG.error(_LE('Create cluster command failed. {result}').format(
+                      result=result.text))
             raise ex.HadoopProvisionError(
                 _('Failed to add cluster: %s') % result.text)
 
+    @cpo.event_wrapper(True, step=_("Add configurations to cluster"),
+                       param=('ambari_info', 2))
     def _add_configurations_to_cluster(
             self, cluster_spec, ambari_info, name):
 
@@ -190,8 +263,8 @@ class AmbariClient():
         for config_name in configs:
             if config_name in existing_configs:
                 if config_name == 'core-site' or config_name == 'global':
-                    existing_version = (existing_configs[config_name]['tag']
-                                        .lstrip('v'))
+                    existing_version = (
+                        existing_configs[config_name]['tag'].lstrip('v'))
                     version = int(existing_version) + 1
                 else:
                     continue
@@ -205,35 +278,37 @@ class AmbariClient():
             result = self._put(config_url, ambari_info, data=json.dumps(body))
             if result.status_code != 200:
                 LOG.error(
-                    _LE('Set configuration command failed. {0}').format(
-                        result.text))
+                    _LE('Set configuration command failed. {result}').format(
+                        result=result.text))
                 raise ex.HadoopProvisionError(
                     _('Failed to set configurations on cluster: %s')
                     % result.text)
 
+    @cpo.event_wrapper(
+        True, step=_("Add services to cluster"), param=('ambari_info', 2))
     def _add_services_to_cluster(self, cluster_spec, ambari_info, name):
         services = cluster_spec.services
         add_service_url = 'http://{0}/api/v1/clusters/{1}/services/{2}'
         for service in services:
-            # Make sure the service is deployed and is managed by Ambari
-            if service.deployed and service.ambari_managed:
+            if service.deployed and service.name != 'AMBARI':
                 result = self._post(add_service_url.format(
                     ambari_info.get_address(), name, service.name),
                     ambari_info)
                 if result.status_code not in [201, 409]:
                     LOG.error(
-                        _LE('Create service command failed. {0}').format(
-                            result.text))
+                        _LE('Create service command failed. {result}').format(
+                            result=result.text))
                     raise ex.HadoopProvisionError(
                         _('Failed to add services to cluster: %s')
                         % result.text)
 
+    @cpo.event_wrapper(
+        True, step=_("Add components to services"), param=('ambari_info', 2))
     def _add_components_to_services(self, cluster_spec, ambari_info, name):
         add_component_url = ('http://{0}/api/v1/clusters/{1}/services/{'
                              '2}/components/{3}')
         for service in cluster_spec.services:
-            # Make sure the service is deployed and is managed by Ambari
-            if service.deployed and service.ambari_managed:
+            if service.deployed and service.name != 'AMBARI':
                 for component in service.components:
                     result = self._post(add_component_url.format(
                         ambari_info.get_address(), name, service.name,
@@ -241,12 +316,14 @@ class AmbariClient():
                         ambari_info)
                     if result.status_code not in [201, 409]:
                         LOG.error(
-                            _LE('Create component command failed. {0}').format(
-                                result.text))
+                            _LE('Create component command failed. {result}')
+                            .format(result=result.text))
                         raise ex.HadoopProvisionError(
                             _('Failed to add components to services: %s')
                             % result.text)
 
+    @cpo.event_wrapper(
+        True, step=_("Add hosts and components"), param=('ambari_info', 3))
     def _add_hosts_and_components(
             self, cluster_spec, servers, ambari_info, name):
 
@@ -260,7 +337,8 @@ class AmbariClient():
                 ambari_info)
             if result.status_code != 201:
                 LOG.error(
-                    _LE('Create host command failed. {0}').format(result.text))
+                    _LE('Create host command failed. {result}').format(
+                        result=result.text))
                 raise ex.HadoopProvisionError(
                     _('Failed to add host: %s') % result.text)
 
@@ -268,24 +346,22 @@ class AmbariClient():
             # TODO(jspeidel): ensure that node group exists
             node_group = cluster_spec.node_groups[node_group_name]
             for component in node_group.components:
-                # Don't add any AMBARI or HUE components
-                # TODO(rlevas): Pragmatically determine if component is
-                #   managed by Ambari
-                if (component.find('AMBARI') != 0
-                        and component.find('HUE') != 0):
+                # don't add any AMBARI components
+                if component.find('AMBARI') != 0:
                     result = self._post(add_host_component_url.format(
                         ambari_info.get_address(), name, hostname, component),
                         ambari_info)
                     if result.status_code != 201:
                         LOG.error(
-                            _LE('Create host_component command failed. %s'),
-                            result.text)
+                            _LE('Create host_component command failed. '
+                                '{result}').format(result=result.text))
                         raise ex.HadoopProvisionError(
                             _('Failed to add host component: %s')
                             % result.text)
 
+    @cpo.event_wrapper(
+        True, step=_("Install services"), param=('ambari_info', 2))
     def _install_services(self, cluster_name, ambari_info):
-        LOG.info(_LI('Installing required Hadoop services ...'))
 
         ambari_address = ambari_info.get_address()
         install_url = ('http://{0}/api/v1/clusters/{'
@@ -303,15 +379,16 @@ class AmbariClient():
                 ambari_info, cluster_name, request_id),
                 ambari_info)
             if success:
-                LOG.info(_LI("Install of Hadoop stack successful."))
+                LOG.info(_LI("Hadoop stack installed successfully."))
                 self._finalize_ambari_state(ambari_info)
             else:
-                LOG.critical(_LC('Install command failed.'))
+                LOG.error(_LE('Install command failed.'))
                 raise ex.HadoopProvisionError(
                     _('Installation of Hadoop stack failed.'))
         elif result.status_code != 200:
             LOG.error(
-                _LE('Install command failed. {0}').format(result.text))
+                _LE('Install command failed. {result}').format(
+                    result=result.text))
             raise ex.HadoopProvisionError(
                 _('Installation of Hadoop stack failed.'))
 
@@ -321,17 +398,13 @@ class AmbariClient():
                     ambari_info.get_address(), cluster_name,
                     request_id))
 
-    # Returns the top-level requests API URI
-    def _get_command_request_uri(self, ambari_info, cluster_name):
-        return ('http://{0}/api/v1/clusters/{1}/requests'.format(
-            ambari_info.get_address(), cluster_name))
-
     def _wait_for_async_request(self, request_url, ambari_info):
         started = False
         while not started:
             result = self._get(request_url, ambari_info)
             LOG.debug(
-                'async request ' + request_url + ' response:\n' + result.text)
+                'async request {url} response: {response}'.format(
+                    url=request_url, response=result.text))
             json_result = json.loads(result.text)
             started = True
             for items in json_result['items']:
@@ -346,7 +419,6 @@ class AmbariClient():
         return started
 
     def _finalize_ambari_state(self, ambari_info):
-        LOG.info(_LI('Finalizing Ambari cluster state.'))
 
         persist_state_uri = 'http://{0}/api/v1/persist'.format(
             ambari_info.get_address())
@@ -357,17 +429,15 @@ class AmbariClient():
         result = self._post(persist_state_uri, ambari_info, data=persist_data)
 
         if result.status_code != 201 and result.status_code != 202:
-            LOG.warning(_LW('Finalizing of Ambari cluster state failed. {0}').
-                        format(result.text))
-            raise ex.HadoopProvisionError(
-                _('Unable to finalize Ambari state.'))
+            LOG.warning(_LW('Finalizing of Ambari cluster state failed. '
+                            '{result}').format(result.text))
+            raise ex.HadoopProvisionError(_('Unable to finalize Ambari '
+                                            'state.'))
+        LOG.info(_LI('Ambari cluster state finalized.'))
 
+    @cpo.event_wrapper(
+        True, step=_("Start services"), param=('ambari_info', 3))
     def start_services(self, cluster_name, cluster_spec, ambari_info):
-        LOG.info(_LI('Starting Hadoop services ...'))
-        LOG.info(_LI('Cluster name: %(cluster_name)s, Ambari server address:'
-                     ' %(server_address)s'),
-                 {'cluster_name': cluster_name,
-                  'server_address': ambari_info.get_address()})
         start_url = ('http://{0}/api/v1/clusters/{1}/services?ServiceInfo/'
                      'state=INSTALLED'.format(
                          ambari_info.get_address(), cluster_name))
@@ -385,28 +455,32 @@ class AmbariClient():
                                             request_id), ambari_info)
             if success:
                 LOG.info(
-                    _LI("Successfully started Hadoop cluster '{0}'.").format(
-                        cluster_name))
+                    _LI("Successfully started Hadoop cluster '{name}'.")
+                    .format(name=cluster_name))
+                LOG.info(_LI('Cluster name: {cluster_name}, '
+                             'Ambari server address: {server_address}')
+                         .format(cluster_name=cluster_name,
+                                 server_address=ambari_info.get_address()))
             else:
-                LOG.critical(_LC('Failed to start Hadoop cluster.'))
+                LOG.error(_LE('Failed to start Hadoop cluster.'))
                 raise ex.HadoopProvisionError(
                     _('Start of Hadoop services failed.'))
 
         elif result.status_code != 200:
             LOG.error(
-                _LE('Start command failed. Status: %(status)s, response: '
-                    '%(response)s'),
-                {'status': result.status_code, 'result': result.text})
+                _LE('Start command failed. Status: {status}, '
+                    'response: {response}').format(status=result.status_code,
+                                                   response=result.text))
             raise ex.HadoopProvisionError(
                 _('Start of Hadoop services failed.'))
 
     def _exec_ambari_command(self, ambari_info, body, cmd_uri):
 
-        LOG.debug('PUT URI: {0}'.format(cmd_uri))
+        LOG.debug('PUT URI: {uri}'.format(uri=cmd_uri))
         result = self._put(cmd_uri, ambari_info, data=body)
         if result.status_code == 202:
             LOG.debug(
-                'PUT response: {0}'.format(result.text))
+                'PUT response: {result}'.format(result=result.text))
             json_result = json.loads(result.text)
             href = json_result['href'] + '/tasks?fields=Tasks/status'
             success = self._wait_for_async_request(href, ambari_info)
@@ -414,16 +488,15 @@ class AmbariClient():
                 LOG.info(
                     _LI("Successfully changed state of Hadoop components "))
             else:
-                LOG.critical(_LC('Failed to change state of Hadoop '
-                                 'components'))
+                LOG.error(_LE('Failed to change state of Hadoop components'))
                 raise ex.HadoopProvisionError(
                     _('Failed to change state of Hadoop components'))
 
         else:
             LOG.error(
-                _LE('Command failed. Status: %(status)s, response: '
-                    '%(response)s'),
-                {'status': result.status_code, 'result': result.text})
+                _LE('Command failed. Status: {status}, response: '
+                    '{response}').format(status=result.status_code,
+                                         response=result.text))
             raise ex.HadoopProvisionError(_('Hadoop/Ambari command failed.'))
 
     def _get_host_list(self, servers):
@@ -440,10 +513,6 @@ class AmbariClient():
                                servers, cluster_spec)
 
     def _install_components(self, ambari_info, auth, cluster_name, servers):
-        LOG.info(_LI('Starting Hadoop components while scaling up'))
-        LOG.info(_LI('Cluster name %(cluster_name)s, Ambari server ip %(ip)s'),
-                 {'cluster_name': cluster_name,
-                  'ip': ambari_info.get_address()})
         # query for the host components on the given hosts that are in the
         # INIT state
         # TODO(jspeidel): provide request context
@@ -454,6 +523,10 @@ class AmbariClient():
                            ambari_info.get_address(), cluster_name,
                            self._get_host_list(servers)))
         self._exec_ambari_command(ambari_info, body, install_uri)
+        LOG.info(_LI('Started Hadoop components while scaling up'))
+        LOG.info(_LI('Cluster name {cluster_name}, Ambari server ip {ip}')
+                 .format(cluster_name=cluster_name,
+                         ip=ambari_info.get_address()))
 
     def _start_components(self, ambari_info, auth, cluster_name, servers,
                           cluster_spec):
@@ -467,7 +540,7 @@ class AmbariClient():
         result = self._get(installed_uri, ambari_info)
         if result.status_code == 200:
             LOG.debug(
-                'GET response: {0}'.format(result.text))
+                'GET response: {result}'.format(result=result.text))
             json_result = json.loads(result.text)
             items = json_result['items']
 
@@ -495,31 +568,33 @@ class AmbariClient():
                   'components in scaled instances.  status'
                   ' code returned = {0}').format(result.status))
 
-    def wait_for_host_registrations(self, num_hosts, ambari_info):
-        LOG.info(
-            _LI('Waiting for all Ambari agents to register with server ...'))
-
+    def _check_host_registrations(self, num_hosts, ambari_info):
         url = 'http://{0}/api/v1/hosts'.format(ambari_info.get_address())
-        result = None
-        json_result = None
+        try:
+            result = self._get(url, ambari_info)
+            json_result = json.loads(result.text)
 
-        # TODO(jspeidel): timeout
-        while result is None or len(json_result['items']) < num_hosts:
-            context.sleep(5)
-            try:
-                result = self._get(url, ambari_info)
-                json_result = json.loads(result.text)
+            LOG.debug('Registered Hosts: {current_number} '
+                      'of {final_number}'.format(
+                          current_number=len(json_result['items']),
+                          final_number=num_hosts))
+            for hosts in json_result['items']:
+                LOG.debug('Registered Host: {host}'.format(
+                    host=hosts['Hosts']['host_name']))
+            return result and len(json_result['items']) >= num_hosts
+        except Exception:
+            LOG.debug('Waiting to connect to ambari server')
+            return False
 
-                LOG.info(_LI('Registered Hosts: %(current_number)s '
-                             'of %(final_number)s'),
-                         {'current_number': len(json_result['items']),
-                          'final_number': num_hosts})
-                for hosts in json_result['items']:
-                    LOG.debug('Registered Host: {0}'.format(
-                        hosts['Hosts']['host_name']))
-            except Exception:
-                # TODO(jspeidel): max wait time
-                LOG.info(_LI('Waiting to connect to ambari server ...'))
+    @cpo.event_wrapper(True, step=_("Wait for all Ambari agents to register"),
+                       param=('ambari_info', 2))
+    def wait_for_host_registrations(self, num_hosts, ambari_info):
+        cluster = ambari_info.get_cluster()
+        poll_utils.plugin_option_poll(
+            cluster, self._check_host_registrations,
+            cfgprov.HOST_REGISTRATIONS_TIMEOUT,
+            _("Wait for host registrations"), 5, {
+                'num_hosts': num_hosts, 'ambari_info': ambari_info})
 
     def update_ambari_admin_user(self, password, ambari_info):
         old_pwd = ambari_info.password
@@ -540,8 +615,8 @@ class AmbariClient():
             ambari_info.get_address(), user.name)
 
         create_body = ('{{"Users":{{"password":"{0}","roles":"{1}"}} }}'.
-                       format(user.password, '%s' % ','.
-                              join(map(str, user.groups))))
+                       format(user.password, '%s' %
+                                             ','.join(map(str, user.groups))))
 
         result = self._post(user_url, ambari_info, data=create_body)
 
@@ -580,117 +655,13 @@ class AmbariClient():
         self._install_and_start_components(
             name, servers, ambari_info, cluster_spec)
 
+    @cpo.event_wrapper(
+        True, step=_("Decommission nodes"), param=('cluster', 1))
     def decommission_cluster_instances(self, cluster, clusterspec, instances,
                                        ambari_info):
-
-        request_uri = self._get_command_request_uri(ambari_info, cluster.name)
-
-        hosts_to_decommission = []
-        # Decommission HDFS datanodes to avoid loss of data
-        # during decommissioning process
-        for instance in instances:
-            ng_name = instance.node_group.name
-            if "DATANODE" in clusterspec.node_groups[ng_name].components:
-                # determine the instances that include HDFS support
-                hosts_to_decommission.append(instance.fqdn())
-
-        LOG.debug('AmbariClient: hosts_to_decommission = '
-                  + str(hosts_to_decommission))
-
-        # template for request body
-        body_header = ('{"RequestInfo" : { "context": "Decommission DataNode",'
-                       ' "command" : "DECOMMISSION", "service_name" : "HDFS",'
-                       ' "component_name" : "NAMENODE", '
-                       ' "parameters" : { "slave_type" : "DATANODE", ')
-
-        excluded_hosts_request = '"excluded_hosts" : "{0}"'
-
-        # generate comma-separated list of hosts to de-commission
-        list_of_hosts = ",".join(hosts_to_decommission)
-
-        LOG.debug('AmbariClient: list_of_hosts = ' + list_of_hosts)
-
-        # create the request body
-        request_body = (
-            body_header +
-            excluded_hosts_request.format(list_of_hosts)
-            + '}}'
-            + ', "Requests/resource_filters":[{"service_name":"HDFS",'
-            '"component_name":"NAMENODE"}]}')
-
-        LOG.debug('AmbariClient: about to make decommission request, uri = ' +
-                  request_uri)
-        LOG.debug('AmbariClient: about to make decommission request, ' +
-                  'request body  = ' + request_body)
-
-        # ask Ambari to decommission the datanodes
-        result = self._post(request_uri, ambari_info, request_body)
-        if result.status_code != 202:
-            LOG.error(_LE('AmbariClient: error while making decommission post '
-                          'request. Error is = %s'), result.text)
-            raise exc.InvalidException(
-                _('An error occurred while trying to '
-                  'decommission the DataNode instances that are '
-                  'being shut down. '
-                  'Please consult the Ambari server logs on the '
-                  'master node for '
-                  'more information about the failure.'))
-        else:
-            LOG.info(_LI('AmbariClient: decommission post request succeeded!'))
-
-        status_template = ('http://{0}/api/v1/clusters/{1}/hosts/{2}/'
-                           'host_components/{3}')
-
-        # find the host that the NameNode is deployed on
-        name_node_host = clusterspec.determine_component_hosts(
-            'NAMENODE').pop()
-        status_request = status_template.format(
-            ambari_info.get_address(),
-            cluster.name, name_node_host.fqdn(),
-            'NAMENODE')
-
-        LOG.debug('AmbariClient: about to make decommission status request,' +
-                  'uri = ' + status_request)
-
-        count = 0
-        while count < 100 and len(hosts_to_decommission) > 0:
-            LOG.info(_LI('AmbariClient: number of hosts waiting for '
-                         'decommissioning to complete = %s'),
-                     str(len(hosts_to_decommission)))
-
-            result = self._get(status_request, ambari_info)
-            if result.status_code != 200:
-                LOG.error(_LE('AmbariClient: error in making decommission '
-                              'status request, error = %s'), result.text)
-            else:
-                LOG.info(_LI('AmbariClient: decommission status request ok, '
-                             'result = %s'), result.text)
-                json_result = json.loads(result.text)
-                live_nodes = (
-                    json_result['metrics']['dfs']['namenode']['LiveNodes'])
-                # parse out the map of live hosts associated with the NameNode
-                json_result_nodes = json.loads(live_nodes)
-                for node in json_result_nodes.keys():
-                    admin_state = json_result_nodes[node]['adminState']
-                    if admin_state == 'Decommissioned':
-                        LOG.info(_LI('AmbariClient: node = %(node)s is '
-                                     'now in adminState = %(admin_state)s'),
-                                 {'node': node,
-                                  'admin_state': admin_state})
-                        # remove from list, to track which nodes
-                        # are now in Decommissioned state
-                        hosts_to_decommission.remove(node)
-
-            LOG.info(_LI('AmbariClient: sleeping for 5 seconds'))
-            context.sleep(5)
-
-            # increment loop counter
-            count += 1
-
-        if len(hosts_to_decommission) > 0:
-            LOG.error(_LE('AmbariClient: decommissioning process timed-out '
-                          'waiting for nodes to enter "Decommissioned" '
-                          'status.'))
+        raise exc.InvalidDataException(_('The HDP plugin does not support '
+                                         'the decommissioning of nodes '
+                                         'for HDP version 1.3.2'))
 
     def provision_cluster(self, cluster_spec, servers, ambari_info, name):
         self._add_cluster(ambari_info, name)
@@ -707,7 +678,7 @@ class AmbariClient():
         try:
             ambari_info.host.remote().close_http_session(ambari_info.port)
         except exc.NotFoundException:
-            LOG.info(_LI("HTTP session is not cached"))
+            LOG.warning(_LW("HTTP session is not cached"))
 
     def _get_services_in_state(self, cluster_name, ambari_info, state):
         services_url = ('http://{0}/api/v1/clusters/{1}/services?'
