@@ -20,7 +20,7 @@ from sahara.service.edp import hdfs_helper
 class EdpOozieEngine(edp_engine.EdpOozieEngine):
 
     def create_hdfs_dir(self, remote, dir_name):
-        hdfs_helper.create_dir_hadoop1(remote, dir_name, self.get_hdfs_user())
+        hdfs_helper.create_dir_hadoop2(remote, dir_name, self.get_hdfs_user())
 
     def get_resource_manager_uri(self, cluster):
-        return cluster['info']['MapReduce']['JobTracker']
+        return cluster['info']['Yarn']['ResourceManager']
