@@ -13,28 +13,19 @@
 # under the License.
 
 
-from oslo_log import log as logging
-from oslo_serialization import jsonutils as json
-import six
+import json
 
+from sahara import context
 import sahara.exceptions as e
 from sahara.i18n import _
 import sahara.plugins.exceptions as ex
-from sahara.plugins.mapr.util import commands as cmd
-from sahara.plugins.mapr.util import event_log as el
-from sahara.plugins.mapr.util import general as g
-from sahara.plugins.mapr.util import service_utils as su
 import sahara.plugins.provisioning as p
 from sahara.utils import files as files
 
-LOG = logging.getLogger(__name__)
-
-SERVICE_UI = 'Web UI'
 
 _INSTALL_PACKAGES_TIMEOUT = 3600
 
 
-@six.add_metaclass(g.Singleton)
 class Service(object):
     def __init__(self):
         self._name = None
@@ -46,7 +37,6 @@ class Service(object):
         self._cluster_defaults = []
         self._node_defaults = []
         self._validation_rules = []
-        self._priority = 1
 
     @property
     def name(self):
@@ -68,6 +58,10 @@ class Service(object):
     def dependencies(self):
         return self._dependencies
 
+    @property
+    def ui_info(self):
+        return self._ui_info
+
     @property
     def cluster_defaults(self):
         return self._cluster_defaults
@@ -80,34 +74,25 @@ class Service(object):
     def validation_rules(self):
         return self._validation_rules
 
-    def get_ui_info(self, cluster_context):
-        return self._ui_info
-
     def install(self, cluster_context, instances):
-        service_instances = cluster_context.filter_instances(instances,
-                                                             service=self)
+        with context.ThreadGroup() as tg:
+            for instance in instances:
+                tg.spawn('install-packages-%s' % instance.id,
+                         self._install_packages_on_instance, cluster_context,
+                         instance)
 
-        @el.provision_step(_("Install %s service") % self.ui_name,
-                           cluster_context_reference=0, instances_reference=1)
-        def _install(_context, _instances):
-            g.execute_on_instances(_instances,
-                                   self._install_packages_on_instance,
-                                   _context)
-        if service_instances:
-            _install(cluster_context, service_instances)
-
-    @el.provision_event(instance_reference=1)
-    def _install_packages_on_instance(self, instance, cluster_context):
+    def _install_packages_on_instance(self, cluster_context, instance):
         processes = [p for p in self.node_processes if
                      p.ui_name in instance.node_group.node_processes]
         if processes is not None and len(processes) > 0:
-            packages = self._get_packages(cluster_context, processes)
+            packages = self._get_packages(processes)
             cmd = cluster_context.distro.create_install_cmd(packages)
             with instance.remote() as r:
                 r.execute_command(cmd, run_as_root=True,
-                                  timeout=_INSTALL_PACKAGES_TIMEOUT)
+                                  timeout=_INSTALL_PACKAGES_TIMEOUT,
+                                  raise_when_error=False)
 
-    def _get_packages(self, cluster_context, node_processes):
+    def _get_packages(self, node_processes):
         result = []
 
         result += self.dependencies
@@ -115,13 +100,6 @@ class Service(object):
 
         return result
 
-    def _set_service_dir_owner(self, cluster_context, instances):
-        service_instances = cluster_context.filter_instances(instances,
-                                                             service=self)
-        LOG.debug("Changing %s service dir owner", self.ui_name)
-        for instance in service_instances:
-            cmd.chown(instance, 'mapr:mapr', self.service_dir(cluster_context))
-
     def post_install(self, cluster_context, instances):
         pass
 
@@ -219,10 +197,7 @@ class Service(object):
 
     def restart(self, instances):
         for node_process in self.node_processes:
-            filtered_instances = su.filter_by_node_process(instances,
-                                                           node_process)
-            if filtered_instances:
-                node_process.restart(filtered_instances)
+            node_process.restart(instances)
 
     def service_dir(self, cluster_context):
         args = {'mapr_home': cluster_context.mapr_home, 'name': self.name}
@@ -239,8 +214,11 @@ class Service(object):
     def conf_dir(self, cluster_context):
         return '%s/conf' % self.home_dir(cluster_context)
 
-    def post_configure_sh(self, cluster_context, instances):
-        pass
 
-    def post_configure(self, cluster_context, instances):
-        pass
+class Single(type):
+    _instances = {}
+
+    def __call__(cls, *args, **kwargs):
+        if cls not in cls._instances:
+            cls._instances[cls] = super(Single, cls).__call__(*args, **kwargs)
+        return cls._instances[cls]
