@@ -34,14 +34,6 @@ class MapRPlugin(p.ProvisioningPluginBase):
     def get_description(self):
         return MapRPlugin.description
 
-    def get_labels(self):
-        return {
-            'plugin_labels': {'enabled': {'status': True}},
-            'version_labels': {
-                '5.2.0.mrv2': {'enabled': {'status': True}},
-            }
-        }
-
     def get_versions(self):
         return vhf.VersionHandlerFactory.get().get_versions()
 
@@ -76,7 +68,7 @@ class MapRPlugin(p.ProvisioningPluginBase):
         v_handler = self._get_handler(cluster.hadoop_version)
         return v_handler.get_edp_engine(cluster, job_type)
 
-    def get_edp_job_types(self, versions=None):
+    def get_edp_job_types(self, versions=[]):
         res = {}
         for vers in self.get_versions():
             if not versions or vers in versions:
@@ -91,20 +83,3 @@ class MapRPlugin(p.ProvisioningPluginBase):
     def get_open_ports(self, node_group):
         v_handler = self._get_handler(node_group.cluster.hadoop_version)
         return v_handler.get_open_ports(node_group)
-
-    def get_health_checks(self, cluster):
-        v_handler = self._get_handler(cluster.hadoop_version)
-        return v_handler.get_cluster_checks(cluster)
-
-    def get_image_arguments(self, hadoop_version):
-        return self._get_handler(hadoop_version).get_image_arguments()
-
-    def pack_image(self, hadoop_version, remote,
-                   test_only=False, image_arguments=None):
-        version = self._get_handler(hadoop_version)
-        version.pack_image(hadoop_version, remote, test_only=test_only,
-                           image_arguments=image_arguments)
-
-    def validate_images(self, cluster, test_only=False, image_arguments=None):
-        self._get_handler(cluster.hadoop_version).validate_images(
-            cluster, test_only=test_only, image_arguments=image_arguments)
