@@ -13,9 +13,10 @@
 # under the License.
 
 
+import six
+
 import sahara.plugins.mapr.domain.node_process as np
 import sahara.plugins.mapr.domain.service as s
-import sahara.plugins.mapr.util.commands as cmd
 import sahara.plugins.mapr.util.validation_utils as vu
 
 
@@ -43,9 +44,8 @@ METRICS = np.NodeProcess(
 )
 
 
+@six.add_metaclass(s.Single)
 class Management(s.Service):
-    SSL_KEYSTORE = '/opt/mapr/conf/ssl_keystore'
-
     def __init__(self):
         super(Management, self).__init__()
         self._ui_name = 'Management'
@@ -55,10 +55,6 @@ class Management(s.Service):
         ]
         self._validation_rules = [
             vu.at_least(1, ZOOKEEPER),
-            vu.at_least(1, WEB_SERVER),
+            vu.exactly(1, WEB_SERVER),
             vu.odd_count_of(ZOOKEEPER),
         ]
-
-    def post_install(self, cluster_context, instances):
-        instance = cluster_context.get_instance(WEB_SERVER)
-        cmd.chown(instance, 'mapr:mapr', self.SSL_KEYSTORE)
