@@ -14,19 +14,20 @@
 
 
 from oslo_log import log as logging
+import six
 
 from sahara import context
 from sahara.i18n import _
+from sahara.i18n import _LI
 import sahara.plugins.mapr.domain.configuration_file as bcf
 import sahara.plugins.mapr.domain.node_process as np
 import sahara.plugins.mapr.domain.service as s
-import sahara.plugins.mapr.util.event_log as el
 import sahara.plugins.mapr.util.general as g
 import sahara.plugins.mapr.util.validation_utils as vu
 import sahara.plugins.provisioning as p
-from sahara.utils import cluster_progress_ops as cpo
 from sahara.utils import files
 
+
 LOG = logging.getLogger(__name__)
 
 CLDB = np.NodeProcess(
@@ -49,14 +50,13 @@ NFS = np.NodeProcess(
 )
 
 
+@six.add_metaclass(s.Single)
 class MapRFS(s.Service):
     _CREATE_DISK_LIST = 'plugins/mapr/resources/create_disk_list_file.sh'
     _DISK_SETUP_CMD = '/opt/mapr/server/disksetup -F /tmp/disk.list'
     _DISK_SETUP_TIMEOUT = 600
 
     ENABLE_MAPR_DB_NAME = 'Enable MapR-DB'
-    HEAP_SIZE_PERCENT_NAME = 'MapR-FS heap size percent'
-
     ENABLE_MAPR_DB_CONFIG = p.Config(
         name=ENABLE_MAPR_DB_NAME,
         applicable_target='general',
@@ -67,24 +67,12 @@ class MapRFS(s.Service):
         description=_('Specifies that MapR-DB is in use.')
     )
 
-    HEAP_SIZE_PERCENT = p.Config(
-        name=HEAP_SIZE_PERCENT_NAME,
-        applicable_target='MapRFS',
-        scope='cluster',
-        config_type="int",
-        priority=1,
-        default_value=8,
-        description=_(
-            'Specifies heap size for MapR-FS in percents of maximum value.')
-    )
-
     def __init__(self):
         super(MapRFS, self).__init__()
         self._ui_name = 'MapRFS'
         self._node_processes = [CLDB, FILE_SERVER, NFS]
         self._ui_info = [
-            ('Container Location Database (CLDB)', CLDB,
-             {s.SERVICE_UI: 'http://%s:7221'}),
+            ('Container Location Database (CLDB)', CLDB, 'http://%s:7221'),
         ]
         self._validation_rules = [
             vu.at_least(1, CLDB),
@@ -106,15 +94,12 @@ class MapRFS(s.Service):
         LOG.debug('Initializing MapR FS')
         instances = instances or cluster_context.get_instances()
         file_servers = cluster_context.filter_instances(instances, FILE_SERVER)
-        cpo.add_provisioning_step(cluster_context.cluster.id,
-                                  _("Initializing MapR-FS"), len(file_servers))
         with context.ThreadGroup() as tg:
             for instance in file_servers:
                 tg.spawn('init-mfs-%s' % instance.id,
                          self._init_mfs_instance, instance)
-        LOG.info('MapR FS successfully initialized')
+        LOG.info(_LI('MapR FS successfully initialized'))
 
-    @el.provision_event(instance_reference=1)
     def _init_mfs_instance(self, instance):
         self._generate_disk_list_file(instance, self._CREATE_DISK_LIST)
         self._execute_disksetup(instance)
@@ -122,7 +107,7 @@ class MapRFS(s.Service):
     def _generate_disk_list_file(self, instance, path_to_disk_setup_script):
         LOG.debug('Creating disk list file')
         g.run_script(instance, path_to_disk_setup_script, 'root',
-                     *instance.storage_paths())
+                     *instance.node_group.storage_paths())
 
     def _execute_disksetup(self, instance):
         with instance.remote() as rmt:
@@ -131,7 +116,7 @@ class MapRFS(s.Service):
                 timeout=self._DISK_SETUP_TIMEOUT)
 
     def get_configs(self):
-        return [MapRFS.ENABLE_MAPR_DB_CONFIG, MapRFS.HEAP_SIZE_PERCENT]
+        return [MapRFS.ENABLE_MAPR_DB_CONFIG]
 
     def get_config_files(self, cluster_context, configs, instance=None):
         default_path = 'plugins/mapr/services/maprfs/resources/cldb.conf'
@@ -142,16 +127,8 @@ class MapRFS(s.Service):
         cldb_conf.parse(files.get_file_text(default_path))
         cldb_conf.add_properties(self._get_cldb_conf_props(cluster_context))
 
-        warden_conf = bcf.PropertiesFile("warden.conf")
-        warden_conf.remote_path = "/opt/mapr/conf/"
-        if instance:
-            warden_conf.fetch(instance)
-        warden_conf.add_properties(
-            {'service.command.mfs.heapsize.percent': configs[
-                self.HEAP_SIZE_PERCENT_NAME]})
+        return [cldb_conf]
 
-        return [cldb_conf, warden_conf]
-
-    def _get_cldb_conf_props(self, cluster_context):
-        zookeepers = cluster_context.get_zookeeper_nodes_ip_with_port()
+    def _get_cldb_conf_props(self, context):
+        zookeepers = context.get_zookeeper_nodes_ip_with_port()
         return {'cldb.zookeeper.servers': zookeepers}
