@@ -20,6 +20,8 @@ import six
 
 import sahara.plugins.mapr.domain.configuration_file as cf
 import sahara.plugins.mapr.domain.service as s
+import sahara.plugins.mapr.services.hive.hive as hive
+from sahara.plugins.mapr.services.spark import spark
 import sahara.plugins.mapr.util.general as g
 import sahara.utils.files as f
 
@@ -28,21 +30,23 @@ LOG = logging.getLogger(__name__)
 db_spec = c.namedtuple('DatabaseSpec', ['db_name', 'user', 'password'])
 
 
+@six.add_metaclass(s.Single)
 class MySQL(s.Service):
     METRICS_SPECS = db_spec('metrics', 'maprmetrics', 'mapr')
     HUE_SPECS = db_spec('hue', 'maprhue', 'mapr')
     METASTORE_SPECS = db_spec('metastore', 'maprmetastore', 'mapr')
     RDBMS_SPECS = db_spec('rdbms', 'maprrdbms', 'mapr')
     OOZIE_SPECS = db_spec('oozie', 'maproozie', 'mapr')
-    SENTRY_SPECS = db_spec('sentry', 'maprsentry', 'mapr')
 
     SELECT_DATA = 'mysql -uroot --skip-column-names -e "%s"| grep -E "\w+"'
     GET_DBS_LIST = SELECT_DATA % 'SHOW DATABASES'
     GET_USERS_HOSTS = (
-        SELECT_DATA %
-        "SELECT Host FROM mysql.user WHERE mysql.user.User='%s'"  # nosec
+        SELECT_DATA % "SELECT Host FROM mysql.user WHERE mysql.user.User='%s'"
     )
 
+    SCHEMA_PATH = (
+        '/opt/mapr/hive/hive-{0}/scripts/metastore/upgrade/mysql/'
+        'hive-schema-{0}.0.mysql.sql')
     DRIVER_CLASS = 'com.mysql.jdbc.Driver'
     MYSQL_SERVER_PORT = 3306
     MYSQL_INSTALL_SCRIPT = 'plugins/mapr/resources/install_mysql.sh'
@@ -53,14 +57,10 @@ class MySQL(s.Service):
         self._ui_name = 'MySQL'
 
     @staticmethod
-    def _get_db_daemon_name(distro, distro_version):
+    def _get_db_daemon_name(distro):
         if distro.lower() == 'ubuntu':
             return 'mysql'
-        if distro.lower() == 'suse':
-            return 'mysqld'
-        if distro.lower() in ['centos', 'redhatenterpriseserver', 'redhat']:
-            if distro_version.split('.')[0] == '7':
-                return 'mariadb'
+        if distro.lower() in ['centos', 'redhatenterpriseserver', 'suse']:
             return 'mysqld'
         return None
 
@@ -108,7 +108,7 @@ class MySQL(s.Service):
 
     @staticmethod
     def _create_metastore_db(instance, cluster_context, databases, instances):
-        hive_meta = cluster_context.get_instance('HiveMetastore')
+        hive_meta = cluster_context.get_instance(hive.HIVE_METASTORE)
 
         if not hive_meta:
             return
@@ -116,7 +116,25 @@ class MySQL(s.Service):
         db_name = MySQL.METASTORE_SPECS.db_name
         if db_name not in databases:
             MySQL._create_service_db(instance, MySQL.METASTORE_SPECS)
-        MySQL._grant_access(instance, MySQL.METASTORE_SPECS, instances)
+            MySQL._grant_access(instance, MySQL.METASTORE_SPECS, instances)
+            with hive_meta.remote() as r:
+                hive_serv = cluster_context.get_service(hive.HIVE_METASTORE)
+                schema_path = MySQL.SCHEMA_PATH.format(hive_serv.version)
+                script = MySQL._create_script_obj('hive_schema.sql',
+                                                  'hive_schema.sql',
+                                                  db_name=db_name,
+                                                  path=schema_path)
+                r.write_file_to(script.remote_path, script.render())
+                args = {
+                    'user': MySQL.METASTORE_SPECS.user,
+                    'password': MySQL.METASTORE_SPECS.password,
+                    'host': instance.management_ip,
+                    'path': script.remote_path
+                }
+                cmd = 'mysql -h{host} -u{user} -p{password} < {path}'
+                r.execute_command(cmd.format(**args), run_as_root=True)
+        else:
+            MySQL._grant_access(instance, MySQL.METASTORE_SPECS, instances)
 
     @staticmethod
     def _create_oozie_db(instance, databases, instances):
@@ -124,25 +142,14 @@ class MySQL(s.Service):
             MySQL._create_service_db(instance, MySQL.OOZIE_SPECS)
         MySQL._grant_access(instance, MySQL.OOZIE_SPECS, instances)
 
-    @staticmethod
-    def _create_sentry_db(instance, cluster_context, databases, instances):
-        sentry_instance = cluster_context.get_instance('Sentry')
-        if not sentry_instance:
-            return
-        if MySQL.SENTRY_SPECS.db_name not in databases:
-            MySQL._create_service_db(instance, MySQL.SENTRY_SPECS)
-        MySQL._grant_access(instance, MySQL.SENTRY_SPECS, instances)
-
     @staticmethod
     def start_mysql_server(cluster_context):
         LOG.debug('Starting MySQL Server')
         instance = MySQL.get_db_instance(cluster_context)
         distro = cluster_context.distro
-        distro_version = cluster_context.distro_version
         with instance.remote() as r:
             r.execute_command(('service %s restart' %
-                               MySQL._get_db_daemon_name(distro.name,
-                                                         distro_version)),
+                               MySQL._get_db_daemon_name(distro.name)),
                               run_as_root=True)
         LOG.debug('MySQL Server successfully started')
 
@@ -163,8 +170,8 @@ class MySQL(s.Service):
         return list()
 
     @staticmethod
-    def get_db_instance(cluster_context):
-        return cluster_context.oozie_server
+    def get_db_instance(context):
+        return context.oozie_server or context.get_instance(spark.SPARK_MASTER)
 
     @staticmethod
     def create_databases(cluster_context, instances):
@@ -176,8 +183,6 @@ class MySQL(s.Service):
         MySQL._create_oozie_db(db_instance, databases, instances)
         MySQL._create_metastore_db(
             db_instance, cluster_context, databases, instances)
-        MySQL._create_sentry_db(db_instance, cluster_context, databases,
-                                instances)
 
     @staticmethod
     def _create_script_obj(filename, template, **kwargs):
@@ -192,16 +197,15 @@ class MySQL(s.Service):
     @staticmethod
     def _grant_access(instance, specs, instances):
         f_name = 'grant_access_%s.sql' % specs.db_name
-        ips = [i.internal_ip for i in instances]
+        ips = [i.management_ip for i in instances]
         user_hosts = MySQL.get_user_hosts(instance, specs.user)
         script = MySQL._create_script_obj(f_name, 'grant_access.sql',
-                                          hosts=set(ips) - set(user_hosts),
+                                          hosts=set(ips)-set(user_hosts),
                                           db_name=specs.db_name,
                                           user=specs.user,
                                           password=specs.password)
         MySQL._execute_script(instance, script.remote_path, script.render())
 
     @staticmethod
-    def install_mysql(instance, distro_name, distro_version):
-        g.run_script(instance, MySQL.MYSQL_INSTALL_SCRIPT, 'root', distro_name,
-                     distro_version.split('.')[0])
+    def install_mysql(instance, distro_name):
+        g.run_script(instance, MySQL.MYSQL_INSTALL_SCRIPT, 'root', distro_name)
