@@ -20,6 +20,7 @@ from sahara.plugins.mapr.services.hbase import hbase
 from sahara.plugins.mapr.services.hive import hive
 from sahara.plugins.mapr.services.httpfs import httpfs
 from sahara.plugins.mapr.services.hue import hue
+from sahara.plugins.mapr.services.impala import impala
 from sahara.plugins.mapr.services.mahout import mahout
 from sahara.plugins.mapr.services.management import management
 from sahara.plugins.mapr.services.mapreduce import mapreduce
@@ -49,21 +50,20 @@ class VersionHandler(bvh.BaseVersionHandler):
             mapreduce.MapReduce(),
             maprfs.MapRFS(),
             management.Management(),
-            oozie.OozieV401(),
+            oozie.Oozie(),
+            hive.HiveV012(),
             hive.HiveV013(),
             hbase.HBaseV094(),
-            hbase.HBaseV0987(),
+            hbase.HBaseV098(),
             httpfs.HttpFS(),
-            mahout.MahoutV09(),
-            pig.PigV013(),
-            pig.PigV014(),
+            mahout.Mahout(),
+            pig.Pig(),
             swift.Swift(),
             flume.Flume(),
-            drill.DrillV07(),
-            drill.DrillV08(),
-            drill.DrillV09(),
+            drill.Drill(),
             sqoop2.Sqoop2(),
-            hue.HueV360(),
+            impala.ImpalaV123(),
+            hue.Hue(),
         ]
 
     def get_context(self, cluster, added=None, removed=None):
