@@ -20,17 +20,19 @@ from sahara.plugins.mapr.services.hbase import hbase
 from sahara.plugins.mapr.services.hive import hive
 from sahara.plugins.mapr.services.httpfs import httpfs
 from sahara.plugins.mapr.services.hue import hue
+from sahara.plugins.mapr.services.impala import impala
 from sahara.plugins.mapr.services.mahout import mahout
-from sahara.plugins.mapr.services.management import management
+from sahara.plugins.mapr.services.management import management as mng
 from sahara.plugins.mapr.services.mapreduce import mapreduce
 from sahara.plugins.mapr.services.maprfs import maprfs
 from sahara.plugins.mapr.services.oozie import oozie
 from sahara.plugins.mapr.services.pig import pig
 from sahara.plugins.mapr.services.sqoop import sqoop2
 from sahara.plugins.mapr.services.swift import swift
-import sahara.plugins.mapr.versions.v4_0_1_mrv1.context as c
+import sahara.plugins.mapr.versions.v4_0_2_mrv1.context as c
 
-version = '4.0.1.mrv1'
+
+version = '4.0.2.mrv1'
 
 
 class VersionHandler(bvh.BaseVersionHandler):
@@ -40,30 +42,26 @@ class VersionHandler(bvh.BaseVersionHandler):
         self._required_services = [
             mapreduce.MapReduce(),
             maprfs.MapRFS(),
-            management.Management(),
+            mng.Management(),
             oozie.Oozie(),
         ]
         self._services = [
-            maprfs.MapRFS(),
-            management.Management(),
-            oozie.OozieV401(),
-            hive.HiveV013(),
-            hbase.HBaseV094(),
-            hbase.HBaseV0987(),
-            hbase.HBaseV0989(),
-            httpfs.HttpFS(),
-            mahout.MahoutV09(),
-            pig.PigV013(),
-            pig.PigV014(),
-            swift.Swift(),
             mapreduce.MapReduce(),
+            maprfs.MapRFS(),
+            mng.Management(),
+            oozie.Oozie(),
+            hive.HiveV012(),
+            hive.HiveV013(),
             flume.Flume(),
-            drill.DrillV07(),
-            drill.DrillV08(),
-            drill.DrillV09(),
+            hbase.HBaseV098(),
+            hue.Hue(),
+            httpfs.HttpFS(),
+            mahout.Mahout(),
+            pig.Pig(),
             sqoop2.Sqoop2(),
-            hue.HueV360(),
-            hue.HueV370(),
+            impala.ImpalaV141(),
+            swift.Swift(),
+            drill.Drill()
         ]
 
     def get_context(self, cluster, added=None, removed=None):
