@@ -21,20 +21,18 @@ from sahara.plugins.mapr.services.hive import hive
 from sahara.plugins.mapr.services.httpfs import httpfs
 from sahara.plugins.mapr.services.hue import hue
 from sahara.plugins.mapr.services.impala import impala
-from sahara.plugins.mapr.services.kafka import kafka
 from sahara.plugins.mapr.services.mahout import mahout
 from sahara.plugins.mapr.services.management import management as mng
 from sahara.plugins.mapr.services.maprfs import maprfs
 from sahara.plugins.mapr.services.oozie import oozie
 from sahara.plugins.mapr.services.pig import pig
-from sahara.plugins.mapr.services.sentry import sentry
-from sahara.plugins.mapr.services.spark import spark
 from sahara.plugins.mapr.services.sqoop import sqoop2
 from sahara.plugins.mapr.services.swift import swift
 from sahara.plugins.mapr.services.yarn import yarn
-import sahara.plugins.mapr.versions.v5_2_0_mrv2.context as c
+import sahara.plugins.mapr.versions.v4_0_2_mrv2.context as c
 
-version = "5.2.0.mrv2"
+
+version = '4.0.2.mrv2'
 
 
 class VersionHandler(bvh.BaseVersionHandler):
@@ -42,33 +40,28 @@ class VersionHandler(bvh.BaseVersionHandler):
         super(VersionHandler, self).__init__()
         self._version = version
         self._required_services = [
-            yarn.YARNv270(),
+            yarn.YARNv251(),
             maprfs.MapRFS(),
             mng.Management(),
             oozie.Oozie(),
         ]
         self._services = [
-            hive.HiveV12(),
-            pig.PigV016(),
-            impala.ImpalaV250(),
-            flume.FlumeV16(),
-            sqoop2.Sqoop2(),
-            mahout.MahoutV012(),
-            oozie.OozieV420(),
-            hue.HueV310(),
-            hue.HueLivyV310(),
-            hbase.HBaseV111(),
-            drill.DrillV19(),
-            yarn.YARNv270(),
+            yarn.YARNv251(),
             maprfs.MapRFS(),
             mng.Management(),
+            oozie.Oozie(),
+            hive.HiveV012(),
+            hive.HiveV013(),
+            impala.ImpalaV141(),
+            flume.Flume(),
+            hbase.HBaseV098(),
+            hue.Hue(),
             httpfs.HttpFS(),
+            mahout.Mahout(),
+            pig.Pig(),
+            sqoop2.Sqoop2(),
             swift.Swift(),
-            sentry.SentryV16(),
-            spark.SparkOnYarnV201(),
-            kafka.Kafka(),
-            kafka.KafkaConnect(),
-            kafka.KafkaRest(),
+            drill.Drill()
         ]
 
     def get_context(self, cluster, added=None, removed=None):
