@@ -21,22 +21,19 @@ def _load_versions():
     m_template = 'sahara.plugins.mapr.versions.%s.version_handler'
 
     def predicate(v_dir):
-        if v_dir != "__pycache__":
-            v_dir = os.path.join(d_name, v_dir)
-            return os.path.isdir(v_dir) and os.listdir(v_dir)
-
-        return False
+        return os.path.isdir(os.path.join(d_name, v_dir))
 
     def mapper(v_dir):
         return m_template % v_dir
 
-    v_dirs = filter(predicate, os.listdir(d_name))
-    m_names = map(mapper, v_dirs)
-    versions = {}
-    for m_name in m_names:
+    def reducer(versions, m_name):
         m = __import__(m_name, fromlist=['sahara'])
         versions[m.version] = getattr(m, 'VersionHandler')()
-    return versions
+        return versions
+
+    v_dirs = filter(predicate, os.listdir(d_name))
+    m_names = map(mapper, v_dirs)
+    return reduce(reducer, m_names, {})
 
 
 class VersionHandlerFactory(object):
@@ -51,7 +48,7 @@ class VersionHandlerFactory(object):
         return VersionHandlerFactory.instance
 
     def get_versions(self):
-        return list(VersionHandlerFactory.versions.keys())
+        return VersionHandlerFactory.versions.keys()
 
     def get_handler(self, version):
         return VersionHandlerFactory.versions[version]
