@@ -13,6 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+
+from sahara import exceptions as ex
+from sahara.i18n import _
 from sahara.plugins import base as plugins_base
 from sahara.utils import resources
 
@@ -26,10 +29,6 @@ class ProvisioningPluginBase(plugins_base.PluginInterface):
     def get_configs(self, hadoop_version):
         pass
 
-    @plugins_base.optional
-    def get_hdfs_user(self):
-        pass
-
     @plugins_base.required
     def get_node_processes(self, hadoop_version):
         pass
@@ -63,16 +62,20 @@ class ProvisioningPluginBase(plugins_base.PluginInterface):
         pass
 
     @plugins_base.optional
-    def get_oozie_server(self, cluster):
+    def get_edp_engine(self, cluster, job_type):
         pass
 
     @plugins_base.optional
-    def validate_edp(self, cluster):
-        pass
+    def get_edp_job_types(self, versions=[]):
+        return {}
 
     @plugins_base.optional
-    def get_resource_manager_uri(self, cluster):
-        pass
+    def get_edp_config_hints(self, job_type, version):
+        return {}
+
+    @plugins_base.required_with_default
+    def get_open_ports(self, node_group):
+        return []
 
     @plugins_base.required_with_default
     def decommission_nodes(self, cluster, instances):
@@ -111,18 +114,22 @@ class ProvisioningPluginBase(plugins_base.PluginInterface):
             for config_name in configs[applicable_target]:
                 confs = config_objs_map.get(applicable_target)
                 if not confs:
-                    # TODO(slukjanov): raise specific exception
-                    raise RuntimeError("Can't find applicable target '%s'"
-                                       % applicable_target)
+                    raise ex.ConfigurationError(
+                        _("Can't find applicable target "
+                          "'%(applicable_target)s' for '%(config_name)s'")
+                        % {"applicable_target": applicable_target,
+                           "config_name": config_name})
                 conf = confs.get(config_name)
                 if not conf:
-                    # TODO(slukjanov): raise specific exception
-                    raise RuntimeError("Can't find config '%s' in '%s'"
-                                       % (config_name, applicable_target))
+                    raise ex.ConfigurationError(
+                        _("Can't find config '%(config_name)s' "
+                          "in '%(applicable_target)s'")
+                        % {"config_name": config_name,
+                           "applicable_target": applicable_target})
                 result.append(UserInput(
                     conf, configs[applicable_target][config_name]))
 
-        return result
+        return sorted(result)
 
 
 class Config(resources.BaseResource):
@@ -159,6 +166,9 @@ class Config(resources.BaseResource):
         # TODO(slukjanov): all custom fields from res
         return res
 
+    def __lt__(self, other):
+        return self.name < other.name
+
     def __repr__(self):
         return '<Config %s in %s>' % (self.name, self.applicable_target)
 
@@ -173,6 +183,9 @@ class UserInput(object):
     def __eq__(self, other):
         return self.config == other.config and self.value == other.value
 
+    def __lt__(self, other):
+        return (self.config, self.value) < (other.config, other.value)
+
     def __repr__(self):
         return '<UserInput %s = %s>' % (self.config.name, self.value)
 
