@@ -15,21 +15,22 @@
 
 import os
 
-from oslo.config import cfg
+from oslo_config import cfg
+from oslo_log import log as logging
 
 from sahara import conductor
 from sahara import context
 from sahara.i18n import _
 from sahara.i18n import _LI
-from sahara.openstack.common import log as logging
-from sahara.plugins.general import exceptions as ex
-from sahara.plugins.general import utils
+from sahara.plugins import exceptions as ex
 from sahara.plugins import provisioning as p
 from sahara.plugins.spark import config_helper as c_helper
 from sahara.plugins.spark import edp_engine
 from sahara.plugins.spark import run_scripts as run
 from sahara.plugins.spark import scaling as sc
+from sahara.plugins import utils
 from sahara.topology import topology_helper as th
+from sahara.utils import cluster_progress_ops as cpo
 from sahara.utils import files as f
 from sahara.utils import general as ug
 from sahara.utils import remote
@@ -75,6 +76,15 @@ class SparkProvider(p.ProvisioningPluginBase):
             raise ex.InvalidComponentCountException("datanode", _("1 or more"),
                                                     nn_count)
 
+        rep_factor = c_helper.get_config_value('HDFS', "dfs.replication",
+                                               cluster)
+        if dn_count < rep_factor:
+            raise ex.InvalidComponentCountException(
+                'datanode', _('%s or more') % rep_factor, dn_count,
+                _('Number of %(dn)s instances should not be less '
+                  'than %(replication)s')
+                % {'dn': 'datanode', 'replication': 'dfs.replication'})
+
         # validate Spark Master Node and Spark Slaves
         sm_count = sum([ng.count for ng
                         in utils.get_node_groups(cluster, "master")])
@@ -96,21 +106,38 @@ class SparkProvider(p.ProvisioningPluginBase):
     def configure_cluster(self, cluster):
         self._setup_instances(cluster)
 
-    def start_cluster(self, cluster):
-        nn_instance = utils.get_instance(cluster, "namenode")
-        sm_instance = utils.get_instance(cluster, "master")
-        dn_instances = utils.get_instances(cluster, "datanode")
-
-        # Start the name node
+    @cpo.event_wrapper(
+        True, step=utils.start_process_event_message("NameNode"))
+    def _start_namenode(self, nn_instance):
         with remote.get_remote(nn_instance) as r:
             run.format_namenode(r)
             run.start_processes(r, "namenode")
 
-        # start the data nodes
-        self._start_slave_datanode_processes(dn_instances)
+    def start_spark(self, cluster):
+        sm_instance = utils.get_instance(cluster, "master")
+        if sm_instance:
+            self._start_spark(cluster, sm_instance)
 
-        LOG.info(_LI("Hadoop services in cluster %s have been started"),
-                 cluster.name)
+    @cpo.event_wrapper(
+        True, step=utils.start_process_event_message("SparkMasterNode"))
+    def _start_spark(self, cluster, sm_instance):
+        with remote.get_remote(sm_instance) as r:
+            run.start_spark_master(r, self._spark_home(cluster))
+            LOG.info(_LI("Spark service at {host} has been started").format(
+                     host=sm_instance.hostname()))
+
+    def start_cluster(self, cluster):
+        nn_instance = utils.get_instance(cluster, "namenode")
+        dn_instances = utils.get_instances(cluster, "datanode")
+
+        # Start the name node
+        self._start_namenode(nn_instance)
+
+        # start the data nodes
+        self._start_datanode_processes(dn_instances)
+
+        LOG.info(_LI("Hadoop services in cluster {cluster} have been started")
+                 .format(cluster=cluster.name))
 
         with remote.get_remote(nn_instance) as r:
             r.execute_command("sudo -u hdfs hdfs dfs -mkdir -p /user/$USER/")
@@ -118,14 +145,10 @@ class SparkProvider(p.ProvisioningPluginBase):
                               "/user/$USER/")
 
         # start spark nodes
-        if sm_instance:
-            with remote.get_remote(sm_instance) as r:
-                run.start_spark_master(r, self._spark_home(cluster))
-                LOG.info(_LI("Spark service at '%s' has been started"),
-                         sm_instance.hostname())
+        self.start_spark(cluster)
 
-        LOG.info(_LI('Cluster %s has been started successfully'),
-                 cluster.name)
+        LOG.info(_LI('Cluster {cluster} has been started successfully').format(
+                 cluster=cluster.name))
         self._set_cluster_info(cluster)
 
     def _spark_home(self, cluster):
@@ -150,12 +173,17 @@ class SparkProvider(p.ProvisioningPluginBase):
         else:
             config_slaves = "\n"
 
+        # Any node that might be used to run spark-submit will need
+        # these libs for swift integration
+        config_defaults = c_helper.generate_spark_executor_classpath(cluster)
+
+        extra['job_cleanup'] = c_helper.generate_job_cleanup_config(cluster)
         for ng in cluster.node_groups:
             extra[ng.id] = {
                 'xml': c_helper.generate_xml_configs(
                     ng.configuration(),
                     ng.storage_paths(),
-                    nn.hostname(), None,
+                    nn.hostname(), None
                 ),
                 'setup_script': c_helper.generate_hadoop_setup_script(
                     ng.storage_paths(),
@@ -163,7 +191,8 @@ class SparkProvider(p.ProvisioningPluginBase):
                         ng.configuration())
                 ),
                 'sp_master': config_master,
-                'sp_slaves': config_slaves
+                'sp_slaves': config_slaves,
+                'sp_defaults': config_defaults
             }
 
         if c_helper.is_data_locality_enabled(cluster):
@@ -174,12 +203,20 @@ class SparkProvider(p.ProvisioningPluginBase):
 
         return extra
 
-    def _start_slave_datanode_processes(self, dn_instances):
+    def _start_datanode_processes(self, dn_instances):
+        if len(dn_instances) == 0:
+            return
+
+        cpo.add_provisioning_step(
+            dn_instances[0].cluster_id,
+            utils.start_process_event_message("DataNodes"), len(dn_instances))
+
         with context.ThreadGroup() as tg:
             for i in dn_instances:
                 tg.spawn('spark-start-dn-%s' % i.instance_name,
                          self._start_datanode, i)
 
+    @cpo.event_wrapper(mark_successful_on_exit=True)
     def _start_datanode(self, instance):
         with instance.remote() as r:
             run.start_processes(r, "datanode")
@@ -194,6 +231,8 @@ class SparkProvider(p.ProvisioningPluginBase):
 
     def _push_configs_to_nodes(self, cluster, extra, new_instances):
         all_instances = utils.get_instances(cluster)
+        cpo.add_provisioning_step(
+            cluster.id, _("Push configs to nodes"), len(all_instances))
         with context.ThreadGroup() as tg:
             for instance in all_instances:
                 if instance in new_instances:
@@ -205,18 +244,23 @@ class SparkProvider(p.ProvisioningPluginBase):
                              self._push_configs_to_existing_node, cluster,
                              extra, instance)
 
+    @cpo.event_wrapper(mark_successful_on_exit=True)
     def _push_configs_to_new_node(self, cluster, extra, instance):
         ng_extra = extra[instance.node_group.id]
 
         files_hadoop = {
-            '/etc/hadoop/conf/core-site.xml': ng_extra['xml']['core-site'],
-            '/etc/hadoop/conf/hdfs-site.xml': ng_extra['xml']['hdfs-site'],
+            os.path.join(c_helper.HADOOP_CONF_DIR,
+                         "core-site.xml"): ng_extra['xml']['core-site'],
+            os.path.join(c_helper.HADOOP_CONF_DIR,
+                         "hdfs-site.xml"): ng_extra['xml']['hdfs-site'],
         }
 
         sp_home = self._spark_home(cluster)
         files_spark = {
             os.path.join(sp_home, 'conf/spark-env.sh'): ng_extra['sp_master'],
-            os.path.join(sp_home, 'conf/slaves'): ng_extra['sp_slaves']
+            os.path.join(sp_home, 'conf/slaves'): ng_extra['sp_slaves'],
+            os.path.join(sp_home,
+                         'conf/spark-defaults.conf'): ng_extra['sp_defaults']
         }
 
         files_init = {
@@ -273,7 +317,9 @@ class SparkProvider(p.ProvisioningPluginBase):
 
             self._write_topology_data(r, cluster, extra)
             self._push_master_configs(r, cluster, extra, instance)
+            self._push_cleanup_job(r, cluster, extra, instance)
 
+    @cpo.event_wrapper(mark_successful_on_exit=True)
     def _push_configs_to_existing_node(self, cluster, extra, instance):
         node_processes = instance.node_group.node_processes
         need_update_hadoop = (c_helper.is_data_locality_enabled(cluster) or
@@ -288,9 +334,13 @@ class SparkProvider(p.ProvisioningPluginBase):
                 os.path.join(sp_home,
                              'conf/spark-env.sh'): ng_extra['sp_master'],
                 os.path.join(sp_home, 'conf/slaves'): ng_extra['sp_slaves'],
+                os.path.join(
+                    sp_home,
+                    'conf/spark-defaults.conf'): ng_extra['sp_defaults']
             }
             r = remote.get_remote(instance)
             r.write_files_to(files)
+            self._push_cleanup_job(r, cluster, extra, instance)
         if need_update_hadoop:
             with remote.get_remote(instance) as r:
                 self._write_topology_data(r, cluster, extra)
@@ -303,14 +353,27 @@ class SparkProvider(p.ProvisioningPluginBase):
 
     def _push_master_configs(self, r, cluster, extra, instance):
         node_processes = instance.node_group.node_processes
-
         if 'namenode' in node_processes:
             self._push_namenode_configs(cluster, r)
 
+    def _push_cleanup_job(self, r, cluster, extra, instance):
+        node_processes = instance.node_group.node_processes
+        if 'master' in node_processes:
+            if extra['job_cleanup']['valid']:
+                r.write_file_to('/etc/hadoop/tmp-cleanup.sh',
+                                extra['job_cleanup']['script'])
+                r.execute_command("chmod 755 /etc/hadoop/tmp-cleanup.sh")
+                cmd = 'sudo sh -c \'echo "%s" > /etc/cron.d/spark-cleanup\''
+                r.execute_command(cmd % extra['job_cleanup']['cron'])
+            else:
+                r.execute_command("sudo rm -f /etc/hadoop/tmp-cleanup.sh")
+                r.execute_command("sudo rm -f /etc/crond.d/spark-cleanup")
+
     def _push_namenode_configs(self, cluster, r):
         r.write_file_to('/etc/hadoop/dn.incl',
                         utils.generate_fqdn_host_names(
                             utils.get_instances(cluster, "datanode")))
+        r.write_file_to('/etc/hadoop/dn.excl', '')
 
     def _set_cluster_info(self, cluster):
         nn = utils.get_instance(cluster, "namenode")
@@ -373,11 +436,13 @@ class SparkProvider(p.ProvisioningPluginBase):
         self._setup_instances(cluster, instances)
         nn = utils.get_instance(cluster, "namenode")
         run.refresh_nodes(remote.get_remote(nn), "dfsadmin")
-        self._start_slave_datanode_processes(instances)
+        dn_instances = [instance for instance in instances if
+                        'datanode' in instance.node_group.node_processes]
+        self._start_datanode_processes(dn_instances)
 
         run.start_spark_master(r_master, self._spark_home(cluster))
-        LOG.info(_LI("Spark master service at '%s' has been restarted"),
-                 master.hostname())
+        LOG.info(_LI("Spark master service at {host} has been restarted")
+                 .format(host=master.hostname()))
 
     def _get_scalable_processes(self):
         return ["datanode", "slave"]
@@ -423,3 +488,40 @@ class SparkProvider(p.ProvisioningPluginBase):
             return edp_engine.EdpEngine(cluster)
 
         return None
+
+    def get_edp_job_types(self, versions=[]):
+        res = {}
+        for vers in self.get_versions():
+            if not versions or vers in versions:
+                if edp_engine.EdpEngine.edp_supported(vers):
+                    res[vers] = edp_engine.EdpEngine.get_supported_job_types()
+        return res
+
+    def get_edp_config_hints(self, job_type, version):
+        if edp_engine.EdpEngine.edp_supported(version):
+            return edp_engine.EdpEngine.get_possible_job_config(job_type)
+        return {}
+
+    def get_open_ports(self, node_group):
+        cluster = node_group.cluster
+        ports_map = {
+            'namenode': [8020, 50070, 50470],
+            'datanode': [50010, 1004, 50075, 1006, 50020],
+            'master': [
+                int(c_helper.get_config_value("Spark", "Master port",
+                                              cluster)),
+                int(c_helper.get_config_value("Spark", "Master webui port",
+                                              cluster)),
+            ],
+            'slave': [
+                int(c_helper.get_config_value("Spark", "Worker webui port",
+                                              cluster))
+            ]
+        }
+
+        ports = []
+        for process in node_group.node_processes:
+            if process in ports_map:
+                ports.extend(ports_map[process])
+
+        return ports
