@@ -13,8 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import copy
-
+from oslo_config import cfg
 from oslo_log import log as logging
 import six
 import yaml
@@ -22,18 +21,18 @@ import yaml
 from sahara import conductor
 from sahara import context
 from sahara.i18n import _
+from sahara.i18n import _LI
 from sahara.plugins import exceptions as ex
 from sahara.plugins import provisioning as p
 from sahara.plugins.storm import config_helper as c_helper
-from sahara.plugins.storm import edp_engine
 from sahara.plugins.storm import run_scripts as run
 from sahara.plugins import utils
 from sahara.utils import cluster_progress_ops as cpo
-from sahara.utils import general as ug
 from sahara.utils import remote
 
 conductor = conductor.API
 LOG = logging.getLogger(__name__)
+CONF = cfg.CONF
 
 
 class StormProvider(p.ProvisioningPluginBase):
@@ -51,20 +50,8 @@ class StormProvider(p.ProvisioningPluginBase):
             _("This plugin provides an ability to launch Storm "
               "cluster without any management consoles."))
 
-    def get_labels(self):
-        default = {'enabled': {'status': True}, 'stable': {'status': True}}
-        deprecated = {'enabled': {'status': True},
-                      'deprecated': {'status': True}}
-        result = {'plugin_labels': copy.deepcopy(default)}
-        result['version_labels'] = {
-            '1.1.0': copy.deepcopy(default),
-            '1.0.1': copy.deepcopy(default),
-            '0.9.2': copy.deepcopy(deprecated),
-        }
-        return result
-
     def get_versions(self):
-        return ['0.9.2', '1.0.1', '1.1.0']
+        return ['0.9.2']
 
     def get_configs(self, storm_version):
         return c_helper.get_plugin_configs()
@@ -77,13 +64,9 @@ class StormProvider(p.ProvisioningPluginBase):
         sm_count = sum([ng.count for ng
                         in utils.get_node_groups(cluster, "nimbus")])
 
-        if sm_count < 1:
+        if sm_count != 1:
             raise ex.RequiredServiceMissingException("Storm nimbus")
 
-        if sm_count >= 2:
-            raise ex.InvalidComponentCountException("Storm nimbus", "1",
-                                                    sm_count)
-
         sl_count = sum([ng.count for ng
                         in utils.get_node_groups(cluster, "supervisor")])
 
@@ -101,10 +84,10 @@ class StormProvider(p.ProvisioningPluginBase):
     def start_cluster(self, cluster):
         sm_instance = utils.get_instance(cluster, "nimbus")
         sl_instances = utils.get_instances(cluster, "supervisor")
-        zk_instances = utils.get_instances(cluster, "zookeeper")
+        zk_instance = utils.get_instances(cluster, "zookeeper")
 
-        # start zookeeper processes
-        self._start_zookeeper_processes(zk_instances)
+        if zk_instance:
+            self._start_zookeeper_processes(zk_instance)
 
         # start storm master
         if sm_instance:
@@ -113,46 +96,10 @@ class StormProvider(p.ProvisioningPluginBase):
         # start storm slaves
         self._start_slave_processes(sl_instances)
 
-        LOG.info("Cluster {cluster} has been started successfully".format(
-            cluster=cluster.name))
+        LOG.info(_LI('Cluster {cluster} has been started successfully').format(
+                 cluster=cluster.name))
         self._set_cluster_info(cluster)
 
-    def get_edp_engine(self, cluster, job_type):
-        if job_type in edp_engine.EdpStormEngine.get_supported_job_types():
-            return edp_engine.EdpStormEngine(cluster)
-        if job_type in edp_engine.EdpPyleusEngine.get_supported_job_types():
-            return edp_engine.EdpPyleusEngine(cluster)
-        return None
-
-    def get_edp_job_types(self, versions=None):
-        res = {}
-        for vers in self.get_versions():
-            if not versions or vers in versions:
-                storm_engine = edp_engine.EdpStormEngine
-                pyleus_engine = edp_engine.EdpPyleusEngine
-                res[vers] = (storm_engine.get_supported_job_types() +
-                             pyleus_engine.get_supported_job_types())
-        return res
-
-    def get_edp_config_hints(self, job_type, version):
-        if edp_engine.EdpStormEngine.edp_supported(version):
-            return edp_engine.EdpStormEngine.get_possible_job_config(job_type)
-        if edp_engine.EdpPyleusEngine.edp_supported(version):
-            return edp_engine.EdpPyleusEngine.get_possible_job_config(job_type)
-        return {}
-
-    def get_open_ports(self, node_group):
-        ports_map = {
-            'nimbus': [8080]
-        }
-
-        ports = []
-        for process in node_group.node_processes:
-            if process in ports_map:
-                ports.extend(ports_map[process])
-
-        return ports
-
     def _extract_configs_to_extra(self, cluster):
         st_master = utils.get_instance(cluster, "nimbus")
         zk_servers = utils.get_instances(cluster, "zookeeper")
@@ -168,22 +115,19 @@ class StormProvider(p.ProvisioningPluginBase):
 
             config_instances = c_helper.generate_storm_config(
                 st_master.hostname(),
-                zknames,
-                cluster.hadoop_version)
+                zknames)
 
         config = self._convert_dict_to_yaml(config_instances)
         supervisor_conf = c_helper.generate_slave_supervisor_conf()
         nimbus_ui_conf = c_helper.generate_master_supervisor_conf()
         zk_conf = c_helper.generate_zookeeper_conf()
-        pyleus_conf = c_helper.generate_pyleus_config()
 
         for ng in cluster.node_groups:
             extra[ng.id] = {
                 'st_instances': config,
                 'slave_sv_conf': supervisor_conf,
                 'master_sv_conf': nimbus_ui_conf,
-                'zk_conf': zk_conf,
-                'pyleus_conf': pyleus_conf
+                'zk_conf': zk_conf
             }
 
         return extra
@@ -193,8 +137,8 @@ class StormProvider(p.ProvisioningPluginBase):
     def _start_storm_master(self, sm_instance):
         with remote.get_remote(sm_instance) as r:
             run.start_storm_nimbus_and_ui(r)
-            LOG.info("Storm master at {host} has been started".format(
-                host=sm_instance.hostname()))
+            LOG.info(_LI("Storm master at {host} has been started").format(
+                     host=sm_instance.hostname()))
 
     def _start_slave_processes(self, sl_instances):
         if len(sl_instances) == 0:
@@ -282,9 +226,6 @@ class StormProvider(p.ProvisioningPluginBase):
         files_supervisor_master = {
             '/etc/supervisor/supervisord.conf': ng_extra['master_sv_conf']
         }
-        file_pyleus_conf = {
-            '/home/ubuntu/.pyleus.conf': ng_extra['pyleus_conf']
-        }
 
         with remote.get_remote(instance) as r:
             node_processes = instance.node_group.node_processes
@@ -293,7 +234,6 @@ class StormProvider(p.ProvisioningPluginBase):
                 self._push_zk_configs(r, files_zk)
             if 'nimbus' in node_processes:
                 self._push_supervisor_configs(r, files_supervisor_master)
-                self._push_supervisor_configs(r, file_pyleus_conf)
             if 'supervisor' in node_processes:
                 self._push_supervisor_configs(r, files_supervisor)
 
@@ -313,7 +253,7 @@ class StormProvider(p.ProvisioningPluginBase):
             r.write_files_to(files_storm)
 
         if need_zookeeper_update:
-            zk_path = '/opt/zookeeper/zookeeper/conf/zoo.cfg'
+            zk_path = '/opt/zookeeper/zookeeper-3.4.6/conf/zoo.cfg'
             files_zookeeper = {zk_path: ng_extra['zk_conf']}
             self._push_zk_configs(r, files_zookeeper)
 
@@ -325,8 +265,7 @@ class StormProvider(p.ProvisioningPluginBase):
             port = "8080"
 
             info['Strom'] = {
-                'Web UI': 'http://%s:%s' % (
-                    st_master.get_ip_or_dns_name(), port)
+                'Web UI': 'http://%s:%s' % (st_master.management_ip, port)
             }
         ctx = context.ctx()
         conductor.cluster_update(ctx, cluster, {'info': info})
@@ -336,75 +275,3 @@ class StormProvider(p.ProvisioningPluginBase):
 
     def _push_supervisor_configs(self, r, files):
         r.append_to_files(files, run_as_root=True)
-
-    # Scaling
-
-    def _get_running_topologies_names(self, cluster):
-        master = utils.get_instance(cluster, "nimbus")
-
-        cmd = (
-            "%(storm)s -c nimbus.host=%(host)s "
-            "list | grep ACTIVE | awk '{print $1}'") % (
-            {
-                "storm": "/usr/local/storm/bin/storm",
-                "host": master.hostname()
-            })
-
-        with remote.get_remote(master) as r:
-            ret, stdout = r.execute_command(cmd)
-        names = stdout.split('\n')
-        topology_names = names[0:len(names)-1]
-        return topology_names
-
-    @cpo.event_wrapper(True, step=_("Rebalance Topology"),
-                       param=('cluster', 1))
-    def rebalance_topology(self, cluster):
-        topology_names = self._get_running_topologies_names(cluster)
-        master = utils.get_instance(cluster, "nimbus")
-
-        for topology_name in topology_names:
-            cmd = (
-                '%(rebalance)s -c nimbus.host=%(host)s %(topology_name)s') % (
-                {
-                    "rebalance": "/usr/local/storm/bin/storm rebalance",
-                    "host": master.hostname(),
-                    "topology_name": topology_name
-                })
-
-            with remote.get_remote(master) as r:
-                ret, stdout = r.execute_command(cmd)
-
-    def validate_scaling(self, cluster, existing, additional):
-        self._validate_existing_ng_scaling(cluster, existing)
-        self._validate_additional_ng_scaling(cluster, additional)
-
-    def scale_cluster(self, cluster, instances):
-        self._setup_instances(cluster, instances)
-        # start storm slaves
-        self._start_slave_processes(instances)
-        self.rebalance_topology(cluster)
-        LOG.info("Storm scaling has been started.")
-
-    def _get_scalable_processes(self):
-        return ["supervisor"]
-
-    def _validate_additional_ng_scaling(self, cluster, additional):
-        scalable_processes = self._get_scalable_processes()
-
-        for ng_id in additional:
-            ng = ug.get_by_id(cluster.node_groups, ng_id)
-            if not set(ng.node_processes).issubset(scalable_processes):
-                raise ex.NodeGroupCannotBeScaled(
-                    ng.name, _("Storm plugin cannot scale nodegroup"
-                               " with processes: %s") %
-                    ' '.join(ng.node_processes))
-
-    def _validate_existing_ng_scaling(self, cluster, existing):
-        scalable_processes = self._get_scalable_processes()
-        for ng in cluster.node_groups:
-            if ng.id in existing:
-                if not set(ng.node_processes).issubset(scalable_processes):
-                    raise ex.NodeGroupCannotBeScaled(
-                        ng.name, _("Storm plugin cannot scale nodegroup"
-                                   " with processes: %s") %
-                        ' '.join(ng.node_processes))
