@@ -13,28 +13,39 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from oslo_config import cfg
+from oslo_log import log as logging
 import six
 
-from sahara.i18n import _LI
-from sahara.openstack.common import log as logging
+from sahara.i18n import _
+from sahara.i18n import _LW
 from sahara.plugins.vanilla.hadoop2 import config_helper as c_helper
 from sahara.plugins.vanilla.hadoop2 import oozie_helper as o_helper
 from sahara.plugins.vanilla import utils as vu
 from sahara.swift import swift_helper as swift
 from sahara.topology import topology_helper as th
+from sahara.utils import cluster_progress_ops as cpo
 from sahara.utils import files as f
+from sahara.utils import proxy
 from sahara.utils import xmlutils as x
 
+CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
 
 HADOOP_CONF_DIR = '/opt/hadoop/etc/hadoop'
 OOZIE_CONF_DIR = '/opt/oozie/conf'
+HIVE_CONF_DIR = '/opt/hive/conf'
 HADOOP_USER = 'hadoop'
 HADOOP_GROUP = 'hadoop'
 
 
 def configure_cluster(pctx, cluster):
-    LOG.debug("Configuring cluster \"%s\"", cluster.name)
+    LOG.debug("Configuring cluster {cluster}".format(cluster=cluster.name))
+    if (CONF.use_identity_api_v3 and CONF.use_domain_for_proxy_users and
+            vu.get_hiveserver(cluster) and
+            c_helper.is_swift_enabled(pctx, cluster)):
+        cluster = proxy.create_proxy_user_for_cluster(cluster)
+
     instances = []
     for node_group in cluster.node_groups:
         for instance in node_group.instances:
@@ -45,9 +56,20 @@ def configure_cluster(pctx, cluster):
 
 
 def configure_instances(pctx, instances):
+    if len(instances) == 0:
+        return
+
+    cpo.add_provisioning_step(
+        instances[0].cluster_id, _("Configure instances"), len(instances))
+
     for instance in instances:
-        _provisioning_configs(pctx, instance)
-        _post_configuration(pctx, instance)
+        _configure_instance(pctx, instance)
+
+
+@cpo.event_wrapper(True)
+def _configure_instance(pctx, instance):
+    _provisioning_configs(pctx, instance)
+    _post_configuration(pctx, instance)
 
 
 def _provisioning_configs(pctx, instance):
@@ -75,7 +97,7 @@ def _get_hadoop_configs(pctx, node_group):
         },
         'HDFS': {
             'dfs.namenode.name.dir': ','.join(dirs['hadoop_name_dirs']),
-            'dfs.datanode.data.dir': ','.join(dirs['hadoop_data_dirs']),
+            'dfs.namenode.data.dir': ','.join(dirs['hadoop_data_dirs']),
             'dfs.hosts': '%s/dn-include' % HADOOP_CONF_DIR,
             'dfs.hosts.exclude': '%s/dn-exclude' % HADOOP_CONF_DIR
         }
@@ -125,6 +147,38 @@ def _get_hadoop_configs(pctx, node_group):
         confs['Hadoop'].update({"topology.script.file.name":
                                 HADOOP_CONF_DIR + "/topology.sh"})
 
+    hive_hostname = vu.get_instance_hostname(vu.get_hiveserver(cluster))
+    if hive_hostname:
+        hive_cfg = {
+            'hive.warehouse.subdir.inherit.perms': True,
+            'javax.jdo.option.ConnectionURL':
+            'jdbc:derby:;databaseName=/opt/hive/metastore_db;create=true'
+        }
+
+        if c_helper.is_mysql_enabled(pctx, cluster):
+            hive_cfg.update({
+                'javax.jdo.option.ConnectionURL':
+                'jdbc:mysql://%s/metastore' % hive_hostname,
+                'javax.jdo.option.ConnectionDriverName':
+                'com.mysql.jdbc.Driver',
+                'javax.jdo.option.ConnectionUserName': 'hive',
+                'javax.jdo.option.ConnectionPassword': 'pass',
+                'datanucleus.autoCreateSchema': 'false',
+                'datanucleus.fixedDatastore': 'true',
+                'hive.metastore.uris': 'thrift://%s:9083' % hive_hostname,
+            })
+
+        proxy_configs = cluster.cluster_configs.get('proxy_configs')
+        if proxy_configs and c_helper.is_swift_enabled(pctx, cluster):
+            hive_cfg.update({
+                swift.HADOOP_SWIFT_USERNAME: proxy_configs['proxy_username'],
+                swift.HADOOP_SWIFT_PASSWORD: proxy_configs['proxy_password'],
+                swift.HADOOP_SWIFT_TRUST_ID: proxy_configs['proxy_trust_id'],
+                swift.HADOOP_SWIFT_DOMAIN_NAME: CONF.proxy_user_domain_name
+            })
+
+        confs['Hive'] = hive_cfg
+
     return confs
 
 
@@ -143,8 +197,6 @@ def _separate_configs(configs, all_env_configs):
     xml_configs = {}
     env_configs = {}
     for service, params in six.iteritems(configs):
-        xml_configs[service] = {}
-        env_configs[service] = {}
         for param, value in six.iteritems(params):
             if all_env_configs.get(service, {}).get(param):
                 if not env_configs.get(service):
@@ -208,7 +260,8 @@ def _push_xml_configs(instance, configs):
         'HDFS': '%s/hdfs-site.xml' % HADOOP_CONF_DIR,
         'YARN': '%s/yarn-site.xml' % HADOOP_CONF_DIR,
         'MapReduce': '%s/mapred-site.xml' % HADOOP_CONF_DIR,
-        'JobFlow': '%s/oozie-site.xml' % OOZIE_CONF_DIR
+        'JobFlow': '%s/oozie-site.xml' % OOZIE_CONF_DIR,
+        'Hive': '%s/hive-site.xml' % HIVE_CONF_DIR
     }
     xml_confs = {}
     for service, confs in six.iteritems(xmls):
@@ -221,7 +274,8 @@ def _push_xml_configs(instance, configs):
 
 
 def _push_configs_to_instance(instance, configs):
-    LOG.debug("Push configs to instance \"%s\"", instance.instance_name)
+    LOG.debug("Push configs to instance {instance}".format(
+        instance=instance.instance_name))
     with instance.remote() as r:
         for fl, data in six.iteritems(configs):
             r.write_file_to(fl, data, run_as_root=True)
@@ -251,7 +305,7 @@ def _post_configuration(pctx, instance):
         r.execute_command('sudo /tmp/post_conf.sh')
 
         if c_helper.is_data_locality_enabled(pctx,
-                                             instance.node_group.cluster):
+                                             instance.cluster):
             t_script = HADOOP_CONF_DIR + '/topology.sh'
             r.write_file_to(t_script, f.get_file_text(
                             'plugins/vanilla/hadoop2/resources/topology.sh'),
@@ -295,10 +349,13 @@ def _merge_configs(a, b):
     return res
 
 
+@cpo.event_wrapper(
+    True, step=_("Configure topology data"), param=('cluster', 1))
 def configure_topology_data(pctx, cluster):
     if c_helper.is_data_locality_enabled(pctx, cluster):
-        LOG.info(_LI("Node group awareness is not implemented in YARN yet "
-                     "so enable_hypervisor_awareness set to False explicitly"))
+        LOG.warning(_LW("Node group awareness is not implemented in YARN yet "
+                        "so enable_hypervisor_awareness set to False "
+                        "explicitly"))
         tpl_map = th.generate_topology_map(cluster, is_node_awareness=False)
         topology_data = "\n".join(
             [k + " " + v for k, v in tpl_map.items()]) + "\n"
@@ -336,4 +393,8 @@ def get_open_ports(node_group):
     if "oozie" in node_group.node_processes:
         ports.append(11000)
 
+    if "hiveserver" in node_group.node_processes:
+        ports.append(9999)
+        ports.append(10000)
+
     return ports
