@@ -13,17 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-
-from oslo_utils import uuidutils
-
 from sahara.plugins import utils as u
-from sahara.service.castellan import utils as castellan
 
 
 def get_namenode(cluster):
     return u.get_instance(cluster, "namenode")
 
 
+def get_jobtracker(cluster):
+    instance = u.get_instance(cluster, "jobtracker")
+
+    return instance
+
+
 def get_resourcemanager(cluster):
     return u.get_instance(cluster, 'resourcemanager')
 
@@ -36,10 +38,6 @@ def get_oozie(cluster):
     return u.get_instance(cluster, "oozie")
 
 
-def get_spark_history_server(cluster):
-    return u.get_instance(cluster, "spark history server")
-
-
 def get_hiveserver(cluster):
     return u.get_instance(cluster, "hiveserver")
 
@@ -48,8 +46,12 @@ def get_datanodes(cluster):
     return u.get_instances(cluster, 'datanode')
 
 
-def get_secondarynamenode(cluster):
-    return u.get_instance(cluster, 'secondarynamenode')
+def get_tasktrackers(cluster):
+    return u.get_instances(cluster, 'tasktracker')
+
+
+def get_secondarynamenodes(cluster):
+    return u.get_instances(cluster, 'secondarynamenode')
 
 
 def get_historyserver(cluster):
@@ -58,12 +60,3 @@ def get_historyserver(cluster):
 
 def get_instance_hostname(instance):
     return instance.hostname() if instance else None
-
-
-def get_zk_servers(cluster):
-    return u.get_instances(cluster, 'zookeeper')
-
-
-def generate_random_password():
-    password = uuidutils.generate_uuid()
-    return castellan.store_secret(password)
