@@ -13,17 +13,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from oslo.config import cfg
+from oslo_config import cfg
+from oslo_log import log as logging
 
 from sahara import conductor as c
 from sahara import context
 from sahara import exceptions as ex
 from sahara.i18n import _
-from sahara.i18n import _LI
 from sahara.i18n import _LW
-from sahara.openstack.common import log as logging
-from sahara.plugins.general import utils
 from sahara.plugins import provisioning as p
+from sahara.plugins import utils
 from sahara.plugins.vanilla import utils as vu
 from sahara.plugins.vanilla.v1_2_1 import mysql_helper as m_h
 from sahara.plugins.vanilla.v1_2_1 import oozie_helper as o_h
@@ -98,6 +97,11 @@ DECOMMISSIONING_TIMEOUT = p.Config('Decommissioning Timeout', 'general',
                                                ' decommissioning operation'
                                                ' during scaling, in seconds')
 
+DATANODES_STARTUP_TIMEOUT = p.Config(
+    'Datanodes startup timeout', 'general', 'cluster', config_type='int',
+    priority=1, default_value=10800, is_optional=True,
+    description='Timeout for datanodes startup, in seconds')
+
 
 HIDDEN_CONFS = ['fs.default.name', 'dfs.name.dir', 'dfs.data.dir',
                 'mapred.job.tracker', 'mapred.system.dir', 'mapred.local.dir',
@@ -160,6 +164,7 @@ def _initialise_configs():
     configs.append(ENABLE_SWIFT)
     configs.append(ENABLE_MYSQL)
     configs.append(DECOMMISSIONING_TIMEOUT)
+    configs.append(DATANODES_STARTUP_TIMEOUT)
     if CONF.enable_data_locality:
         configs.append(ENABLE_DATA_LOCALITY)
 
@@ -224,7 +229,7 @@ def generate_cfg_from_general(cfg, configs, general_config,
         for name, value in configs['general'].items():
             if value:
                 cfg = _set_config(cfg, general_config, name)
-                LOG.info(_LI("Applying config: %s"), name)
+                LOG.debug("Applying config: {config}".format(config=name))
     else:
         cfg = _set_config(cfg, general_config)
     return cfg
@@ -334,18 +339,47 @@ def generate_xml_configs(cluster, node_group, hive_mysql_passwd):
     }
 
     if hive_hostname:
+        cfg = all_cfg
+        cfg_filter = HIVE_DEFAULT
+        proxy_configs = cluster.cluster_configs.get('proxy_configs')
+        if CONF.use_identity_api_v3 and proxy_configs:
+            cfg, cfg_filter = _inject_swift_trust_info(cfg,
+                                                       cfg_filter,
+                                                       proxy_configs)
         xml_configs.update({'hive-site':
-                            x.create_hadoop_xml(all_cfg, HIVE_DEFAULT)})
-        LOG.debug('Generated hive-site.xml for hive % s', hive_hostname)
+                            x.create_hadoop_xml(cfg, cfg_filter)})
+        LOG.debug('Generated hive-site.xml for hive {host}'.format(
+            host=hive_hostname))
 
     if oozie_hostname:
         xml_configs.update({'oozie-site':
                             x.create_hadoop_xml(all_cfg, o_h.OOZIE_DEFAULT)})
-        LOG.debug('Generated oozie-site.xml for oozie % s', oozie_hostname)
+        LOG.debug('Generated oozie-site.xml for oozie {host}'.format(
+            host=oozie_hostname))
 
     return xml_configs
 
 
+def _inject_swift_trust_info(cfg, cfg_filter, proxy_configs):
+    cfg = cfg.copy()
+    cfg.update({
+        swift.HADOOP_SWIFT_USERNAME: proxy_configs['proxy_username'],
+        swift.HADOOP_SWIFT_PASSWORD: proxy_configs['proxy_password'],
+        swift.HADOOP_SWIFT_TRUST_ID: proxy_configs['proxy_trust_id'],
+        swift.HADOOP_SWIFT_DOMAIN_NAME: CONF.proxy_user_domain_name
+    })
+
+    allow_swift_auth_filter = [
+        {'name': swift.HADOOP_SWIFT_USERNAME},
+        {'name': swift.HADOOP_SWIFT_PASSWORD},
+        {'name': swift.HADOOP_SWIFT_TRUST_ID},
+        {'name': swift.HADOOP_SWIFT_DOMAIN_NAME}
+    ]
+    cfg_filter = cfg_filter + allow_swift_auth_filter
+
+    return cfg, cfg_filter
+
+
 def extract_environment_confs(configs):
     """Returns environment specific Hadoop configurations.
 
@@ -360,8 +394,9 @@ def extract_environment_confs(configs):
                     if param_name == cfg_name and param_value is not None:
                         lst.append(cfg_format_str % param_value)
         else:
-            LOG.warn(_LW("Plugin received wrong applicable target '%s' in "
-                     "environmental configs"), service)
+            LOG.warning(_LW("Plugin received wrong applicable target {service}"
+                            " in environmental configs").format(
+                                service=service))
     return sorted(lst)
 
 
@@ -381,8 +416,8 @@ def extract_xml_confs(configs):
                     if param_name in names and param_value is not None:
                         lst.append((param_name, param_value))
         else:
-            LOG.warn(_LW("Plugin received wrong applicable target '%s' for "
-                     "xml configs"), service)
+            LOG.warning(_LW("Plugin received wrong applicable target {service}"
+                            " for xml configs").format(service=service))
     return sorted(lst)
 
 
@@ -415,7 +450,7 @@ def generate_setup_script(storage_paths, env_configs, append_oozie=False):
 
 
 def extract_name_values(configs):
-    return dict((cfg['name'], cfg['value']) for cfg in configs)
+    return {cfg['name']: cfg['value'] for cfg in configs}
 
 
 def extract_hadoop_path(lst, hadoop_dir):
@@ -451,6 +486,10 @@ def is_data_locality_enabled(cluster):
     return _get_general_cluster_config_value(cluster, ENABLE_DATA_LOCALITY)
 
 
+def is_swift_enable(cluster):
+    return _get_general_cluster_config_value(cluster, ENABLE_SWIFT)
+
+
 def get_decommissioning_timeout(cluster):
     return _get_general_cluster_config_value(cluster, DECOMMISSIONING_TIMEOUT)
 
