@@ -46,8 +46,8 @@ class OozieWorkflowCreator(object):
     def _add_to_prepare_element(self, element, paths):
         if element not in ['delete', 'mkdir']:
             raise ex.NotFoundException(element,
-                                       _('"%s" child cannot be '
-                                         'added to prepare element'))
+                                       message=_('"%s" child cannot be '
+                                                 'added to prepare element'))
         prop = x.get_and_create_if_not_exist(self.doc, self.tag_name,
                                              'prepare')
         for path in paths:
@@ -57,8 +57,8 @@ class OozieWorkflowCreator(object):
     def _add_to_streaming_element(self, element, path):
         if element not in ['mapper', 'reducer']:
             raise ex.NotFoundException(element,
-                                       _('"%s" child cannot be added '
-                                         'to streaming element'))
+                                       message=_('"%s" child cannot be added '
+                                                 'to streaming element'))
 
         x.get_and_create_if_not_exist(self.doc, self.tag_name,
                                       'streaming')
