@@ -18,26 +18,27 @@ import abc
 import datetime
 import string
 
+from oslo_log import log as logging
 import six
 
 from sahara import conductor as c
 from sahara import context
+from sahara.i18n import _
 from sahara.i18n import _LI
-from sahara.i18n import _LW
-from sahara.openstack.common import log as logging
 from sahara.service import networks
+from sahara.utils import cluster_progress_ops as cpo
 from sahara.utils import edp
 from sahara.utils import general as g
 from sahara.utils.openstack import nova
+from sahara.utils import poll_utils
 from sahara.utils import remote
 
-
 LOG = logging.getLogger(__name__)
 conductor = c.API
 
 
 @six.add_metaclass(abc.ABCMeta)
-class Engine:
+class Engine(object):
     @abc.abstractmethod
     def create_cluster(self, cluster):
         pass
@@ -65,54 +66,73 @@ class Engine:
         image_id = node_group.get_image_id()
         return nova.client().images.get(image_id).username
 
+    @poll_utils.poll_status('ips_assign_timeout', _("Assign IPs"), sleep=1)
+    def _ips_assign(self, ips_assigned, cluster, instances):
+        if not g.check_cluster_exists(cluster):
+            return True
+        for instance in instances:
+            if instance.id not in ips_assigned:
+                if networks.init_instances_ips(instance):
+                    ips_assigned.add(instance.id)
+                    cpo.add_successful_event(instance)
+        return len(ips_assigned) == len(instances)
+
     def _await_networks(self, cluster, instances):
         if not instances:
             return
 
-        ips_assigned = set()
-        while len(ips_assigned) != len(instances):
-            if not g.check_cluster_exists(cluster):
-                return
-            for instance in instances:
-                if instance.id not in ips_assigned:
-                    if networks.init_instances_ips(instance):
-                        ips_assigned.add(instance.id)
+        cpo.add_provisioning_step(cluster.id, _("Assign IPs"), len(instances))
 
-            context.sleep(1)
+        ips_assigned = set()
+        self._ips_assign(ips_assigned, cluster, instances)
 
         LOG.info(
-            _LI("Cluster '%s': all instances have IPs assigned"), cluster.id)
+            _LI("Cluster {cluster_id}: all instances have IPs assigned")
+            .format(cluster_id=cluster.id))
 
         cluster = conductor.cluster_get(context.ctx(), cluster)
         instances = g.get_instances(cluster, ips_assigned)
 
+        cpo.add_provisioning_step(
+            cluster.id, _("Wait for instance accessibility"), len(instances))
+
         with context.ThreadGroup() as tg:
             for instance in instances:
                 tg.spawn("wait-for-ssh-%s" % instance.instance_name,
                          self._wait_until_accessible, instance)
 
-        LOG.info(_LI("Cluster '%s': all instances are accessible"), cluster.id)
+        LOG.info(_LI("Cluster {cluster_id}: all instances are accessible")
+                 .format(cluster_id=cluster.id))
 
+    @poll_utils.poll_status(
+        'wait_until_accessible', _("Wait for instance accessibility"),
+        sleep=5)
+    def _is_accessible(self, instance):
+        if not g.check_cluster_exists(instance.cluster):
+            return True
+        try:
+            # check if ssh is accessible and cloud-init
+            # script is finished generating authorized_keys
+            exit_code, stdout = instance.remote().execute_command(
+                "ls .ssh/authorized_keys", raise_when_error=False)
+
+            if exit_code == 0:
+                LOG.debug(
+                    'Instance {instance_name} is accessible'.format(
+                        instance_name=instance.instance_name))
+                return True
+        except Exception as ex:
+            LOG.debug("Can't login to node {instance_name} {mgmt_ip}, "
+                      "reason {reason}".format(
+                          instance_name=instance.instance_name,
+                          mgmt_ip=instance.management_ip, reason=ex))
+            return False
+
+        return False
+
+    @cpo.event_wrapper(mark_successful_on_exit=True)
     def _wait_until_accessible(self, instance):
-        while True:
-            try:
-                # check if ssh is accessible and cloud-init
-                # script is finished generating authorized_keys
-                exit_code, stdout = instance.remote().execute_command(
-                    "ls .ssh/authorized_keys", raise_when_error=False)
-
-                if exit_code == 0:
-                    LOG.debug(
-                        'Instance %s is accessible' % instance.instance_name)
-                    return
-            except Exception as ex:
-                LOG.debug("Can't login to node %s (%s), reason %s",
-                          instance.instance_name, instance.management_ip, ex)
-
-            context.sleep(5)
-
-            if not g.check_cluster_exists(instance.node_group.cluster):
-                return
+        self._is_accessible(instance)
 
     def _configure_instances(self, cluster):
         """Configure active instances.
@@ -122,6 +142,8 @@ class Engine:
         * etc.
         """
         hosts_file = g.generate_etc_hosts(cluster)
+        cpo.add_provisioning_step(
+            cluster.id, _("Configure instances"), g.count_instances(cluster))
 
         with context.ThreadGroup() as tg:
             for node_group in cluster.node_groups:
@@ -129,8 +151,10 @@ class Engine:
                     tg.spawn("configure-instance-%s" % instance.instance_name,
                              self._configure_instance, instance, hosts_file)
 
+    @cpo.event_wrapper(mark_successful_on_exit=True)
     def _configure_instance(self, instance, hosts_file):
-        LOG.debug('Configuring instance %s' % instance.instance_name)
+        LOG.debug('Configuring instance {instance_name}'.format(
+            instance_name=instance.instance_name))
 
         with instance.remote() as r:
             r.write_file_to('etc-hosts', hosts_file)
@@ -142,6 +166,8 @@ class Engine:
     def _generate_user_data_script(self, node_group, instance_name):
         script = """#!/bin/bash
 echo "${public_key}" >> ${user_home}/.ssh/authorized_keys\n
+# ====== COMMENT OUT Defaults requiretty in /etc/sudoers ========
+sed '/^Defaults    requiretty*/ s/^/#/' -i /etc/sudoers\n
 """
 
         script += remote.get_userdata_template()
@@ -170,12 +196,3 @@ echo "${public_key}" >> ${user_home}/.ssh/authorized_keys\n
                 update.update({"info": info,
                                "end_time": datetime.datetime.now()})
             conductor.job_execution_update(ctx, je, update)
-
-    def _log_operation_exception(self, message, cluster, ex):
-        # we want to log the initial exception even if cluster was deleted
-        cluster_name = cluster.name if cluster is not None else '_unknown_'
-        LOG.warn(message, {'cluster': cluster_name, 'reason': ex})
-        if cluster is None:
-            LOG.warn(
-                _LW("Presumably the operation failed because the cluster was "
-                    "deleted by a user during the process."))
