@@ -13,14 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import re
-
 from oslo_config import cfg
-from oslo_utils import uuidutils
 import six.moves.urllib.parse as urlparse
 
-from sahara import conductor as c
-from sahara import context
 import sahara.exceptions as ex
 from sahara.i18n import _
 import sahara.service.validations.edp.base as b
@@ -28,48 +23,47 @@ from sahara.swift import utils as su
 
 CONF = cfg.CONF
 
+DATA_SOURCE_SCHEMA = {
+    "type": "object",
+    "properties": {
+        "name": {
+            "type": "string",
+            "minLength": 1,
+            "maxLength": 50,
+            "format": "valid_name"
+        },
+        "description": {
+            "type": "string"
+        },
+        "type": b.data_source_type,
+        "url": {
+            "type": "string",
+        },
+        "credentials": {
+            "type": "object"
+        }
+    },
+    "additionalProperties": False,
+    "required": [
+        "name",
+        "type",
+        "url"
+    ]
+}
+
 
 def check_data_source_create(data, **kwargs):
     b.check_data_source_unique_name(data['name'])
-    _check_data_source_url(data)
-
-
-def _check_datasource_placeholder(url):
-    if url is None:
-        return
-    total_length = 0
-    substrings = re.findall(r"%RANDSTR\(([\-]?\d+)\)%", url)
-    for length in map(int, substrings):
-        if length <= 0:
-            total_length = -1
-            break
-        total_length += length
-
-    if total_length > 1024:
-        raise ex.InvalidDataException(_("Requested RANDSTR length is"
-                                        " too long, please choose a "
-                                        "value less than 1024."))
-
-    if total_length < 0:
-        raise ex.InvalidDataException(_("Requested RANDSTR length"
-                                        " must be positive."))
-
-
-def _check_data_source_url(data):
-    _check_datasource_placeholder(data["url"])
 
     if "swift" == data["type"]:
         _check_swift_data_source_create(data)
 
-    elif "hdfs" == data["type"]:
+    if "hdfs" == data["type"]:
         _check_hdfs_data_source_create(data)
 
-    elif "maprfs" == data["type"]:
+    if "maprfs" == data["type"]:
         _check_maprfs_data_source_create(data)
 
-    elif "manila" == data["type"]:
-        _check_manila_data_source_create(data)
-
 
 def _check_swift_data_source_create(data):
     if len(data['url']) == 0:
@@ -119,36 +113,3 @@ def _check_maprfs_data_source_create(data):
     if url.scheme:
         if url.scheme != "maprfs":
             raise ex.InvalidDataException(_("URL scheme must be 'maprfs'"))
-
-
-def _check_manila_data_source_create(data):
-    if len(data['url']) == 0:
-        raise ex.InvalidDataException(_("Manila url must not be empty"))
-    url = urlparse.urlparse(data['url'])
-    if url.scheme != "manila":
-        raise ex.InvalidDataException(_("Manila url scheme must be 'manila'"))
-    if not uuidutils.is_uuid_like(url.netloc):
-        raise ex.InvalidDataException(_("Manila url netloc must be a uuid"))
-    if not url.path:
-        raise ex.InvalidDataException(_("Manila url path must not be empty"))
-
-
-def check_data_source_update(data, data_source_id):
-    ctx = context.ctx()
-    jobs = c.API.job_execution_get_all(ctx)
-    pending_jobs = [job for job in jobs if job.info["status"] == "PENDING"]
-    for job in pending_jobs:
-        if data_source_id in job.data_source_urls:
-            raise ex.UpdateFailedException(
-                _("DataSource is used in a "
-                  "PENDING Job and can not be updated."))
-
-    ds = c.API.data_source_get(ctx, data_source_id)
-    if 'name' in data and data['name'] != ds.name:
-        b.check_data_source_unique_name(data['name'])
-
-    check_data = {'type': data.get('type', None) or ds.type,
-                  'url': data.get('url', None) or ds.url,
-                  'credentials': data.get(
-                      'credentials', None) or ds.credentials}
-    _check_data_source_url(check_data)
