@@ -15,15 +15,19 @@
 
 import uuid
 
-from sahara.openstack.common import excutils
+from oslo_utils import excutils
+
 from sahara.tests.integration.tests import base
 
 
 class SwiftTest(base.ITestCase):
+    DEFAULT_TEST_SCRIPT = 'swift_test_script.sh'
+
     @base.skip_test(
         'SKIP_SWIFT_TEST',
         message='Test for check of Swift availability was skipped.')
-    def check_swift_availability(self, cluster_info):
+    def check_swift_availability(self, cluster_info, script=None):
+        script = script or SwiftTest.DEFAULT_TEST_SCRIPT
         plugin_config = cluster_info['plugin_config']
         # Make unique name of Swift container during Swift testing
         swift_container_name = 'Swift-test-' + str(uuid.uuid4())[:8]
@@ -35,10 +39,10 @@ class SwiftTest(base.ITestCase):
             'SWIFT_CONTAINER_NAME': swift_container_name
         }
         namenode_ip = cluster_info['node_info']['namenode_ip']
-        self.open_ssh_connection(namenode_ip, plugin_config.SSH_USERNAME)
+        self.open_ssh_connection(namenode_ip)
         try:
             self.transfer_helper_script_to_node(
-                'swift_test_script.sh', parameter_list=extra_script_parameters
+                script, parameter_list=extra_script_parameters
             )
 
         except Exception as e:
