@@ -16,11 +16,8 @@
 import time
 
 import fixtures
-from keystoneclient.auth.identity import v3 as identity_v3
-from keystoneclient import session
 from neutronclient.neutron import client as neutron_client
 from novaclient import client as nova_client
-from novaclient import exceptions as nova_exc
 from oslo_utils import uuidutils
 from saharaclient.api import base as saharaclient_base
 from saharaclient import client as sahara_client
@@ -28,30 +25,14 @@ from swiftclient import client as swift_client
 from swiftclient import exceptions as swift_exc
 from tempest_lib import exceptions as exc
 
-from sahara.tests.scenario import utils
-
-
-def get_session(auth_url=None, username=None, password=None,
-                project_name=None, verify=True, cert=None):
-    auth = identity_v3.Password(auth_url=auth_url.replace('/v2.0', '/v3'),
-                                username=username,
-                                password=password,
-                                project_name=project_name,
-                                user_domain_name='default',
-                                project_domain_name='default')
-    return session.Session(auth=auth, verify=verify, cert=cert)
-
-from sahara.tests.scenario import timeouts
-
 
 class Client(object):
     def is_resource_deleted(self, method, *args, **kwargs):
         raise NotImplementedError
 
     def delete_resource(self, method, *args, **kwargs):
-        with fixtures.Timeout(
-                timeouts.Defaults.instance.timeout_delete_resource,
-                gentle=True):
+        # TODO(sreshetniak): make timeout configurable
+        with fixtures.Timeout(300, gentle=True):
             while True:
                 if self.is_resource_deleted(method, *args, **kwargs):
                     break
@@ -96,9 +77,6 @@ class SaharaClient(Client):
         data = self.sahara_client.data_sources.create(*args, **kwargs)
         return data.id
 
-    def get_datasource(self, *args, **kwargs):
-        return self.sahara_client.data_sources.get(*args, **kwargs)
-
     def delete_datasource(self, datasource_id):
         return self.delete_resource(
             self.sahara_client.data_sources.delete,
@@ -140,9 +118,6 @@ class SaharaClient(Client):
             self.sahara_client.job_executions.delete,
             job_execution_id)
 
-    def get_cluster(self, cluster_id, show_progress=False):
-        return self.sahara_client.clusters.get(cluster_id, show_progress)
-
     def get_cluster_status(self, cluster_id):
         data = self.sahara_client.clusters.get(cluster_id)
         return str(data.status)
@@ -173,40 +148,6 @@ class NovaClient(Client):
 
         raise exc.NotFound(image_name)
 
-    def get_flavor_id(self, flavor_name):
-        if uuidutils.is_uuid_like(flavor_name) or flavor_name.isdigit():
-            return flavor_name
-        for flavor in self.nova_client.flavors.list():
-            if flavor.name == flavor_name:
-                return flavor.id
-
-        raise exc.NotFound(flavor_name)
-
-    def create_flavor(self, flavor_object):
-        return self.nova_client.flavors.create(
-            flavor_object.get('name', utils.rand_name('scenario')),
-            flavor_object.get('ram', 1),
-            flavor_object.get('vcpus', 1),
-            flavor_object.get('root_disk', 0),
-            ephemeral=flavor_object.get('ephemeral_disk', 0),
-            swap=flavor_object.get('swap_disk', 0),
-            flavorid=flavor_object.get('id', 'auto'))
-
-    def delete_flavor(self, flavor_id):
-        return self.delete_resource(self.nova_client.flavors.delete, flavor_id)
-
-    def delete_keypair(self, key_name):
-        return self.delete_resource(
-            self.nova_client.keypairs.delete, key_name)
-
-    def is_resource_deleted(self, method, *args, **kwargs):
-        try:
-            method(*args, **kwargs)
-        except nova_exc.NotFound as ex:
-            return ex.code == 404
-
-        return False
-
 
 class NeutronClient(Client):
     def __init__(self, *args, **kwargs):
