@@ -34,8 +34,8 @@ class RunnerUnitTest(testtools.TestCase):
             "clusters": [
                 {
                     "plugin_name": "vanilla",
-                    "plugin_version": "2.7.1",
-                    "image": "sahara-vanilla-2.7.1-ubuntu-14.04"
+                    "plugin_version": "2.6.0",
+                    "image": "sahara-vanilla-2.6.0-ubuntu-14.04"
                 }],
             }
 
@@ -44,11 +44,8 @@ class RunnerUnitTest(testtools.TestCase):
                 "os_username": "admin",
                 "os_auth_url": "http://localhost:5000/v2.0",
                 "sahara_url": None,
-                "sahara_service_type": "data-processing",
                 "os_password": "nova",
-                "os_tenant": "admin",
-                "ssl_cert": None,
-                "ssl_verify": True
+                "os_tenant": "admin"
             }
         }
 
@@ -64,13 +61,13 @@ class RunnerUnitTest(testtools.TestCase):
         expected_default_cluster = {
             "clusters": [
                 {
-                    "image": "sahara-vanilla-2.7.1-ubuntu-14.04",
+                    "image": "sahara-vanilla-2.6.0-ubuntu-14.04",
                     "edp_jobs_flow": None,
-                    "class_name": "vanilla2_7_1",
+                    "class_name": "vanilla2_6_0",
                     "plugin_name": "vanilla",
                     "scenario": ['run_jobs', 'scale', 'run_jobs'],
-                    "plugin_version": "2.7.1",
-                    "retain_resources": False,
+                    "plugin_version": "2.6.0",
+                    "retain_resources": False
                 }],
         }
 
@@ -89,8 +86,7 @@ class RunnerUnitTest(testtools.TestCase):
                 "os_auth_url": "http://127.0.0.1:5000/v2.0",
                 "sahara_url": "http://127.0.0.1",
                 "os_password": "changed_nova",
-                "os_tenant": "changed_admin",
-                "ssl_cert": "/etc/tests/cert.crt"
+                "os_tenant": "changed_admin"
             },
             "network": {
                 "type": "neutron",
@@ -101,8 +97,8 @@ class RunnerUnitTest(testtools.TestCase):
             "clusters": [
                 {
                     "plugin_name": "vanilla",
-                    "plugin_version": "2.7.1",
-                    "image": "sahara-vanilla-2.7.1-ubuntu-14.04",
+                    "plugin_version": "2.6.0",
+                    "image": "sahara-vanilla-2.6.0-ubuntu-14.04",
                     "edp_jobs_flow": "test_flow",
                     "retain_resources": True
                 }],
@@ -147,10 +143,7 @@ class RunnerUnitTest(testtools.TestCase):
                 "os_auth_url": "http://127.0.0.1:5000/v2.0",
                 "sahara_url": "http://127.0.0.1",
                 "os_password": "changed_nova",
-                "os_tenant": "changed_admin",
-                "sahara_service_type": "data-processing",
-                "ssl_cert": "/etc/tests/cert.crt",
-                "ssl_verify": True
+                "os_tenant": "changed_admin"
             },
         }
 
@@ -167,8 +160,8 @@ class RunnerUnitTest(testtools.TestCase):
             "clusters": [
                 {
                     "plugin_name": "vanilla",
-                    "plugin_version": "2.7.1",
-                    "image": "sahara-vanilla-2.7.1-ubuntu-14.04",
+                    "plugin_version": "2.6.0",
+                    "image": "sahara-vanilla-2.6.0-ubuntu-14.04",
                     "retain_resources": True,
                     'edp_jobs_flow': [
                         {
@@ -202,7 +195,7 @@ class RunnerUnitTest(testtools.TestCase):
                         }
                     ],
                     "scenario": ['run_jobs', 'scale', 'run_jobs'],
-                    "class_name": "vanilla2_7_1"
+                    "class_name": "vanilla2_6_0"
                 }],
         }
 
@@ -216,42 +209,8 @@ class RunnerUnitTest(testtools.TestCase):
             expected_cluster, config))
 
     @mock.patch('sys.exit', return_value=None)
-    @mock.patch('subprocess.call', return_value=None)
-    def test_runner_main(self, mock_sub, mock_sys):
+    @mock.patch('os.system', return_value=None)
+    def test_runner_main(self, mock_os, mock_sys):
         sys.argv = ['sahara/tests/scenario/runner.py',
-                    'sahara/tests/scenario_unit/vanilla2_7_1.yaml']
-        runner.main()
-
-    @mock.patch('sys.exit', return_value=None)
-    @mock.patch('subprocess.call', return_value=None)
-    def test_runner_template_missing_varfile(self, mock_sub, mock_sys):
-        sys.argv = ['sahara/tests/scenario/runner.py',
-                    'sahara/tests/scenario_unit/vanilla2_7_1.yaml.mako']
-        self.assertRaises(NameError, runner.main)
-
-    @mock.patch('sys.exit', return_value=None)
-    @mock.patch('subprocess.call', return_value=None)
-    def test_runner_template_wrong_varfile(self, mock_sub, mock_sys):
-        sys.argv = ['sahara/tests/scenario/runner.py',
-                    '-V',
-                    'sahara/tests/scenario_unit/templatevars_nodefault.ini',
-                    'sahara/tests/scenario_unit/vanilla2_7_1.yaml.mako']
-        self.assertRaises(NameError, runner.main)
-
-    @mock.patch('sys.exit', return_value=None)
-    @mock.patch('subprocess.call', return_value=None)
-    def test_runner_template_incomplete_varfile(self, mock_sub, mock_sys):
-        sys.argv = ['sahara/tests/scenario/runner.py',
-                    '-V',
-                    'sahara/tests/scenario_unit/templatevars_incomplete.ini',
-                    'sahara/tests/scenario_unit/vanilla2_7_1.yaml.mako']
-        self.assertRaises(NameError, runner.main)
-
-    @mock.patch('sys.exit', return_value=None)
-    @mock.patch('subprocess.call', return_value=None)
-    def test_runner_template_working(self, mock_sub, mock_sys):
-        sys.argv = ['sahara/tests/scenario/runner.py',
-                    '-V',
-                    'sahara/tests/scenario_unit/templatevars_complete.ini',
-                    'sahara/tests/scenario_unit/vanilla2_7_1.yaml.mako']
+                    'sahara/tests/scenario_unit/vanilla2_6_0.yaml']
         runner.main()
