@@ -20,15 +20,13 @@ from saharaclient.api import base as sab
 from saharaclient import client as sahara_client
 from tempest import config
 from tempest import exceptions
+from tempest.scenario.data_processing import config as sahara_test_config
 from tempest.scenario import manager
 
 
+CONF = sahara_test_config.SAHARA_TEST_CONF
 TEMPEST_CONF = config.CONF
 
-# cluster status
-CLUSTER_STATUS_ACTIVE = "Active"
-CLUSTER_STATUS_ERROR = "Error"
-
 LOG = logging.getLogger(__name__)
 
 
@@ -42,23 +40,23 @@ class BaseDataProcessingTest(manager.ScenarioTest):
         catalog_type = TEMPEST_CONF.data_processing.catalog_type
         auth_url = TEMPEST_CONF.identity.uri
 
-        credentials = cls.os_primary.credentials
+        credentials = cls.credentials()
 
         cls.client = sahara_client.Client(
-            TEMPEST_CONF.data_processing.saharaclient_version,
+            CONF.data_processing.saharaclient_version,
             credentials.username,
             credentials.password,
             project_name=credentials.tenant_name,
             endpoint_type=endpoint_type,
             service_type=catalog_type,
             auth_url=auth_url,
-            sahara_url=TEMPEST_CONF.data_processing.sahara_url)
+            sahara_url=CONF.data_processing.sahara_url)
 
-        cls.object_client = cls.os_primary.object_client
-        cls.container_client = cls.os_primary.container_client
-        cls.networks_client = cls.os_primary.compute_networks_client
+        cls.object_client = cls.manager.object_client
+        cls.container_client = cls.manager.container_client
+        cls.networks_client = cls.manager.networks_client
 
-        cls.floating_ip_pool = TEMPEST_CONF.network.floating_network_name
+        cls.floating_ip_pool = CONF.data_processing.floating_ip_pool
         if TEMPEST_CONF.service_available.neutron:
             cls.floating_ip_pool = cls.get_floating_ip_pool_id_for_neutron()
 
@@ -70,7 +68,7 @@ class BaseDataProcessingTest(manager.ScenarioTest):
                 'datanode',
                 'tasktracker'
             ],
-            'flavor_id': TEMPEST_CONF.compute.flavor_ref,
+            'flavor_id': CONF.data_processing.flavor_id,
             'floating_ip_pool': cls.floating_ip_pool
         }
 
@@ -82,7 +80,7 @@ class BaseDataProcessingTest(manager.ScenarioTest):
                 'namenode',
                 'jobtracker'
             ],
-            'flavor_id': TEMPEST_CONF.compute.flavor_ref,
+            'flavor_id': CONF.data_processing.flavor_id,
             'floating_ip_pool': cls.floating_ip_pool,
             'auto_security_group': True
         }
@@ -118,26 +116,26 @@ class BaseDataProcessingTest(manager.ScenarioTest):
     @classmethod
     def get_floating_ip_pool_id_for_neutron(cls):
         net_id = cls._find_network_by_name(
-            TEMPEST_CONF.network.floating_network_name)
+            CONF.data_processing.floating_ip_pool)
         if not net_id:
             raise exceptions.NotFound(
                 'Floating IP pool \'%s\' not found in pool list.'
-                % TEMPEST_CONF.network.floating_network_name)
+                % CONF.data_processing.floating_ip_pool)
         return net_id
 
     @classmethod
     def get_private_network_id(cls):
         net_id = cls._find_network_by_name(
-            TEMPEST_CONF.compute.fixed_network_name)
+            CONF.data_processing.private_network)
         if not net_id:
             raise exceptions.NotFound(
                 'Private network \'%s\' not found in network list.'
-                % TEMPEST_CONF.compute.fixed_network_name)
+                % CONF.data_processing.private_network)
         return net_id
 
     @classmethod
     def _find_network_by_name(cls, network_name):
-        for network in cls.networks_client.list_networks()['networks']:
+        for network in cls.networks_client.list_networks():
             if network['label'] == network_name:
                 return network['id']
         return None
@@ -218,20 +216,19 @@ class BaseDataProcessingTest(manager.ScenarioTest):
         return resp_body
 
     def check_cluster_active(self, cluster_id):
-        timeout = TEMPEST_CONF.data_processing.cluster_timeout
+        timeout = CONF.data_processing.cluster_timeout
         s_time = timeutils.utcnow()
         while timeutils.delta_seconds(s_time, timeutils.utcnow()) < timeout:
             cluster = self.client.clusters.get(cluster_id)
-            if cluster.status == CLUSTER_STATUS_ACTIVE:
+            if cluster.status == 'Active':
                 return
-            if cluster.status == CLUSTER_STATUS_ERROR:
+            if cluster.status == 'Error':
                 raise exceptions.BuildErrorException(
-                    'Cluster failed to build and is in %s status.' %
-                    CLUSTER_STATUS_ERROR)
-            time.sleep(TEMPEST_CONF.data_processing.request_timeout)
+                    'Cluster failed to build and is in "Error" status.')
+            time.sleep(CONF.data_processing.request_timeout)
         raise exceptions.TimeoutException(
-            'Cluster failed to get to %s status within %d seconds.'
-            % (CLUSTER_STATUS_ACTIVE, timeout))
+            'Cluster failed to get to "Active status within %d seconds.'
+            % timeout)
 
     def create_job_execution(self, **kwargs):
 
@@ -258,7 +255,7 @@ class BaseDataProcessingTest(manager.ScenarioTest):
 
     def delete_timeout(
             self, resource_client, resource_id,
-            timeout=TEMPEST_CONF.data_processing.cluster_timeout):
+            timeout=CONF.data_processing.cluster_timeout):
 
         start = timeutils.utcnow()
         while timeutils.delta_seconds(start, timeutils.utcnow()) < timeout:
@@ -269,7 +266,7 @@ class BaseDataProcessingTest(manager.ScenarioTest):
                     return
                 raise sahara_api_exception
 
-            time.sleep(TEMPEST_CONF.data_processing.request_timeout)
+            time.sleep(CONF.data_processing.request_timeout)
 
         raise exceptions.TimeoutException(
             'Failed to delete resource "%s" in %d seconds.'
