@@ -12,13 +12,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from tempest import config
-from tempest.lib.common.utils import data_utils
+from tempest.scenario.data_processing.client_tests import base
+from tempest.scenario.data_processing import config as sahara_test_config
+from tempest import test
+from tempest_lib.common.utils import data_utils
 
-from sahara.tests.tempest.scenario.data_processing.client_tests import base
-
-
-TEMPEST_CONF = config.CONF
+CONF = sahara_test_config.SAHARA_TEST_CONF
 
 
 class ClusterTemplateTest(base.BaseDataProcessingTest):
@@ -31,7 +30,7 @@ class ClusterTemplateTest(base.BaseDataProcessingTest):
         full_cluster_template['node_groups'] = [
             {
                 'name': 'master-node',
-                'flavor_id': TEMPEST_CONF.compute.flavor_ref,
+                'flavor_id': CONF.data_processing.flavor_id,
                 'node_processes': ['namenode'],
                 'count': 1
             },
@@ -69,17 +68,6 @@ class ClusterTemplateTest(base.BaseDataProcessingTest):
         self.assertEqual(template_name, template.name)
         self.assertDictContainsSubset(self.cluster_template, template.__dict__)
 
-    def _check_cluster_template_update(self, template_id):
-        values = {
-            'name': data_utils.rand_name('updated-sahara-ct'),
-            'description': 'description',
-        }
-
-        # check updating of cluster template
-        template = self.client.cluster_templates.update(
-            template_id, **values)
-        self.assertDictContainsSubset(values, template.__dict__)
-
     def _check_cluster_template_delete(self, template_id):
         # delete cluster template by id
         self.client.cluster_templates.delete(
@@ -89,9 +77,9 @@ class ClusterTemplateTest(base.BaseDataProcessingTest):
         templates = self.client.cluster_templates.list()
         self.assertNotIn(template_id, [template.id for template in templates])
 
+    @test.services('data_processing')
     def test_cluster_templates(self):
         template_id, template_name = self._check_create_cluster_template()
         self._check_cluster_template_list(template_id, template_name)
         self._check_cluster_template_get(template_id, template_name)
-        self._check_cluster_template_update(template_id)
         self._check_cluster_template_delete(template_id)
