@@ -18,24 +18,24 @@ from oslo_utils import timeutils
 from saharaclient.api import base as sab
 from tempest import config
 from tempest import exceptions
-from tempest.lib.common.utils import data_utils
-from tempest.lib import decorators
+from tempest.scenario.data_processing.client_tests import base
+from tempest.scenario.data_processing import config as sahara_test_config
 from tempest import test
+from tempest_lib.common.utils import data_utils
+from tempest_lib import decorators
 
-from sahara.tests.tempest.scenario.data_processing.client_tests import base
-
-
+CONF = sahara_test_config.SAHARA_TEST_CONF
 TEMPEST_CONF = config.CONF
 
 
 class JobExecutionTest(base.BaseDataProcessingTest):
     def _check_register_image(self, image_id):
         self.client.images.update_image(
-            image_id, TEMPEST_CONF.scenario.ssh_user, '')
+            image_id, CONF.data_processing.ssh_username, '')
         reg_image = self.client.images.get(image_id)
 
         self.assertDictContainsSubset(
-            {'_sahara_username': TEMPEST_CONF.scenario.ssh_user},
+            {'_sahara_username': CONF.data_processing.ssh_username},
             reg_image.metadata)
 
     def _check_image_get(self, image_id):
@@ -106,7 +106,7 @@ class JobExecutionTest(base.BaseDataProcessingTest):
             'plugin_name': 'fake',
             'hadoop_version': '0.1',
             'cluster_template_id': cluster_template.id,
-            'default_image_id': TEMPEST_CONF.data_processing.fake_image_id
+            'default_image_id': CONF.data_processing.fake_image_id
         }
 
         # create cluster
@@ -133,15 +133,6 @@ class JobExecutionTest(base.BaseDataProcessingTest):
         self.assertEqual(cluster_name, cluster.name)
         self.assertDictContainsSubset(self.cluster_info, cluster.__dict__)
 
-    def _check_cluster_update(self, cluster_id):
-        values = {
-            'name': data_utils.rand_name('updated-sahara-cluster'),
-            'description': 'description'
-        }
-        # check updating of cluster
-        cluster = self.client.clusters.update(cluster_id)
-        self.assertDictContainsSubset(values, cluster.__dict__)
-
     def _check_cluster_scale(self, cluster_id):
         big_worker = self.create_node_group_template(
             data_utils.rand_name('sahara-ng-template'), **self.worker_template)
@@ -189,7 +180,7 @@ class JobExecutionTest(base.BaseDataProcessingTest):
         cluster = self.client.clusters.get(cluster_id)
         self.assertEqual('Deleting', cluster.status)
 
-        timeout = TEMPEST_CONF.data_processing.cluster_timeout
+        timeout = CONF.data_processing.cluster_timeout
         s_time = timeutils.utcnow()
         while timeutils.delta_seconds(s_time, timeutils.utcnow()) < timeout:
             try:
@@ -197,7 +188,7 @@ class JobExecutionTest(base.BaseDataProcessingTest):
             except sab.APIException:
                 # cluster is deleted
                 return
-            time.sleep(TEMPEST_CONF.data_processing.request_timeout)
+            time.sleep(CONF.data_processing.request_timeout)
 
         raise exceptions.TimeoutException('Cluster failed to terminate'
                                           'in %d seconds.' % timeout)
@@ -268,13 +259,6 @@ class JobExecutionTest(base.BaseDataProcessingTest):
         del job_exec_info['configs']
         self.assertDictContainsSubset(job_exec_info, job_exec.__dict__)
 
-    def _check_job_execution_update(self, job_exec_id):
-        values = {
-            'is_public': True
-        }
-        job_exec = self.client.job_executions.update(job_exec_id, **values)
-        self.assertDictContainsSubset(values, job_exec.__dict__)
-
     def _check_job_execution_delete(self, job_exec_id):
         # delete job_execution by id
         self.client.job_executions.delete(job_exec_id)
@@ -285,8 +269,9 @@ class JobExecutionTest(base.BaseDataProcessingTest):
 
     @decorators.skip_because(bug="1430252")
     @test.attr(type='slow')
+    @test.services('data_processing')
     def test_job_executions(self):
-        image_id = TEMPEST_CONF.data_processing.fake_image_id
+        image_id = CONF.data_processing.fake_image_id
         self._check_register_image(image_id)
         self._check_image_get(image_id)
         self._check_image_list(image_id)
@@ -295,13 +280,11 @@ class JobExecutionTest(base.BaseDataProcessingTest):
         cluster_id, cluster_name = self._check_cluster_create()
         self._check_cluster_list(cluster_id, cluster_name)
         self._check_cluster_get(cluster_id, cluster_name)
-        self._check_cluster_update(cluster_id)
         self._check_cluster_scale(cluster_id)
 
         job_exec_id = self._check_job_execution_create(cluster_id)
         self._check_job_execution_list(job_exec_id)
         self._check_job_execution_get(job_exec_id)
-        self._check_job_execution_update(job_exec_id)
 
         self._check_job_execution_delete(job_exec_id)
         self._check_cluster_delete(cluster_id)
@@ -311,7 +294,7 @@ class JobExecutionTest(base.BaseDataProcessingTest):
     @classmethod
     def tearDownClass(cls):
         image_list = cls.client.images.list()
-        image_id = TEMPEST_CONF.data_processing.fake_image_id
+        image_id = CONF.data_processing.fake_image_id
         if image_id in [image.id for image in image_list]:
             cls.client.images.unregister_image(image_id)
         super(JobExecutionTest, cls).tearDownClass()
