@@ -12,9 +12,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from tempest.lib.common.utils import data_utils
-
-from sahara.tests.tempest.scenario.data_processing.client_tests import base
+from tempest.scenario.data_processing.client_tests import base
+from tempest import test
+from tempest_lib.common.utils import data_utils
 
 
 class JobTest(base.BaseDataProcessingTest):
@@ -54,16 +54,6 @@ class JobTest(base.BaseDataProcessingTest):
         job = self.client.jobs.get(job_id)
         self.assertEqual(job_name, job.name)
 
-    def _check_job_update(self, job_id):
-        # check updating of job
-        values = {
-            'name': data_utils.rand_name('updated-sahara-job'),
-            'description': 'description'
-
-        }
-        job = self.client.jobs.update(job_id, **values)
-        self.assertDictContainsSubset(values, job.job)
-
     def _check_delete_job(self, job_id):
         # delete job by id
         self.client.jobs.delete(job_id)
@@ -71,9 +61,9 @@ class JobTest(base.BaseDataProcessingTest):
         job_list = self.client.jobs.list()
         self.assertNotIn(job_id, [job.id for job in job_list])
 
+    @test.services('data_processing')
     def test_job(self):
         job_id, job_name = self._check_create_job()
         self._check_job_list(job_id, job_name)
         self._check_get_job(job_id, job_name)
-        self._check_job_update(job_id)
         self._check_delete_job(job_id)
