@@ -13,8 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from unittest import mock
-
 from oslo_policy import policy as cpolicy
 
 from sahara.api import acl
@@ -29,26 +27,22 @@ class TestAcl(base.SaharaTestCase):
         rules = cpolicy.Rules.load_json(json)
         acl.ENFORCER.set_rules(rules, use_conf=False)
 
-    @mock.patch('oslo_config.cfg.ConfigOpts.find_file')
-    def test_policy_allow(self, mock_config):
-        mock_config.return_value = '/etc/sahara/'
-        @acl.enforce("data-processing:clusters:get_all")
+    def test_policy_allow(self):
+        @acl.enforce("clusters:get_all")
         def test():
             pass
 
-        json = '{"data-processing:clusters:get_all": ""}'
+        json = '{"clusters:get_all": ""}'
         self._set_policy(json)
 
         test()
 
-    @mock.patch('oslo_config.cfg.ConfigOpts.find_file')
-    def test_policy_deny(self, mock_config):
-        mock_config.return_value = '/etc/sahara/'
-        @acl.enforce("data-processing:clusters:get_all")
+    def test_policy_deny(self):
+        @acl.enforce("clusters:get_all")
         def test():
             pass
 
-        json = '{"data-processing:clusters:get_all": "!"}'
+        json = '{"clusters:get_all": "!"}'
         self._set_policy(json)
 
         self.assertRaises(ex.Forbidden, test)
