@@ -14,15 +14,7 @@
 # under the License.
 
 """
-Tests for database migrations. This test case reads the configuration
-file test_migrations.conf for database connection settings
-to use in the tests. For each connection found in the config file,
-the test case runs a series of test cases to ensure that migrations work
-properly.
-
-There are also "opportunistic" tests for both mysql and postgresql in here,
-which allows testing against mysql and pg) in a properly configured unit
-test environment.
+Tests for database migrations.
 
 For the opportunistic testing you need to set up a db named 'openstack_citest'
 with user 'openstack_citest' and password 'openstack_citest' on localhost.
@@ -39,25 +31,13 @@ postgres=# create database openstack_citest with owner openstack_citest;
 
 import os
 
-from oslo.config import cfg
-from oslo.db.sqlalchemy import utils as db_utils
+from oslo_db.sqlalchemy import test_base
+from oslo_db.sqlalchemy import utils as db_utils
 
 from sahara.tests.unit.db.migration import test_migrations_base as base
 
-CONF = cfg.CONF
 
-
-class TestMigrations(base.BaseWalkMigrationTestCase, base.CommonTestsMixIn):
-    """Test sqlalchemy-migrate migrations."""
-    USER = "openstack_citest"
-    PASSWD = "openstack_citest"
-    DATABASE = "openstack_citest"
-
-    def __init__(self, *args, **kwargs):
-        super(TestMigrations, self).__init__(*args, **kwargs)
-
-    def setUp(self):
-        super(TestMigrations, self).setUp()
+class SaharaMigrationsCheckers(object):
 
     def assertColumnExists(self, engine, table, column):
         t = db_utils.get_table(engine, table)
@@ -69,7 +49,7 @@ class TestMigrations(base.BaseWalkMigrationTestCase, base.CommonTestsMixIn):
 
     def assertColumnCount(self, engine, table, columns):
         t = db_utils.get_table(engine, table)
-        self.assertEqual(len(t.columns), len(columns))
+        self.assertEqual(len(columns), len(t.columns))
 
     def assertColumnNotExists(self, engine, table, column):
         t = db_utils.get_table(engine, table)
@@ -92,6 +72,9 @@ class TestMigrations(base.BaseWalkMigrationTestCase, base.CommonTestsMixIn):
 
         self.assertEqual(sorted(members), sorted(index_columns))
 
+    def test_walk_versions(self):
+        self.walk_versions(self.engine)
+
     def _pre_upgrade_001(self, engine):
         # Anything returned from this method will be
         # passed to corresponding _check_xxx method as 'data'.
@@ -380,17 +363,17 @@ class TestMigrations(base.BaseWalkMigrationTestCase, base.CommonTestsMixIn):
         self.assertEqual(desc, new_desc)
         engine.execute(t.delete())
 
-    def _check_008(self, engine, date):
+    def _check_008(self, engine, data):
         self.assertColumnExists(engine, 'node_group_templates',
                                 'security_groups')
         self.assertColumnExists(engine, 'node_groups', 'security_groups')
         self.assertColumnExists(engine, 'templates_relations',
                                 'security_groups')
 
-    def _check_009(self, engine, date):
+    def _check_009(self, engine, data):
         self.assertColumnExists(engine, 'clusters', 'rollback_info')
 
-    def _check_010(self, engine, date):
+    def _check_010(self, engine, data):
         self.assertColumnExists(engine, 'node_group_templates',
                                 'auto_security_group')
         self.assertColumnExists(engine, 'node_groups', 'auto_security_group')
@@ -398,5 +381,96 @@ class TestMigrations(base.BaseWalkMigrationTestCase, base.CommonTestsMixIn):
                                 'auto_security_group')
         self.assertColumnExists(engine, 'node_groups', 'open_ports')
 
-    def _check_011(self, engine, date):
+    def _check_011(self, engine, data):
         self.assertColumnExists(engine, 'clusters', 'sahara_info')
+
+    def _check_012(self, engine, data):
+        self.assertColumnExists(engine, 'node_group_templates',
+                                'availability_zone')
+        self.assertColumnExists(engine, 'node_groups', 'availability_zone')
+        self.assertColumnExists(engine, 'templates_relations',
+                                'availability_zone')
+
+    def _check_014(self, engine, data):
+        self.assertColumnExists(engine, 'node_group_templates', 'volume_type')
+        self.assertColumnExists(engine, 'node_groups', 'volume_type')
+        self.assertColumnExists(engine, 'templates_relations', 'volume_type')
+
+    def _check_015(self, engine, data):
+        provision_steps_columns = [
+            'created_at',
+            'updated_at',
+            'id',
+            'cluster_id',
+            'tenant_id',
+            'step_name',
+            'step_type',
+            'completed',
+            'total',
+            'successful',
+            'started_at',
+            'completed_at',
+        ]
+        events_columns = [
+            'created_at',
+            'updated_at',
+            'id',
+            'node_group_id',
+            'instance_id',
+            'instance_name',
+            'event_info',
+            'successful',
+            'step_id',
+        ]
+
+        self.assertColumnCount(engine, 'cluster_provision_steps',
+                               provision_steps_columns)
+        self.assertColumnsExists(engine, 'cluster_provision_steps',
+                                 provision_steps_columns)
+
+        self.assertColumnCount(engine, 'cluster_events', events_columns)
+        self.assertColumnsExists(engine, 'cluster_events', events_columns)
+
+    def _check_016(self, engine, data):
+        self.assertColumnExists(engine, 'node_group_templates',
+                                'is_proxy_gateway')
+        self.assertColumnExists(engine, 'node_groups', 'is_proxy_gateway')
+        self.assertColumnExists(engine, 'templates_relations',
+                                'is_proxy_gateway')
+
+    def _check_017(self, engine, data):
+        self.assertColumnNotExists(engine, 'job_executions', 'progress')
+
+    def _check_018(self, engine, data):
+        self.assertColumnExists(engine, 'node_group_templates',
+                                'volume_local_to_instance')
+        self.assertColumnExists(engine, 'node_groups',
+                                'volume_local_to_instance')
+        self.assertColumnExists(engine, 'templates_relations',
+                                'volume_local_to_instance')
+
+    def _check_019(self, engine, data):
+        self.assertColumnExists(engine, 'node_group_templates', 'is_default')
+        self.assertColumnExists(engine, 'cluster_templates', 'is_default')
+
+    def _check_020(self, engine, data):
+        self.assertColumnNotExists(engine, 'cluster_provision_steps',
+                                   'completed')
+        self.assertColumnNotExists(engine, 'cluster_provision_steps',
+                                   'completed_at')
+        self.assertColumnNotExists(engine, 'cluster_provision_steps',
+                                   'started_at')
+
+
+class TestMigrationsMySQL(SaharaMigrationsCheckers,
+                          base.BaseWalkMigrationTestCase,
+                          base.TestModelsMigrationsSync,
+                          test_base.MySQLOpportunisticTestCase):
+    pass
+
+
+class TestMigrationsPostgresql(SaharaMigrationsCheckers,
+                               base.BaseWalkMigrationTestCase,
+                               base.TestModelsMigrationsSync,
+                               test_base.PostgreSQLOpportunisticTestCase):
+    pass
