@@ -21,25 +21,20 @@ from sahara.plugins.mapr.services.maprfs import maprfs
 from sahara.plugins.mapr.services.oozie import oozie
 from sahara.plugins.mapr.services.swift import swift
 from sahara.plugins.mapr.services.yarn import yarn
-import sahara.plugins.mapr.versions.v5_0_0_mrv2.context as cc
-import sahara.plugins.mapr.versions.v5_0_0_mrv2.version_handler as handler
+import sahara.plugins.mapr.versions.v4_0_1_mrv2.context as cc
+import sahara.plugins.mapr.versions.v4_0_1_mrv2.version_handler as handler
 from sahara.plugins import provisioning as p
 from sahara.tests.unit import base as b
 from sahara.tests.unit import testutils as tu
 
 
-MANAGEMENT_IP = '1.1.1.1'
-INTERNAL_IP = '1.1.1.2'
-
-
 class TestClusterContext(b.SaharaTestCase):
     def __init__(self, *args, **kwds):
         super(TestClusterContext, self).__init__(*args, **kwds)
         self.fake_np = np.NodeProcess('fake', 'foo', 'bar')
 
     def _get_context(self):
-        i1 = tu.make_inst_dict('id_1', 'instance_1', MANAGEMENT_IP)
-        i1['internal_ip'] = INTERNAL_IP
+        i1 = tu.make_inst_dict('id_1', 'instance_1', '1.1.1.1')
         master_proc = [
             yarn.RESOURCE_MANAGER.ui_name,
             yarn.NODE_MANAGER.ui_name,
@@ -55,15 +50,12 @@ class TestClusterContext(b.SaharaTestCase):
                 'key': 'value',
                 'Service Version': '1.1',
             },
-            'Oozie': {
-                'Oozie Version': '4.1.0',
-            }
         }
         cluster = tu.create_cluster(
             name='test_cluster',
             tenant='large',
             plugin='mapr',
-            version='5.0.0.mrv2',
+            version='4.0.1.mrv1',
             node_groups=[master_ng],
             cluster_configs=cluster_configs,
         )
@@ -73,8 +65,7 @@ class TestClusterContext(b.SaharaTestCase):
 
     def test_get_oozie_server_uri(self):
         ctx = self._get_context()
-        expected = 'http://%s:11000/oozie' % MANAGEMENT_IP
-        self.assertEqual(expected, ctx.oozie_server_uri)
+        self.assertEqual('http://1.1.1.1:11000/oozie', ctx.oozie_server_uri)
 
     def test_oozie_server(self):
         ctx = self._get_context()
@@ -83,19 +74,19 @@ class TestClusterContext(b.SaharaTestCase):
 
     def test_oozie_http(self):
         ctx = self._get_context()
-        expected = '%s:11000' % MANAGEMENT_IP
-        self.assertEqual(expected, ctx.oozie_http)
+        self.assertEqual('1.1.1.1:11000', ctx.oozie_http)
 
     def test_configure_sh(self):
         ctx = self._get_context()
         conf_sh = ctx.configure_sh
         pattern = (r'^(\S+)\s+(-N (\S+))\s+(-C (\S+))\s+(-Z (\S+))\s+'
-                   r'(-no-autostart)\s+(-f)\s+\s(-HS (\S+))')
+                   r'(-no-autostart)\s+(-f)\s+(-RM (\S+))\s(-HS (\S+))')
         self.assertRegex(conf_sh, pattern)
         self.assertIn('/opt/mapr/server/configure.sh', conf_sh)
-        self.assertIn('-C %s' % INTERNAL_IP, conf_sh)
-        self.assertIn('-Z %s' % INTERNAL_IP, conf_sh)
-        self.assertIn('-HS %s' % INTERNAL_IP, conf_sh)
+        self.assertIn('-C 1.1.1.1', conf_sh)
+        self.assertIn('-Z 1.1.1.1', conf_sh)
+        self.assertIn('-RM 1.1.1.1', conf_sh)
+        self.assertIn('-HS 1.1.1.1', conf_sh)
         self.assertIn('-no-autostart', conf_sh)
         self.assertIn('-N ' + ctx.cluster.name, conf_sh)
 
@@ -133,33 +124,29 @@ class TestClusterContext(b.SaharaTestCase):
         ctx = self._get_context()
         ip_list_1 = ctx.get_instances_ip(yarn.RESOURCE_MANAGER)
         self.assertEqual(1, len(ip_list_1))
-        self.assertIn(INTERNAL_IP, ip_list_1)
+        self.assertIn('1.1.1.1', ip_list_1)
         ip_list_2 = ctx.get_instances_ip(yarn.RESOURCE_MANAGER.ui_name)
         self.assertEqual(1, len(ip_list_2))
-        self.assertIn(INTERNAL_IP, ip_list_2)
+        self.assertIn('1.1.1.1', ip_list_2)
         empty_list = ctx.get_instances_ip(self.fake_np)
         self.assertEqual(0, len(empty_list))
 
     def test_get_instance_ip(self):
         ctx = self._get_context()
         ip_1 = ctx.get_instance_ip(yarn.RESOURCE_MANAGER)
-        self.assertEqual(INTERNAL_IP, ip_1)
+        self.assertEqual('1.1.1.1', ip_1)
         ip_2 = ctx.get_instance_ip(yarn.RESOURCE_MANAGER.ui_name)
-        self.assertEqual(INTERNAL_IP, ip_2)
+        self.assertEqual('1.1.1.1', ip_2)
         none_ip = ctx.get_instance_ip(self.fake_np)
         self.assertIsNone(none_ip)
 
     def test_get_zookeeper_nodes_ip_with_port(self):
         ctx = self._get_context()
-
-        expected = '%s:5181' % INTERNAL_IP
-        actual = ctx.get_zookeeper_nodes_ip_with_port()
-        self.assertEqual(expected, actual)
-
+        self.assertEqual('1.1.1.1:5181',
+                         ctx.get_zookeeper_nodes_ip_with_port())
         management.ZK_CLIENT_PORT = '0000'
-        expected = '%s:0000' % INTERNAL_IP
-        actual = ctx.get_zookeeper_nodes_ip_with_port()
-        self.assertEqual(expected, actual)
+        self.assertEqual('1.1.1.1:0000',
+                         ctx.get_zookeeper_nodes_ip_with_port())
 
     def test_filter_instances(self):
         ctx = self._get_context()
@@ -246,40 +233,33 @@ class TestClusterContext(b.SaharaTestCase):
         ctx = self._get_context()
         cldb_list_1 = ctx.get_cldb_nodes_ip()
         self.assertEqual(1, len(cldb_list_1.split(',')))
-        self.assertIn(INTERNAL_IP, cldb_list_1)
+        self.assertIn('1.1.1.1', cldb_list_1)
         cldb_list_2 = ctx.get_cldb_nodes_ip()
         self.assertEqual(1, len(cldb_list_2.split(',')))
-        self.assertIn(INTERNAL_IP, cldb_list_2)
+        self.assertIn('1.1.1.1', cldb_list_2)
         sep = ':'
         cldb_list_3 = ctx.get_cldb_nodes_ip(sep)
         self.assertEqual(1, len(cldb_list_3.split(sep)))
-        self.assertIn(INTERNAL_IP, cldb_list_3)
+        self.assertIn('1.1.1.1', cldb_list_3)
 
     def test_get_zookeeper_nodes_ip(self):
         ctx = self._get_context()
         zk_list_1 = ctx.get_zookeeper_nodes_ip()
         self.assertEqual(1, len(zk_list_1.split(',')))
-        self.assertIn(INTERNAL_IP, zk_list_1)
+        self.assertIn('1.1.1.1', zk_list_1)
         zk_list_2 = ctx.get_zookeeper_nodes_ip()
         self.assertEqual(1, len(zk_list_2.split(',')))
-        self.assertIn(INTERNAL_IP, zk_list_2)
+        self.assertIn('1.1.1.1', zk_list_2)
         sep = ':'
         zk_list_3 = ctx.get_zookeeper_nodes_ip(sep)
         self.assertEqual(1, len(zk_list_3.split(sep)))
-        self.assertIn(INTERNAL_IP, zk_list_3)
+        self.assertIn('1.1.1.1', zk_list_3)
 
     def test_get_resourcemanager_ip(self):
         ctx = self._get_context()
         ip = ctx.get_resourcemanager_ip()
-        self.assertEqual(INTERNAL_IP, ip)
+        self.assertEqual('1.1.1.1', ip)
 
     def test_get_historyserver_ip(self):
         ctx = self._get_context()
         self.assertTrue(ctx.has_control_nodes([self.instance]))
-
-    def test_is_present(self):
-        cluster_context = self._get_context()
-
-        self.assertTrue(cluster_context.is_present(oozie.Oozie()))
-        self.assertFalse(cluster_context.is_present(oozie.OozieV401()))
-        self.assertTrue(cluster_context.is_present(oozie.OozieV410()))
