@@ -15,7 +15,6 @@
 
 import testtools
 
-from sahara import main
 from sahara.plugins import base as pb
 
 
@@ -23,9 +22,9 @@ class BasePluginsSupportTest(testtools.TestCase):
 
     def setUp(self):
         super(BasePluginsSupportTest, self).setUp()
-        main.CONF.set_override('plugins', ['fake', 'cdh', 'spark'])
         pb.setup_plugins()
 
     def test_plugins_loaded(self):
-        plugins = [p.name for p in pb.PLUGINS.get_plugins()]
-        self.assertIn('fake', plugins)
+        plugins = [p.name for p in pb.PLUGINS.get_plugins(pb.PluginInterface)]
+        self.assertIn('vanilla', plugins)
+        self.assertIn('hdp', plugins)
