@@ -14,16 +14,20 @@
 # limitations under the License.
 
 import mock
+import testtools
 
 from sahara import conductor as cond
 from sahara import context
-from sahara.plugins.general import exceptions as ex
+from sahara import exceptions as e
+from sahara.plugins import base as pb
+from sahara.plugins import exceptions as ex
 from sahara.plugins.vanilla import plugin as p
 from sahara.plugins.vanilla.v1_2_1 import config_helper as c_h
 from sahara.plugins.vanilla.v1_2_1 import mysql_helper as m_h
 from sahara.plugins.vanilla.v1_2_1 import versionhandler as v_h
 from sahara.tests.unit import base
 from sahara.tests.unit import testutils as tu
+from sahara.utils import edp
 
 
 conductor = cond.API
@@ -32,6 +36,7 @@ conductor = cond.API
 class VanillaPluginTest(base.SaharaWithDbTestCase):
     def setUp(self):
         super(VanillaPluginTest, self).setUp()
+        pb.setup_plugins()
         self.pl = p.VanillaProvider()
 
     def test_validate(self):
@@ -43,19 +48,19 @@ class VanillaPluginTest(base.SaharaWithDbTestCase):
 
         self._validate_case(1, 1, 10, 1)
 
-        with self.assertRaises(ex.InvalidComponentCountException):
+        with testtools.ExpectedException(ex.InvalidComponentCountException):
             self._validate_case(0, 1, 10, 1)
-        with self.assertRaises(ex.InvalidComponentCountException):
+        with testtools.ExpectedException(ex.InvalidComponentCountException):
             self._validate_case(2, 1, 10, 1)
 
-        with self.assertRaises(ex.RequiredServiceMissingException):
+        with testtools.ExpectedException(ex.RequiredServiceMissingException):
             self._validate_case(1, 0, 10, 1)
-        with self.assertRaises(ex.InvalidComponentCountException):
+        with testtools.ExpectedException(ex.InvalidComponentCountException):
             self._validate_case(1, 2, 10, 1)
 
-        with self.assertRaises(ex.InvalidComponentCountException):
+        with testtools.ExpectedException(ex.InvalidComponentCountException):
             self._validate_case(1, 1, 0, 2)
-        with self.assertRaises(ex.RequiredServiceMissingException):
+        with testtools.ExpectedException(ex.RequiredServiceMissingException):
             self._validate_case(1, 0, 0, 1)
 
     def _validate_case(self, *args):
@@ -74,7 +79,10 @@ class VanillaPluginTest(base.SaharaWithDbTestCase):
             if cfg.config_type is "bool":
                 self.assertIsInstance(cfg.default_value, bool)
             elif cfg.config_type is "int":
-                self.assertIsInstance(cfg.default_value, int)
+                try:
+                    self.assertIsInstance(cfg.default_value, int)
+                except AssertionError:
+                    self.assertIsInstance(cfg.default_value, long)
             else:
                 self.assertIsInstance(cfg.default_value, str)
             self.assertNotIn(cfg.name, c_h.HIDDEN_CONFS)
@@ -95,12 +103,12 @@ class VanillaPluginTest(base.SaharaWithDbTestCase):
             "Wrong-applicable-target": {
                 't1': 4
             }}
-        self.assertListEqual(c_h.extract_environment_confs(env_configs),
-                             ['HADOOP_NAMENODE_OPTS=\\"-Xmx3000m\\"',
-                              'HADOOP_DATANODE_OPTS=\\"-Xmx4000m\\"',
-                              'CATALINA_OPTS -Xmx4000m',
-                              'HADOOP_JOBTRACKER_OPTS=\\"-Xmx1000m\\"',
-                              'HADOOP_TASKTRACKER_OPTS=\\"-Xmx2000m\\"'])
+        self.assertEqual(['CATALINA_OPTS -Xmx4000m',
+                          'HADOOP_DATANODE_OPTS=\\"-Xmx4000m\\"',
+                          'HADOOP_JOBTRACKER_OPTS=\\"-Xmx1000m\\"',
+                          'HADOOP_NAMENODE_OPTS=\\"-Xmx3000m\\"',
+                          'HADOOP_TASKTRACKER_OPTS=\\"-Xmx2000m\\"'],
+                         c_h.extract_environment_confs(env_configs))
 
     def test_extract_xml_configs(self):
         xml_configs = {
@@ -118,11 +126,11 @@ class VanillaPluginTest(base.SaharaWithDbTestCase):
             }
         }
 
-        self.assertListEqual(c_h.extract_xml_confs(xml_configs),
-                             [('fs.default.name', 'hdfs://'),
-                              ('dfs.replication', 3),
-                              ('mapred.reduce.tasks', 2),
-                              ('io.sort.factor', 10)])
+        self.assertEqual([('dfs.replication', 3),
+                         ('fs.default.name', 'hdfs://'),
+                         ('io.sort.factor', 10),
+                         ('mapred.reduce.tasks', 2)],
+                         c_h.extract_xml_confs(xml_configs))
 
     def test_general_configs(self):
         gen_config = {
@@ -149,28 +157,28 @@ class VanillaPluginTest(base.SaharaWithDbTestCase):
             }
         }
         cfg = c_h.generate_cfg_from_general({}, configs, gen_config)
-        self.assertDictEqual(cfg, all_configured)
+        self.assertEqual(all_configured, cfg)
         configs['general'].update({'Enable MySQL': False})
         cfg = c_h.generate_cfg_from_general({}, configs, gen_config)
-        self.assertDictEqual(cfg, {'fs.swift.enabled': True})
+        self.assertEqual({'fs.swift.enabled': True}, cfg)
         configs['general'].update({
             'Enable Swift': False,
             'Enable MySQL': False
         })
         cfg = c_h.generate_cfg_from_general({}, configs, gen_config)
-        self.assertDictEqual(cfg, {})
+        self.assertEqual({}, cfg)
         configs = {}
         cfg = c_h.generate_cfg_from_general({}, configs, gen_config)
-        self.assertDictEqual(cfg, all_configured)
+        self.assertEqual(all_configured, cfg)
 
     def test_get_mysql_configs(self):
         cfg = m_h.get_required_mysql_configs(None, None)
-        self.assertDictEqual(cfg, m_h.get_oozie_mysql_configs())
+        self.assertEqual(cfg, m_h.get_oozie_mysql_configs())
         cfg = m_h.get_required_mysql_configs("metastore_host", "passwd")
         cfg_to_compare = m_h.get_oozie_mysql_configs()
         cfg_to_compare.update(m_h.get_hive_mysql_configs(
             "metastore_host", "passwd"))
-        self.assertDictEqual(cfg, cfg_to_compare)
+        self.assertEqual(cfg, cfg_to_compare)
 
     @mock.patch('sahara.conductor.api.LocalApi.cluster_get')
     def test_get_config_value(self, cond_get_cluster):
@@ -178,13 +186,13 @@ class VanillaPluginTest(base.SaharaWithDbTestCase):
         cond_get_cluster.return_value = cluster
 
         self.assertEqual(
-            c_h.get_config_value('HDFS', 'fs.default.name', cluster),
-            'hdfs://inst1:8020')
+            'hdfs://inst1:8020',
+            c_h.get_config_value('HDFS', 'fs.default.name', cluster))
         self.assertEqual(
-            c_h.get_config_value('HDFS', 'spam', cluster), 'eggs')
+            'eggs', c_h.get_config_value('HDFS', 'spam', cluster))
         self.assertEqual(
-            c_h.get_config_value('HDFS', 'dfs.safemode.extension'), 30000)
-        self.assertRaises(RuntimeError,
+            30000, c_h.get_config_value('HDFS', 'dfs.safemode.extension'))
+        self.assertRaises(e.ConfigurationError,
                           c_h.get_config_value,
                           'MapReduce', 'spam', cluster)
 
@@ -267,22 +275,38 @@ class VanillaPluginTest(base.SaharaWithDbTestCase):
             'plugin_name': 'mock_plugin',
             'hadoop_version': 'mock_version',
             'default_image_id': 'initial',
-            'node_groups': [tu.make_ng_dict("ng1", "f1", ["s1"], 1)]}
+            'node_groups': [tu.make_ng_dict("ng1", "f1", ["s1"], 1)],
+            'extra': {'test': '1'}}
 
         cluster1 = conductor.cluster_create(context.ctx(), cluster_dict)
         (private_key1, public_key1) = c_h.get_hadoop_ssh_keys(cluster1)
 
-        #should store keys for old cluster
+        # should store keys for old cluster
         cluster1 = conductor.cluster_get(context.ctx(), cluster1)
         (private_key2, public_key2) = c_h.get_hadoop_ssh_keys(cluster1)
 
         self.assertEqual(public_key1, public_key2)
         self.assertEqual(private_key1, private_key2)
 
-        #should generate new keys for new cluster
+        # should generate new keys for new cluster
         cluster_dict.update({'name': 'cluster2'})
         cluster2 = conductor.cluster_create(context.ctx(), cluster_dict)
         (private_key3, public_key3) = c_h.get_hadoop_ssh_keys(cluster2)
 
         self.assertNotEqual(public_key1, public_key3)
         self.assertNotEqual(private_key1, private_key3)
+
+    @mock.patch('sahara.service.edp.hdfs_helper.create_dir_hadoop1')
+    def test_edp_calls_hadoop1_create_dir(self, create_dir):
+        cluster_dict = {
+            'name': 'cluster1',
+            'plugin_name': 'vanilla',
+            'hadoop_version': '1.2.1',
+            'default_image_id': 'image'}
+
+        cluster = conductor.cluster_create(context.ctx(), cluster_dict)
+        plugin = pb.PLUGINS.get_plugin(cluster.plugin_name)
+        plugin.get_edp_engine(cluster, edp.JOB_TYPE_PIG).create_hdfs_dir(
+            mock.Mock(), '/tmp')
+
+        self.assertEqual(1, create_dir.call_count)
