@@ -13,14 +13,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import uuid
 
-from unittest import mock
-
-from oslo_utils import uuidutils
+import mock
+import six
 import testtools
 
 from sahara import conductor as cond
-from sahara.service.edp.data_sources import manager as ds_manager
 from sahara.service.edp import job_utils
 from sahara.tests.unit.service.edp import edp_test_utils as u
 
@@ -31,7 +30,6 @@ class JobUtilsTestCase(testtools.TestCase):
 
     def setUp(self):
         super(JobUtilsTestCase, self).setUp()
-        ds_manager.setup_data_sources()
 
     def test_args_may_contain_data_sources(self):
         job_configs = None
@@ -66,7 +64,7 @@ class JobUtilsTestCase(testtools.TestCase):
         self.assertFalse(by_uuid)
 
     def test_find_possible_data_source_refs_by_name(self):
-        id = uuidutils.generate_uuid()
+        id = six.text_type(uuid.uuid4())
         job_configs = {}
         self.assertEqual([],
                          job_utils.find_possible_data_source_refs_by_name(
@@ -106,7 +104,7 @@ class JobUtilsTestCase(testtools.TestCase):
         job_configs = {'args': [name_ref, name_ref2, id],
                        'configs': {'config': name_ref},
                        'params': {'param': name_ref}}
-        self.assertCountEqual(
+        self.assertItemsEqual(
             ['name', 'name2'],
             job_utils.find_possible_data_source_refs_by_name(job_configs))
 
@@ -119,7 +117,7 @@ class JobUtilsTestCase(testtools.TestCase):
                          job_utils.find_possible_data_source_refs_by_uuid(
                              job_configs))
 
-        id = uuidutils.generate_uuid()
+        id = six.text_type(uuid.uuid4())
         job_configs = {'args': ['first', name_ref],
                        'configs': {'config': 'value'},
                        'params': {'param': 'value'}}
@@ -148,11 +146,11 @@ class JobUtilsTestCase(testtools.TestCase):
             [id],
             job_utils.find_possible_data_source_refs_by_uuid(job_configs))
 
-        id2 = uuidutils.generate_uuid()
+        id2 = six.text_type(uuid.uuid4())
         job_configs = {'args': [id, id2, name_ref],
                        'configs': {'config': id},
                        'params': {'param': id}}
-        self.assertCountEqual([id, id2],
+        self.assertItemsEqual([id, id2],
                               job_utils.find_possible_data_source_refs_by_uuid(
                                   job_configs))
 
@@ -163,17 +161,14 @@ class JobUtilsTestCase(testtools.TestCase):
         ctx.return_value = 'dummy'
 
         name_ref = job_utils.DATA_SOURCE_PREFIX+'input'
-        job_exec_id = uuidutils.generate_uuid()
 
-        input_url = "swift://container/input"
-        input = u.create_data_source(input_url,
+        input = u.create_data_source("swift://container/input",
                                      name="input",
-                                     id=uuidutils.generate_uuid())
+                                     id=six.text_type(uuid.uuid4()))
 
-        output = u.create_data_source("swift://container/output.%JOB_EXEC_ID%",
+        output = u.create_data_source("swift://container/output",
                                       name="output",
-                                      id=uuidutils.generate_uuid())
-        output_url = "swift://container/output." + job_exec_id
+                                      id=six.text_type(uuid.uuid4()))
 
         by_name = {'input': input,
                    'output': output}
@@ -203,17 +198,43 @@ class JobUtilsTestCase(testtools.TestCase):
                 job_utils.DATA_SOURCE_SUBST_NAME: True,
                 job_utils.DATA_SOURCE_SUBST_UUID: True},
             'args': [name_ref, output.id, input.id]}
-        urls = {}
-        ds, nc = job_utils.resolve_data_source_references(job_configs,
-                                                          job_exec_id, urls)
+
+        ds, nc = job_utils.resolve_data_source_references(job_configs)
         self.assertEqual(2, len(ds))
-        self.assertEqual([input.url, output_url, input.url], nc['args'])
+        self.assertEqual([input.url, output.url, input.url], nc['args'])
+        # Swift configs should be filled in since they were blank
+        self.assertEqual(input.credentials['user'],
+                         nc['configs']['fs.swift.service.sahara.username'])
+        self.assertEqual(input.credentials['password'],
+                         nc['configs']['fs.swift.service.sahara.password'])
+
+        job_configs['configs'] = {'fs.swift.service.sahara.username': 'sam',
+                                  'fs.swift.service.sahara.password': 'gamgee',
+                                  job_utils.DATA_SOURCE_SUBST_NAME: False,
+                                  job_utils.DATA_SOURCE_SUBST_UUID: True}
+        ds, nc = job_utils.resolve_data_source_references(job_configs)
+        self.assertEqual(2, len(ds))
+        self.assertEqual([name_ref, output.url, input.url], nc['args'])
+        # Swift configs should not be overwritten
+        self.assertEqual(job_configs['configs'], nc['configs'])
+
+        job_configs['configs'] = {job_utils.DATA_SOURCE_SUBST_NAME: True,
+                                  job_utils.DATA_SOURCE_SUBST_UUID: False}
+        job_configs['proxy_configs'] = {'proxy_username': 'john',
+                                        'proxy_password': 'smith',
+                                        'proxy_trust_id': 'trustme'}
+        ds, nc = job_utils.resolve_data_source_references(job_configs)
+        self.assertEqual(1, len(ds))
+        self.assertEqual([input.url, output.id, input.id], nc['args'])
+
+        # Swift configs should be empty and proxy configs should be preserved
+        self.assertEqual(job_configs['configs'], nc['configs'])
+        self.assertEqual(job_configs['proxy_configs'], nc['proxy_configs'])
 
         # Substitution not enabled
         job_configs['configs'] = {job_utils.DATA_SOURCE_SUBST_NAME: False,
                                   job_utils.DATA_SOURCE_SUBST_UUID: False}
-        ds, nc = job_utils.resolve_data_source_references(job_configs,
-                                                          job_exec_id, {})
+        ds, nc = job_utils.resolve_data_source_references(job_configs)
         self.assertEqual(0, len(ds))
         self.assertEqual(job_configs['args'], nc['args'])
         self.assertEqual(job_configs['configs'], nc['configs'])
@@ -222,38 +243,7 @@ class JobUtilsTestCase(testtools.TestCase):
         job_configs['configs'] = {job_utils.DATA_SOURCE_SUBST_NAME: True,
                                   job_utils.DATA_SOURCE_SUBST_UUID: True}
         job_configs['args'] = ['val1', 'val2', 'val3']
-        ds, nc = job_utils.resolve_data_source_references(job_configs,
-                                                          job_exec_id, {})
+        ds, nc = job_utils.resolve_data_source_references(job_configs)
         self.assertEqual(0, len(ds))
-        self.assertEqual(nc['args'], job_configs['args'])
-        self.assertEqual(nc['configs'], job_configs['configs'])
-
-    def test_to_url_dict(self):
-        data_source_urls = {'1': ('1_native', '1_runtime'),
-                            '2': ('2_native', '2_runtime')}
-        self.assertCountEqual({'1': '1_native',
-                               '2': '2_native'},
-                              job_utils.to_url_dict(data_source_urls))
-
-        self.assertCountEqual({'1': '1_runtime',
-                               '2': '2_runtime'},
-                              job_utils.to_url_dict(data_source_urls,
-                                                    runtime=True))
-
-    @mock.patch('sahara.service.edp.hdfs_helper.configure_cluster_for_hdfs')
-    def test_prepare_cluster_for_ds(self, configure):
-        data_source_urls = {'1': '1_runtime',
-                            '2': '2_runtime'}
-
-        data_source = mock.Mock()
-        data_source.type = 'hdfs'
-        data_source.id = '1'
-
-        cluster = mock.Mock()
-        job_configs = mock.Mock()
-
-        job_utils.prepare_cluster_for_ds([data_source], cluster, job_configs,
-                                         data_source_urls)
-
-        configure.assert_called_once()
-        configure.assert_called_with(cluster, '1_runtime')
+        self.assertEqual(job_configs['args'], nc['args'])
+        self.assertEqual(job_configs['configs'], nc['configs'])
