@@ -14,16 +14,16 @@
 # limitations under the License.
 
 import itertools
+import json
 import os
+import uuid
 
-from oslo_serialization import jsonutils as json
-from oslo_utils import uuidutils
 import testtools
 
-from sahara.service.validations.edp import data_source_schema
-from sahara.service.validations.edp import job_binary_schema
-from sahara.service.validations.edp import job_execution_schema
-from sahara.service.validations.edp import job_schema
+from sahara.service.validations.edp import data_source
+from sahara.service.validations.edp import job
+from sahara.service.validations.edp import job_binary
+from sahara.service.validations.edp import job_execution
 from sahara.utils import api_validator
 
 
@@ -32,13 +32,13 @@ class TestJSONApiExamplesV11(testtools.TestCase):
     EXAMPLES_PATH = 'etc/edp-examples/json-api-examples/v1.1/%s'
 
     def test_data_sources(self):
-        schema = data_source_schema.DATA_SOURCE_SCHEMA
+        schema = data_source.DATA_SOURCE_SCHEMA
         path = self.EXAMPLES_PATH % 'data-sources'
         formatter = self._formatter()
         self._test(schema, path, formatter)
 
     def test_job_binaries(self):
-        schema = job_binary_schema.JOB_BINARY_SCHEMA
+        schema = job_binary.JOB_BINARY_SCHEMA
         path = self.EXAMPLES_PATH % 'job-binaries'
         formatter = self._formatter("job_binary_internal_id",
                                     "script_binary_internal_id",
@@ -46,7 +46,7 @@ class TestJSONApiExamplesV11(testtools.TestCase):
         self._test(schema, path, formatter)
 
     def test_jobs(self):
-        schema = job_schema.JOB_SCHEMA
+        schema = job.JOB_SCHEMA
         path = self.EXAMPLES_PATH % 'jobs'
         formatter = self._formatter("job_binary_id",
                                     "udf_binary_id",
@@ -55,7 +55,7 @@ class TestJSONApiExamplesV11(testtools.TestCase):
         self._test(schema, path, formatter)
 
     def test_job_executions(self):
-        schema = job_execution_schema.JOB_EXEC_SCHEMA
+        schema = job_execution.JOB_EXEC_SCHEMA
         path = self.EXAMPLES_PATH % 'job-executions'
         formatter = self._formatter("cluster_id",
                                     "input_source_id",
@@ -76,4 +76,4 @@ class TestJSONApiExamplesV11(testtools.TestCase):
         return itertools.chain(*all_files)
 
     def _formatter(self, *variables):
-        return {variable: uuidutils.generate_uuid() for variable in variables}
+        return {variable: str(uuid.uuid4()) for variable in variables}
