@@ -83,7 +83,7 @@ class TestClusterRollBack(AbstractInstanceTest):
 
         ctx = context.ctx()
         cluster_obj = conductor.cluster_get_all(ctx)[0]
-        self.assertEqual(len(cluster_obj.node_groups[0].instances), 0)
+        self.assertEqual(0, len(cluster_obj.node_groups[0].instances))
 
 
 class NodePlacementTest(AbstractInstanceTest):
@@ -103,19 +103,21 @@ class NodePlacementTest(AbstractInstanceTest):
                        scheduler_hints={'group': "123"},
                        userdata=userdata,
                        key_name='user_keypair',
-                       security_groups=None),
+                       security_groups=None,
+                       availability_zone=None),
              mock.call("test_cluster-test_group-002",
                        "initial",
                        "test_flavor",
                        scheduler_hints={'group': "123"},
                        userdata=userdata,
                        key_name='user_keypair',
-                       security_groups=None)],
+                       security_groups=None,
+                       availability_zone=None)],
             any_order=False)
 
         ctx = context.ctx()
         cluster_obj = conductor.cluster_get_all(ctx)[0]
-        self.assertEqual(len(cluster_obj.node_groups[0].instances), 2)
+        self.assertEqual(2, len(cluster_obj.node_groups[0].instances))
 
     def test_one_node_groups_and_no_affinity_group(self):
         self.nova.server_groups.create.return_value = mock.Mock(id='123')
@@ -135,19 +137,21 @@ class NodePlacementTest(AbstractInstanceTest):
                        scheduler_hints=None,
                        userdata=userdata,
                        key_name='user_keypair',
-                       security_groups=None),
+                       security_groups=None,
+                       availability_zone=None),
              mock.call("test_cluster-test_group-002",
                        "initial",
                        "test_flavor",
                        scheduler_hints=None,
                        userdata=userdata,
                        key_name='user_keypair',
-                       security_groups=None)],
+                       security_groups=None,
+                       availability_zone=None)],
             any_order=False)
 
         ctx = context.ctx()
         cluster_obj = conductor.cluster_get_all(ctx)[0]
-        self.assertEqual(len(cluster_obj.node_groups[0].instances), 2)
+        self.assertEqual(2, len(cluster_obj.node_groups[0].instances))
 
     def test_two_node_groups_and_one_affinity_group(self):
         self.nova.server_groups.create.return_value = mock.Mock(id='123')
@@ -168,28 +172,31 @@ class NodePlacementTest(AbstractInstanceTest):
                        scheduler_hints={'group': "123"},
                        userdata=userdata,
                        key_name='user_keypair',
-                       security_groups=None),
+                       security_groups=None,
+                       availability_zone=None),
              mock.call('test_cluster-test_group_1-002',
                        "initial",
                        "test_flavor",
                        scheduler_hints={'group': "123"},
                        userdata=userdata,
                        key_name='user_keypair',
-                       security_groups=None),
+                       security_groups=None,
+                       availability_zone=None),
              mock.call('test_cluster-test_group_2-001',
                        "initial",
                        "test_flavor",
                        scheduler_hints={'group': "123"},
                        userdata=userdata,
                        key_name='user_keypair',
-                       security_groups=None)],
+                       security_groups=None,
+                       availability_zone=None)],
             any_order=False)
 
         ctx = context.ctx()
         cluster_obj = conductor.cluster_get_all(ctx)[0]
         inst_number = len(cluster_obj.node_groups[0].instances)
         inst_number += len(cluster_obj.node_groups[1].instances)
-        self.assertEqual(inst_number, 3)
+        self.assertEqual(3, inst_number)
 
 
 class IpManagementTest(AbstractInstanceTest):
@@ -218,7 +225,7 @@ class IpManagementTest(AbstractInstanceTest):
         self.nova.floating_ips.create.assert_has_calls(
             [mock.call("pool"), mock.call("pool")])
 
-        self.assertEqual(self.nova.floating_ips.create.call_count, 2,
+        self.assertEqual(2, self.nova.floating_ips.create.call_count,
                          "Not expected floating IPs number found.")
 
 
@@ -243,9 +250,9 @@ class ShutdownClusterTest(AbstractInstanceTest):
         deleted_checker.return_value = True
 
         self.engine._shutdown_instances(cluster)
-        self.assertEqual(self.nova.floating_ips.delete.call_count, 2,
+        self.assertEqual(2, self.nova.floating_ips.delete.call_count,
                          "Not expected floating IPs number found in delete")
-        self.assertEqual(self.nova.servers.delete.call_count, 2,
+        self.assertEqual(2, self.nova.servers.delete.call_count,
                          "Not expected")
 
 
@@ -312,6 +319,8 @@ def _mock_ips(count):
 def _generate_user_data_script(cluster):
     script_template = """#!/bin/bash
 echo "%(public_key)s" >> %(user_home)s/.ssh/authorized_keys\n
+# ====== COMMENT OUT Defaults requiretty in /etc/sudoers ========
+sed '/^Defaults    requiretty*/ s/^/#/' -i /etc/sudoers\n
 """
     return script_template % {
         "public_key": cluster.management_public_key,
