@@ -117,21 +117,11 @@ class TestClusterCreateValidation(u.ValidationTestCase):
                 'hadoop_version': "1.2.1",
                 'user_keypair_id': 'wrong_keypair'
             },
-            bad_req_i=(1, 'INVALID_REFERENCE',
+            bad_req_i=(1, 'NOT_FOUND',
                        "Requested keypair 'wrong_keypair' not found")
         )
 
     def test_cluster_create_v_keypair_type(self):
-        self._assert_create_object_validation(
-            data={
-                'name': "test-name",
-                'plugin_name': "vanilla",
-                'hadoop_version': "1.2.1",
-                'user_keypair_id': '1'
-            },
-            bad_req_i=(1, 'VALIDATION_ERROR',
-                       "'1' is not a 'valid_name'")
-        )
         self._assert_create_object_validation(
             data={
                 'name': "test-name",
@@ -139,7 +129,7 @@ class TestClusterCreateValidation(u.ValidationTestCase):
                 'hadoop_version': "1.2.1",
                 'user_keypair_id': '!'},
             bad_req_i=(1, 'VALIDATION_ERROR',
-                       "'!' is not a 'valid_name'")
+                       "'!' is not a 'valid_keypair_name'")
         )
 
     def test_cluster_create_v_image_exists(self):
@@ -178,8 +168,8 @@ class TestClusterCreateValidation(u.ValidationTestCase):
                 'neutron_management_network': '53a36917-ab9f-4589-'
                                               '94ce-b6df85a68332'
             },
-            bad_req_i=(1, 'INVALID_REFERENCE', "Network 53a36917-ab9f-4589-"
-                                               "94ce-b6df85a68332 not found")
+            bad_req_i=(1, 'NOT_FOUND', "Network 53a36917-ab9f-4589-"
+                                       "94ce-b6df85a68332 not found")
         )
 
     def test_cluster_create_mixed_nova_neutron(self):
@@ -228,7 +218,7 @@ class TestClusterCreateValidation(u.ValidationTestCase):
                     }
                 ]
             },
-            bad_req_i=(1, 'INVALID_REFERENCE',
+            bad_req_i=(1, 'INVALID_DATA',
                        "Composite hostname long-long-cluster-name-long-long-"
                        "long-very-long-node-group-name-100.novalocal "
                        "in provisioned cluster exceeds maximum limit 64 "
@@ -285,6 +275,74 @@ class TestClusterCreateValidation(u.ValidationTestCase):
             }
         )
 
+    def test_cluster_create_missing_floating_pool(self):
+        self.override_config("use_neutron", True)
+        self._assert_create_object_validation(
+            data={
+                'name': "testname",
+                'plugin_name': "vanilla",
+                'hadoop_version': "1.2.1",
+                'user_keypair_id': 'test_keypair',
+                'default_image_id': '550e8400-e29b-41d4-a716-446655440000',
+                'neutron_management_network': 'd9a3bebc-f788-4b81-'
+                                              '9a93-aa048022c1ca',
+                'node_groups': [
+                    {
+                        "name": "ng1",
+                        "node_processes": ["namenode"],
+                        "flavor_id": "42",
+                        "count": 100,
+                        'security_groups': ['group1', 'group2'],
+                        'floating_ip_pool':
+                            'd9a3bebc-f788-4b81-9a93-aa048022c1ca'
+                    },
+                    {
+                        "name": "ng2",
+                        "node_processes": ["datanode"],
+                        "flavor_id": "42",
+                        "count": 100,
+                        'security_groups': ['group1', 'group2']
+                    }
+                ]
+            },
+            bad_req_i=(1, 'MISSING_FLOATING_NETWORK',
+                       "Node Group ng2 is missing 'floating_ip_pool' "
+                       "field")
+        )
+
+    def test_cluster_create_with_proxy_gateway(self):
+        self.override_config("use_neutron", True)
+        self._assert_create_object_validation(
+            data={
+                'name': "testname",
+                'plugin_name': "vanilla",
+                'hadoop_version': "1.2.1",
+                'user_keypair_id': 'test_keypair',
+                'default_image_id': '550e8400-e29b-41d4-a716-446655440000',
+                'neutron_management_network': 'd9a3bebc-f788-4b81-'
+                                              '9a93-aa048022c1ca',
+                'node_groups': [
+                    {
+                        "name": "ng1",
+                        "node_processes": ["namenode"],
+                        "flavor_id": "42",
+                        "count": 100,
+                        'security_groups': ['group1', 'group2'],
+                        'floating_ip_pool':
+                            'd9a3bebc-f788-4b81-9a93-aa048022c1ca',
+                        "is_proxy_gateway": True
+                    },
+                    {
+                        "name": "ng2",
+                        "node_processes": ["datanode"],
+                        "flavor_id": "42",
+                        "count": 100,
+                        'security_groups': ['group1', 'group2']
+                    }
+                ]
+            }
+        )
+
     def test_cluster_create_security_groups_by_ids(self):
         self.override_config("use_neutron", True)
         self._assert_create_object_validation(
@@ -333,10 +391,95 @@ class TestClusterCreateValidation(u.ValidationTestCase):
                     }
                 ]
             },
-            bad_req_i=(1, 'INVALID_REFERENCE',
+            bad_req_i=(1, 'NOT_FOUND',
                        "Security group 'group3' not found")
         )
 
+    def test_cluster_create_availability_zone(self):
+        self.override_config('use_neutron', True)
+        self._assert_create_object_validation(
+            data={
+                'name': 'testname',
+                'plugin_name': 'vanilla',
+                'hadoop_version': '1.2.1',
+                'user_keypair_id': 'test_keypair',
+                'default_image_id': '550e8400-e29b-41d4-a716-446655440000',
+                'neutron_management_network': 'd9a3bebc-f788-4b81-'
+                                              '9a93-aa048022c1ca',
+                'node_groups': [
+                    {
+                        'name': 'nodegroup',
+                        'node_processes': ['namenode'],
+                        'flavor_id': '42',
+                        'count': 100,
+                        'security_groups': [],
+                        'floating_ip_pool':
+                            'd9a3bebc-f788-4b81-9a93-aa048022c1ca',
+                        'availability_zone': 'nova',
+                        'volumes_per_node': 1,
+                        'volumes_availability_zone': 'nova'
+                    }
+                ]
+            }
+        )
+
+    def test_cluster_create_wrong_availability_zone(self):
+        self.override_config('use_neutron', True)
+        self._assert_create_object_validation(
+            data={
+                'name': 'testname',
+                'plugin_name': 'vanilla',
+                'hadoop_version': '1.2.1',
+                'user_keypair_id': 'test_keypair',
+                'default_image_id': '550e8400-e29b-41d4-a716-446655440000',
+                'neutron_management_network': 'd9a3bebc-f788-4b81-'
+                                              '9a93-aa048022c1ca',
+                'node_groups': [
+                    {
+                        'name': 'nodegroup',
+                        'node_processes': ['namenode'],
+                        'flavor_id': '42',
+                        'count': 100,
+                        'security_groups': [],
+                        'floating_ip_pool':
+                            'd9a3bebc-f788-4b81-9a93-aa048022c1ca',
+                        'availability_zone': 'nonexistent'
+                    }
+                ]
+            },
+            bad_req_i=(1, 'NOT_FOUND',
+                       "Nova availability zone 'nonexistent' not found")
+        )
+
+    def test_cluster_create_wrong_volumes_availability_zone(self):
+        self.override_config('use_neutron', True)
+        self._assert_create_object_validation(
+            data={
+                'name': 'testname',
+                'plugin_name': 'vanilla',
+                'hadoop_version': '1.2.1',
+                'user_keypair_id': 'test_keypair',
+                'default_image_id': '550e8400-e29b-41d4-a716-446655440000',
+                'neutron_management_network': 'd9a3bebc-f788-4b81-'
+                                              '9a93-aa048022c1ca',
+                'node_groups': [
+                    {
+                        'name': 'nodegroup',
+                        'node_processes': ['namenode'],
+                        'flavor_id': '42',
+                        'count': 100,
+                        'security_groups': [],
+                        'floating_ip_pool':
+                            'd9a3bebc-f788-4b81-9a93-aa048022c1ca',
+                        'volumes_per_node': 1,
+                        'volumes_availability_zone': 'nonexistent'
+                    }
+                ]
+            },
+            bad_req_i=(1, 'NOT_FOUND',
+                       "Cinder availability zone 'nonexistent' not found")
+        )
+
 
 class TestClusterCreateFlavorValidation(base.SaharaWithDbTestCase):
     """Tests for valid flavor on cluster create.
@@ -466,13 +609,15 @@ class TestClusterCreateFlavorValidation(base.SaharaWithDbTestCase):
             'default_image_id': '550e8400-e29b-41d4-a716-446655440000'
         }
         for values in [data, data1]:
-            with testtools.ExpectedException(exceptions.InvalidException):
+            with testtools.ExpectedException(
+                    exceptions.NotFoundException):
                 patchers = u.start_patch(False)
                 try:
                     c.check_cluster_create(values)
-                except exceptions.InvalidException as e:
+                except exceptions.NotFoundException as e:
+                    message = six.text_type(e).split('\n')[0]
                     self.assertEqual("Requested flavor '10' not found",
-                                     six.text_type(e))
+                                     message)
                     raise e
                 finally:
                     u.stop_patch(patchers)
@@ -527,12 +672,14 @@ class TestClusterCreateFlavorValidation(base.SaharaWithDbTestCase):
             ],
             'default_image_id': '550e8400-e29b-41d4-a716-446655440000'
         }
-        with testtools.ExpectedException(exceptions.InvalidException):
+        with testtools.ExpectedException(exceptions.NotFoundException):
+            patchers = u.start_patch(False)
             try:
-                patchers = u.start_patch(False)
                 c.check_cluster_create(data)
-                u.stop_patch(patchers)
-            except exceptions.InvalidException as e:
+            except exceptions.NotFoundException as e:
+                message = six.text_type(e).split('\n')[0]
                 self.assertEqual("Requested flavor '23' not found",
-                                 six.text_type(e))
+                                 message)
                 raise e
+            finally:
+                u.stop_patch(patchers)
