@@ -37,6 +37,8 @@ class TestScalingValidation(u.ValidationTestCase):
         super(TestScalingValidation, self).setUp()
         api.plugin_base.setup_plugins()
         self._create_object_fun = mock.Mock()
+        self.duplicates_detected = ("Duplicates in node group names are"
+                                    " detected: ['a']")
 
     @mock.patch('sahara.service.api.get_cluster')
     @mock.patch('sahara.plugins.base.PluginManager.get_plugin')
@@ -44,21 +46,23 @@ class TestScalingValidation(u.ValidationTestCase):
                               get_plugin_p=None,
                               get_cluster_p=None,
                               data=None, cluster=None,
-                              expected_message=None):
+                              expected_message=None,
+                              expected_exception=ex.InvalidReferenceException):
 
         get_cluster_p.return_value = cluster
         get_plugin_p.side_effect = _get_plugin
 
-        with testtools.ExpectedException(ex.InvalidException):
+        with testtools.ExpectedException(expected_exception):
             try:
                 c_s.check_cluster_scaling(data, cluster.id)
-            except ex.InvalidException as e:
-                self.assertEqual(expected_message, six.text_type(e))
+            except expected_exception as e:
+                message = six.text_type(e).split('\n')[0]
+                self.assertEqual(expected_message, message)
                 raise e
 
-    @mock.patch("sahara.service.ops.get_engine_type_and_version",
-                return_value="direct.1.1")
-    def test_check_cluster_scaling_resize_ng(self, engine_version):
+    @mock.patch("sahara.service.api.OPS")
+    def test_check_cluster_scaling_resize_ng(self, ops):
+        ops.get_engine_type_and_version.return_value = "direct.1.1"
         ng1 = tu.make_ng_dict('ng', '42', ['namenode'], 1)
         cluster = tu.create_cluster("cluster1", "tenant1", "vanilla", "1.2.1",
                                     [ng1], status='Validating', id='12321')
@@ -99,12 +103,12 @@ class TestScalingValidation(u.ValidationTestCase):
         ]})
         self._assert_check_scaling(
             data=data, cluster=cluster,
-            expected_message='Duplicates in node '
-                             'group names are detected')
+            expected_message=self.duplicates_detected,
+            expected_exception=ex.InvalidDataException)
 
-    @mock.patch("sahara.service.ops.get_engine_type_and_version",
-                return_value="direct.1.1")
-    def test_check_cluster_scaling_add_ng(self, engine_version):
+    @mock.patch("sahara.service.api.OPS")
+    def test_check_cluster_scaling_add_ng(self, ops):
+        ops.get_engine_type_and_version.return_value = "direct.1.1"
         ng1 = tu.make_ng_dict('ng', '42', ['namenode'], 1)
         cluster = tu.create_cluster("test-cluster", "tenant", "vanilla",
                                     "1.2.1", [ng1], status='Active',
@@ -125,8 +129,8 @@ class TestScalingValidation(u.ValidationTestCase):
         }
         self._assert_check_scaling(
             data=data, cluster=cluster,
-            expected_message='Duplicates in node '
-                             'group names are detected')
+            expected_message=self.duplicates_detected,
+            expected_exception=ex.InvalidDataException)
         data = {
             'add_node_groups': [
                 {
@@ -158,7 +162,8 @@ class TestScalingValidation(u.ValidationTestCase):
             expected_message="Composite hostname test-cluster-very-"
                              "very-very-very-very-very-long-ng-name-"
                              "010.novalocal in provisioned cluster exceeds "
-                             "maximum limit 64 characters")
+                             "maximum limit 64 characters",
+            expected_exception=ex.InvalidDataException)
         u.stop_patch(patchers)
 
     @mock.patch("sahara.utils.api.request_data")
@@ -175,12 +180,12 @@ class TestScalingValidation(u.ValidationTestCase):
                    self._create_object_fun)(m_func)(data=data,
                                                     cluster_id='42')
 
-        self.assertEqual(req_data.call_count, 1)
+        self.assertEqual(1, req_data.call_count)
         self._assert_calls(bad_req, bad_req_i)
 
-    @mock.patch("sahara.service.ops.get_engine_type_and_version",
-                return_value="direct.1.1")
-    def test_cluster_scaling_scheme_v_resize_ng(self, engine_version):
+    @mock.patch("sahara.service.api.OPS")
+    def test_cluster_scaling_scheme_v_resize_ng(self, ops):
+        ops.get_engine_type_and_version.return_value = "direct.1.1"
         self._create_object_fun = mock.Mock()
         data = {
         }
@@ -210,9 +215,9 @@ class TestScalingValidation(u.ValidationTestCase):
                        u"'count' is a required property")
         )
 
-    @mock.patch("sahara.service.ops.get_engine_type_and_version",
-                return_value="direct.1.1")
-    def test_cluster_scaling_validation_add_ng(self, engine_version):
+    @mock.patch("sahara.service.api.OPS")
+    def test_cluster_scaling_validation_add_ng(self, ops):
+        ops.get_engine_type_and_version.return_value = "direct.1.1"
         data = {
             'add_node_groups': [
                 {
@@ -246,9 +251,9 @@ class TestScalingValidation(u.ValidationTestCase):
                        u"of the given schemas")
         )
 
-    @mock.patch("sahara.service.ops.get_engine_type_and_version",
-                return_value="direct.1.1")
-    def test_cluster_scaling_validation_right_schema(self, engine_version):
+    @mock.patch("sahara.service.api.OPS")
+    def test_cluster_scaling_validation_right_schema(self, ops):
+        ops.get_engine_type_and_version.return_value = "direct.1.1"
         data = {
             'add_node_groups': [
                 {
@@ -293,9 +298,9 @@ class TestScalingValidation(u.ValidationTestCase):
             data=data
         )
 
-    @mock.patch("sahara.service.ops.get_engine_type_and_version",
-                return_value="direct.1.1")
-    def test_cluster_scaling_scheme_validation_types(self, engine_version):
+    @mock.patch("sahara.service.api.OPS")
+    def test_cluster_scaling_scheme_validation_types(self, ops):
+        ops.get_engine_type_and_version.return_value = "direct.1.1"
         data = {
             'resize_node_groups': {},
         }
@@ -321,9 +326,9 @@ class TestScalingValidation(u.ValidationTestCase):
                        u'[] is too short')
         )
 
-    @mock.patch("sahara.service.ops.get_engine_type_and_version",
-                return_value="direct.1.1")
-    def test_cluster_scaling_v_right_data(self, engine_version):
+    @mock.patch("sahara.service.api.OPS")
+    def test_cluster_scaling_v_right_data(self, ops):
+        ops.get_engine_type_and_version.return_value = "direct.1.1"
         self._create_object_fun = c_s.check_cluster_scaling
 
         data = {
@@ -346,9 +351,9 @@ class TestScalingValidation(u.ValidationTestCase):
         self._assert_cluster_scaling_validation(data=data)
         u.stop_patch(patchers)
 
-    @mock.patch("sahara.service.ops.get_engine_type_and_version",
-                return_value="direct.1.1")
-    def test_check_cluster_scaling_wrong_engine(self, engine_version):
+    @mock.patch("sahara.service.api.OPS")
+    def test_check_cluster_scaling_wrong_engine(self, ops):
+        ops.get_engine_type_and_version.return_value = "direct.1.1"
         ng1 = tu.make_ng_dict('ng', '42', ['namenode'], 1)
         cluster = tu.create_cluster(
             "cluster1", "tenant1", "vanilla", "1.2.1", [ng1],
@@ -360,9 +365,9 @@ class TestScalingValidation(u.ValidationTestCase):
             expected_message="Cluster created with heat.1.1 infrastructure "
                              "engine can't be scaled with direct.1.1 engine")
 
-    @mock.patch("sahara.service.ops.get_engine_type_and_version",
-                return_value="heat.1.1")
-    def test_check_heat_cluster_scaling_missing_engine(self, engine_version):
+    @mock.patch("sahara.service.api.OPS")
+    def test_check_heat_cluster_scaling_missing_engine(self, ops):
+        ops.get_engine_type_and_version.return_value = "heat.1.1"
         ng1 = tu.make_ng_dict('ng', '42', ['namenode'], 1)
         cluster = tu.create_cluster("cluster1", "tenant1", "vanilla", "1.2.1",
                                     [ng1], status='Active', id='12321')
