@@ -14,6 +14,7 @@
 # limitations under the License.
 
 from sahara.service import api
+from sahara.service.validations import cluster_template_schema as ct_schema
 from sahara.service.validations import cluster_templates as ct
 from sahara.tests.unit.service.validation import utils as u
 
@@ -22,7 +23,7 @@ class TestClusterTemplateCreateValidation(u.ValidationTestCase):
     def setUp(self):
         super(TestClusterTemplateCreateValidation, self).setUp()
         self._create_object_fun = ct.check_cluster_template_create
-        self.scheme = ct.CLUSTER_TEMPLATE_SCHEMA
+        self.scheme = ct_schema.CLUSTER_TEMPLATE_SCHEMA
         api.plugin_base.setup_plugins()
 
     def test_cluster_template_create_v_cluster_configs(self):
@@ -94,7 +95,7 @@ class TestClusterTemplateCreateValidation(u.ValidationTestCase):
                     }
                 ]
             },
-            bad_req_i=(1, "INVALID_REFERENCE",
+            bad_req_i=(1, "INVALID_DATA",
                        "Duplicates in node group names are detected")
         )
 
@@ -235,8 +236,8 @@ class TestClusterTemplateCreateValidation(u.ValidationTestCase):
         }
         self._assert_create_object_validation(
             data=data,
-            bad_req_i=(1, 'INVALID_REFERENCE', "Network 53a36917-ab9f-4589-"
-                                               "94ce-b6df85a68332 not found")
+            bad_req_i=(1, 'NOT_FOUND', "Network 53a36917-ab9f-4589-"
+                                       "94ce-b6df85a68332 not found")
         )
 
     def test_cluster_create_v_default_image_required_tags(self):
