@@ -14,27 +14,24 @@
 # limitations under the License.
 
 import copy
-from unittest import mock
 
-
-from sahara.service.api import v10 as api
+from sahara.service import api
 from sahara.service.validations import cluster_template_schema as ct_schema
+from sahara.service.validations import cluster_templates as ct
 from sahara.tests.unit.service.validation import utils as u
 
 
 SAMPLE_DATA = {
     'name': 'testname',
-    'plugin_name': 'fake',
-    'hadoop_version': '0.1',
-    'is_public': False,
-    'is_protected': False
+    'plugin_name': 'vanilla',
+    'hadoop_version': '1.2.1'
 }
 
 
 class TestClusterTemplateUpdateValidation(u.ValidationTestCase):
     def setUp(self):
         super(TestClusterTemplateUpdateValidation, self).setUp()
-        self._create_object_fun = mock.Mock()
+        self._create_object_fun = ct.check_cluster_template_update
         self.scheme = ct_schema.CLUSTER_TEMPLATE_UPDATE_SCHEMA
         api.plugin_base.setup_plugins()
 
