@@ -14,6 +14,7 @@
 # limitations under the License.
 
 from sahara.service import api
+from sahara.service.validations import node_group_template_schema as ngt_schema
 from sahara.service.validations import node_group_templates as nt
 from sahara.tests.unit.service.validation import utils as u
 
@@ -22,7 +23,7 @@ class TestNGTemplateCreateValidation(u.ValidationTestCase):
     def setUp(self):
         super(TestNGTemplateCreateValidation, self).setUp()
         self._create_object_fun = nt.check_node_group_template_create
-        self.scheme = nt.NODE_GROUP_TEMPLATE_SCHEMA
+        self.scheme = ngt_schema.NODE_GROUP_TEMPLATE_SCHEMA
         api.plugin_base.setup_plugins()
 
     def test_node_groups_create_required(self):
@@ -89,7 +90,7 @@ class TestNGTemplateCreateValidation(u.ValidationTestCase):
                 'hadoop_version': '1.2.1',
                 'node_processes': ["namenode", "namenode"]
             },
-            bad_req_i=(1, 'INVALID_REFERENCE',
+            bad_req_i=(1, 'INVALID_DATA',
                        'Duplicates in node processes have been detected')
         )
         self._assert_create_object_validation(
@@ -101,9 +102,8 @@ class TestNGTemplateCreateValidation(u.ValidationTestCase):
                 'node_processes': ['wrong_process']
             },
             bad_req_i=(1, 'INVALID_REFERENCE',
-                       "Plugin supports the following node procesess: ["
-                       "'datanode', 'hiveserver', 'jobtracker', 'namenode', "
-                       "'oozie', 'secondarynamenode', 'tasktracker']")
+                       "Plugin doesn't support the following node processes: "
+                       "['wrong_process']")
         )
 
     def test_ng_template_create_v_right(self):
@@ -188,7 +188,7 @@ class TestNGTemplateCreateValidation(u.ValidationTestCase):
                 'hadoop_version': '1.2.1',
                 'node_processes': ['namenode']
             },
-            bad_req_i=(1, 'INVALID_REFERENCE',
+            bad_req_i=(1, 'NOT_FOUND',
                        "Requested flavor '1' not found")
         )
 
@@ -289,6 +289,6 @@ class TestNGTemplateCreateValidation(u.ValidationTestCase):
                 'node_processes': ['datanode', 'tasktracker'],
                 'floating_ip_pool': 'network_bad'
             },
-            bad_req_i=(1, 'INVALID_REFERENCE', "Floating IP pool network_bad "
-                                               "for node group 'a' not found")
+            bad_req_i=(1, 'NOT_FOUND', "Floating IP pool network_bad "
+                                       "not found")
         )
