@@ -13,15 +13,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import ast
 import re
 
 import mock
 import novaclient.exceptions as nova_ex
-import unittest2
+import six
 
 from sahara.conductor import resource as r
 from sahara.plugins.vanilla import plugin
 import sahara.service.validation as v
+from sahara.tests.unit import base
 from sahara.tests.unit import testutils as tu
 
 
@@ -70,6 +72,10 @@ def _get_fl_ip_pool_list():
     return [FakeNetwork("d9a3bebc-f788-4b81-9a93-aa048022c1ca")]
 
 
+def _get_availability_zone_list(detailed=True):
+    return [FakeAvailabilityZone('nova')]
+
+
 def _get_heat_stack_list():
     return [FakeStack('test-heat')]
 
@@ -84,34 +90,50 @@ class FakeNetwork(object):
         self.name = name
 
 
+class FakeAvailabilityZone(object):
+    def __init__(self, name):
+        self.zoneName = name
+
+
 class FakeFlavor(object):
     def __init__(self, id):
         self.id = id
 
 
+class FakeSecurityGroup(object):
+    def __init__(self, id, name):
+        self.id = id
+        self.name = name
+
+
 def _get_flavors_list():
     return [FakeFlavor("42")]
 
 
+def _get_security_groups_list():
+    return [FakeSecurityGroup("1", "default"),
+            FakeSecurityGroup("2", "group1"),
+            FakeSecurityGroup("3", "group2")]
+
+
 def start_patch(patch_templates=True):
     get_clusters_p = mock.patch("sahara.service.api.get_clusters")
     get_cluster_p = mock.patch("sahara.service.api.get_cluster")
     if patch_templates:
-        get_ng_templates_p = \
-            mock.patch("sahara.service.api.get_node_group_templates")
-        get_ng_template_p = \
-            mock.patch("sahara.service.api.get_node_group_template")
-    get_plugins_p = mock.patch("sahara.service.api.get_plugins")
-    get_plugin_p = \
-        mock.patch("sahara.plugins.base.PluginManager.get_plugin")
+        get_ng_templates_p = mock.patch(
+            "sahara.service.api.get_node_group_templates")
+        get_ng_template_p = mock.patch(
+            "sahara.service.api.get_node_group_template")
     if patch_templates:
-        get_cl_templates_p = \
-            mock.patch("sahara.service.api.get_cluster_templates")
-        get_cl_template_p = \
-            mock.patch("sahara.service.api.get_cluster_template")
+        get_cl_templates_p = mock.patch(
+            "sahara.service.api.get_cluster_templates")
+        get_cl_template_p = mock.patch(
+            "sahara.service.api.get_cluster_template")
     nova_p = mock.patch("sahara.utils.openstack.nova.client")
-    keystone_p = mock.patch("sahara.utils.openstack.keystone.client")
     heat_p = mock.patch("sahara.utils.openstack.heat.client")
+    cinder_p = mock.patch("sahara.utils.openstack.cinder.client")
+    cinder_exists_p = mock.patch(
+        "sahara.utils.openstack.cinder.check_cinder_exists")
     get_image_p = mock.patch("sahara.service.api.get_image")
 
     get_image = get_image_p.start()
@@ -120,37 +142,32 @@ def start_patch(patch_templates=True):
     if patch_templates:
         get_ng_templates = get_ng_templates_p.start()
         get_ng_template = get_ng_template_p.start()
-    get_plugins = get_plugins_p.start()
-    get_plugin = get_plugin_p.start()
     if patch_templates:
         get_cl_templates = get_cl_templates_p.start()
         get_cl_template_p.start()
 
     nova = nova_p.start()
-    keystone = keystone_p.start()
 
     if patch_templates:
         get_cl_templates.return_value = []
 
     nova().flavors.list.side_effect = _get_flavors_list
+    nova().security_groups.list.side_effect = _get_security_groups_list
     nova().keypairs.get.side_effect = _get_keypair
     nova().networks.find.side_effect = _get_network
     nova().floating_ip_pools.list.side_effect = _get_fl_ip_pool_list
+    nova().availability_zones.list.side_effect = _get_availability_zone_list
 
     heat = heat_p.start()
     heat().stacks.list.side_effect = _get_heat_stack_list
 
-    class Service:
-        @property
-        def name(self):
-            return 'cinder'
+    cinder = cinder_p.start()
+    cinder().availability_zones.list.side_effect = _get_availability_zone_list
 
-    def _services_list():
-        return [Service()]
+    cinder_exists = cinder_exists_p.start()
+    cinder_exists.return_value = True
 
-    keystone().services.list.side_effect = _services_list
-
-    class Image:
+    class Image(object):
         def __init__(self, name='test'):
             self.name = name
 
@@ -188,7 +205,6 @@ def start_patch(patch_templates=True):
     if patch_templates:
         ngt_dict = {'name': 'test', 'tenant_id': 't', 'flavor_id': '42',
                     'plugin_name': 'vanilla', 'hadoop_version': '1.2.1',
-                    #'id': '1234321',
                     'id': '550e8400-e29b-41d4-a716-446655440000',
                     'node_processes': ['namenode']}
 
@@ -199,27 +215,18 @@ def start_patch(patch_templates=True):
 
         get_cl_templates.return_value = [r.ClusterTemplateResource(ct_dict)]
 
-    vanilla = plugin.VanillaProvider()
-    vanilla.name = 'vanilla'
-    get_plugins.return_value = [vanilla]
-
     def _get_ng_template(id):
         for template in get_ng_templates():
             if template.id == id:
                 return template
         return None
 
-    def _get_plugin(name):
-        if name == 'vanilla':
-            return vanilla
-        return None
-
-    get_plugin.side_effect = _get_plugin
     if patch_templates:
         get_ng_template.side_effect = _get_ng_template
     # request data to validate
-    patchers = [get_clusters_p, get_cluster_p, get_plugins_p, get_plugin_p,
-                nova_p, keystone_p, get_image_p, heat_p]
+    patchers = [get_clusters_p, get_cluster_p,
+                nova_p, get_image_p, heat_p, cinder_p,
+                cinder_exists_p]
     if patch_templates:
         patchers.extend([get_ng_template_p, get_ng_templates_p,
                          get_cl_template_p, get_cl_templates_p])
@@ -227,32 +234,58 @@ def start_patch(patch_templates=True):
 
 
 def stop_patch(patchers):
-    for patcher in patchers:
+    for patcher in reversed(patchers):
         patcher.stop()
 
 
-class ValidationTestCase(unittest2.TestCase):
+class ValidationTestCase(base.SaharaTestCase):
     def setUp(self):
+        super(ValidationTestCase, self).setUp()
         self._create_object_fun = None
         self.scheme = None
 
     def tearDown(self):
         self._create_object_fun = None
+        super(ValidationTestCase, self).tearDown()
 
     def _assert_calls(self, mock, call_info):
         if not call_info:
-            self.assertEqual(mock.call_count, 0)
+            self.assertEqual(0, mock.call_count)
         else:
-            self.assertEqual(mock.call_count, call_info[0])
-            self.assertEqual(mock.call_args[0][0].code, call_info[1])
+            self.assertEqual(call_info[0], mock.call_count)
+            self.assertEqual(call_info[1], mock.call_args[0][0].code)
+            possible_messages = ([call_info[2]] if isinstance(
+                call_info[2], six.string_types) else call_info[2])
+            match = False
+            check = mock.call_args[0][0].message
+            if check.find('Error ID:') != -1:
+                check = check.split('\n')[0]
+            for message in possible_messages:
+                if self._check_match(message, check):
+                    match = True
+                    break
+            if not match:
+                self.assertIn(check, possible_messages)
 
-            # Note(slukjanov): the call_info[2] is an expected validation
-            #                  message regex; regex needed because of different
-            #                  versions of jsonschema generates different
-            #                  messages.
-            if not re.match(call_info[2], mock.call_args[0][0].message):
-                self.assertEqual(call_info[2], mock.call_args[0][0].message,
-                                 "Validation message didn't match expected")
+    def _check_match(self, expected, actual):
+        d1, r1 = self._extract_printed_dict(expected)
+        d2, r2 = self._extract_printed_dict(actual)
+
+        # Note(slukjanov): regex needed because of different
+        #                  versions of jsonschema generate different
+        #                  messages.
+        return (r1 == r2 or re.match(r1, r2)) and (d1 == d2)
+
+    def _extract_printed_dict(self, s):
+        start = s.find('{')
+        if start == -1:
+            return None, s
+
+        end = s.rfind('}')
+        if end == -1:
+            return None, s
+
+        return ast.literal_eval(s[start:end+1]), s[0:start+1] + s[end]
 
     @mock.patch("sahara.utils.api.request_data")
     @mock.patch("sahara.utils.api.bad_request")
@@ -267,7 +300,7 @@ class ValidationTestCase(unittest2.TestCase):
         m_func.__name__ = "m_func"
         v.validate(self.scheme, self._create_object_fun)(m_func)(data=data)
 
-        self.assertEqual(request_data.call_count, 1)
+        self.assertEqual(1, request_data.call_count)
         self._assert_calls(bad_req, bad_req_i)
         stop_patch(patchers)
 
@@ -309,20 +342,15 @@ class ValidationTestCase(unittest2.TestCase):
                     if isinstance(value, str):
                         value_str = "'%s'" % value_str
                     data.update({p_name: value})
+                    message = ("%s is not of type '%s'" %
+                               (value_str, prop["type"]))
                     if "enum" in prop:
-                        self._assert_create_object_validation(
-                            data=data,
-                            bad_req_i=(1, 'VALIDATION_ERROR',
-                                       u"%s is not one of %s"
-                                       % (value_str, prop["enum"]))
-                        )
-                    else:
-                        self._assert_create_object_validation(
-                            data=data,
-                            bad_req_i=(1, 'VALIDATION_ERROR',
-                                       u"%s is not of type '%s'"
-                                       % (value_str, prop["type"]))
-                        )
+                        message = [message, "%s is not one of %s" %
+                                            (value_str, prop["enum"])]
+                    self._assert_create_object_validation(
+                        data=data,
+                        bad_req_i=(1, 'VALIDATION_ERROR', message)
+                    )
 
     def _assert_cluster_configs_validation(self, require_image_id=False):
         data = {
