@@ -35,7 +35,9 @@ def make_ng_dict(name, flavor, processes, count, instances=None, **kwargs):
     dct = {'name': name, 'flavor_id': flavor, 'node_processes': processes,
            'count': count, 'instances': instances, 'node_configs': {},
            'security_groups': None, 'auto_security_group': False,
-           'open_ports': []}
+           'availability_zone': None, 'volumes_availability_zone': None,
+           'open_ports': [], 'is_proxy_gateway': False,
+           'volume_local_to_instance': False}
     dct.update(kwargs)
     return dct
 
