@@ -13,10 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import uuid
 
-from unittest import mock
-
-from oslo_utils import uuidutils
+import mock
 
 from sahara import conductor
 from sahara import context
@@ -27,12 +26,9 @@ from sahara.utils import cluster_progress_ops as cpo
 
 class FakeInstance(object):
     def __init__(self):
-        self.id = uuidutils.generate_uuid()
-        self.name = uuidutils.generate_uuid()
-        self.cluster_id = uuidutils.generate_uuid()
-        self.node_group_id = uuidutils.generate_uuid()
-        self.instance_id = uuidutils.generate_uuid()
-        self.instance_name = uuidutils.generate_uuid()
+        self.id = uuid.uuid4()
+        self.name = uuid.uuid4()
+        self.cluster_id = uuid.uuid4()
 
 
 class ClusterProgressOpsTest(base.SaharaWithDbTestCase):
@@ -79,7 +75,7 @@ class ClusterProgressOpsTest(base.SaharaWithDbTestCase):
         result_cluster = self.api.cluster_get(ctx, cluster.id)
         result_step = result_cluster.provision_progress[0]
 
-        self.assertTrue(result_step.successful)
+        self.assertEqual(True, result_step.successful)
 
         # check updating in case of failed provision step
 
@@ -99,7 +95,7 @@ class ClusterProgressOpsTest(base.SaharaWithDbTestCase):
 
         for step in result_cluster.provision_progress:
             if step.id == step_id2:
-                self.assertFalse(step.successful)
+                self.assertEqual(False, step.successful)
 
         # check that it's possible to add provision step after failed step
         step_id3 = cpo.add_provisioning_step(cluster.id, "some_name", 2)
@@ -166,7 +162,7 @@ class ClusterProgressOpsTest(base.SaharaWithDbTestCase):
         pass
 
     @mock.patch('sahara.utils.cluster_progress_ops._find_in_args')
-    @mock.patch('sahara.utils.cluster.check_cluster_exists')
+    @mock.patch('sahara.utils.general.check_cluster_exists')
     def test_event_wrapper(self, p_check_cluster_exists, p_find):
         self.override_config("disable_event_log", True)
         self._do_nothing()
@@ -194,55 +190,3 @@ class ClusterProgressOpsTest(base.SaharaWithDbTestCase):
         self.assertEqual("Some name", step.step_name)
         self.assertEqual(3, step.total)
         self.assertEqual("INFO", step.events[0].event_info)
-
-    @mock.patch('sahara.context.ctx')
-    @mock.patch(
-        'sahara.utils.cluster_progress_ops.get_current_provisioning_step',
-        return_value='step_id')
-    @mock.patch('sahara.utils.cluster_progress_ops.conductor')
-    def test_add_successful_event(self, conductor, get_step, ctx):
-        instance = FakeInstance()
-
-        self.override_config("disable_event_log", True)
-        cpo.add_successful_event(instance)
-        self.assertEqual(0, conductor.cluster_event_add.call_count)
-
-        self.override_config("disable_event_log", False)
-        cpo.add_successful_event(instance)
-        self.assertEqual(1, conductor.cluster_event_add.call_count)
-        args, kwargs = conductor.cluster_event_add.call_args
-        self.assertEqual('step_id', args[1])
-        req_dict = {
-            'successful': True,
-            'node_group_id': instance.node_group_id,
-            'instance_id': instance.instance_id,
-            'instance_name': instance.instance_name,
-            'event_info': None,
-        }
-        self.assertEqual(req_dict, args[2])
-
-    @mock.patch('sahara.context.ctx')
-    @mock.patch(
-        'sahara.utils.cluster_progress_ops.get_current_provisioning_step',
-        return_value='step_id')
-    @mock.patch('sahara.utils.cluster_progress_ops.conductor')
-    def test_add_fail_event(self, conductor, get_step, ctx):
-        instance = FakeInstance()
-
-        self.override_config("disable_event_log", True)
-        cpo.add_fail_event(instance, Exception('oops'))
-        self.assertEqual(0, conductor.cluster_event_add.call_count)
-
-        self.override_config("disable_event_log", False)
-        cpo.add_fail_event(instance, Exception('oops'))
-        self.assertEqual(1, conductor.cluster_event_add.call_count)
-        args, kwargs = conductor.cluster_event_add.call_args
-        self.assertEqual('step_id', args[1])
-        req_dict = {
-            'successful': False,
-            'node_group_id': instance.node_group_id,
-            'instance_id': instance.instance_id,
-            'instance_name': instance.instance_name,
-            'event_info': 'oops',
-        }
-        self.assertEqual(req_dict, args[2])
