@@ -15,11 +15,13 @@
 
 import hashlib
 
-from oslo.config import cfg
+from oslo_config import cfg
+from oslo_log import log
 
 from sahara import context
 from sahara import exceptions as ex
-from sahara.openstack.common import log
+from sahara.i18n import _
+from sahara.i18n import _LW
 from sahara.utils.openstack import nova
 from sahara.utils import xmlutils as x
 
@@ -36,31 +38,25 @@ LOG = log.getLogger(__name__)
 opts = [
     cfg.BoolOpt('enable_data_locality',
                 default=False,
-                help="""Enables data locality for hadoop cluster.
-                 Also enables data locality for Swift used by hadoop.
-                 If enabled, 'compute_topology' and 'swift_topology'
-                 configuration parameters should point to OpenStack and Swift
-                 topology correspondingly."""),
+                help="Enables data locality for hadoop cluster. "
+                     "Also enables data locality for Swift used by hadoop. "
+                     "If enabled, 'compute_topology' and 'swift_topology' "
+                     "configuration parameters should point to OpenStack and "
+                     "Swift topology correspondingly."),
     cfg.BoolOpt('enable_hypervisor_awareness',
                 default=True,
-                help="""Enables four-level topology for data locality.
-                Works only if corresponding plugin supports such mode."""),
+                help="Enables four-level topology for data locality. "
+                     "Works only if corresponding plugin supports such mode."),
     cfg.StrOpt('compute_topology_file',
                default='etc/sahara/compute.topology',
-               help="""File with nova compute topology.
-                It should contain mapping between nova computes and racks.
-                File format:
-                compute1 /rack1
-                compute2 /rack2
-                compute3 /rack2"""),
+               help="File with nova compute topology. "
+                    "It should contain mapping between nova computes and "
+                    "racks."),
     cfg.StrOpt('swift_topology_file',
                default='etc/sahara/swift.topology',
-               help="""File with Swift topology.
-                It should contain mapping between Swift nodes and racks.
-                File format:
-                node1 /rack1
-                node2 /rack2
-                node3 /rack2""")
+               help="File with Swift topology."
+                    "It should contain mapping between Swift nodes and "
+                    "racks.")
 ]
 
 CONF = cfg.CONF
@@ -68,6 +64,8 @@ CONF.register_opts(opts)
 
 
 def _read_swift_topology():
+    LOG.debug("Reading Swift nodes topology from {config}".format(
+              config=CONF.swift_topology_file))
     topology = {}
     try:
         with open(CONF.swift_topology_file) as f:
@@ -78,13 +76,16 @@ def _read_swift_topology():
                 (host, path) = line.split()
                 topology[host] = path
     except IOError:
-        raise ex.NotFoundException(
-            CONF.swift_topology_file,
-            "Unable to find file %s with Swift topology")
+        LOG.warning(_LW("Unable to read Swift nodes topology from {config}")
+                    .format(config=CONF.swift_topology_file))
+        return {}
+
     return topology
 
 
 def _read_compute_topology():
+    LOG.debug("Reading compute nodes topology from {config}".format(
+              config=CONF.compute_topology_file))
     ctx = context.ctx()
     tenant_id = str(ctx.tenant_id)
     topology = {}
@@ -95,16 +96,16 @@ def _read_compute_topology():
                 if not line:
                     continue
                 (host, path) = line.split()
-                #calulating host id based on tenant id and host
-                #using the same algorithm as in nova
-                #see nova/api/openstack/compute/views/servers.py
-                #def _get_host_id(instance):
+                # Calulating host id based on tenant id and host
+                # using the same algorithm as in nova
+                # see nova/api/openstack/compute/views/servers.py
+                # def _get_host_id(instance):
                 sha_hash = hashlib.sha224(tenant_id + host)
                 topology[sha_hash.hexdigest()] = path
     except IOError:
         raise ex.NotFoundException(
             CONF.compute_topology_file,
-            "Unable to find file %s with compute topology")
+            _("Unable to find file %s with compute topology"))
     return topology
 
 
@@ -114,13 +115,13 @@ def generate_topology_map(cluster, is_node_awareness):
     topology_mapping = {}
     for ng in cluster.node_groups:
         for i in ng.instances:
-            #TODO(alazarev) get all servers info with one request
+            # TODO(alazarev) get all servers info with one request
             ni = nova_client.servers.get(i.instance_id)
             hostId = ni.hostId
             if hostId not in mapping:
                 raise ex.NotFoundException(
-                    i.instance_id, "Was not able to find compute node "
-                                   "topology for VM %s")
+                    i.instance_id,
+                    _("Was not able to find compute node topology for VM %s"))
             rack = mapping[hostId]
             if is_node_awareness:
                 rack += "/" + hostId
@@ -145,16 +146,16 @@ def vm_awareness_core_config():
         if param:
             param['value'] = 'org.apache.hadoop.net.NetworkTopology'
 
-    LOG.info("Vm awareness will add following configs in core-site "
-             "params: %s", result)
+    LOG.debug("Vm awareness will add following configs in core-site "
+              "params: {result}".format(result=result))
     return result
 
 
 def vm_awareness_mapred_config():
     c = x.load_hadoop_xml_defaults('topology/resources/mapred-template.xml')
     result = [cfg for cfg in c if cfg['value']]
-    LOG.info("Vm awareness will add following configs in map-red "
-             "params: %s", result)
+    LOG.debug("Vm awareness will add following configs in map-red "
+              "params: {result}".format(result=result))
     return result
 
 
