@@ -16,12 +16,14 @@
 import traceback
 
 import flask
+from oslo_log import log as logging
 from werkzeug import datastructures
 
 from sahara import context
 from sahara import exceptions as ex
-from sahara.openstack.common import log as logging
-from sahara.openstack.common import wsgi
+from sahara.i18n import _
+from sahara.i18n import _LE
+from sahara.utils import wsgi
 
 
 LOG = logging.getLogger(__name__)
@@ -61,7 +63,8 @@ class Rest(flask.Blueprint):
             def handler(**kwargs):
                 context.set_ctx(None)
 
-                LOG.debug("Rest.route.decorator.handler, kwargs=%s", kwargs)
+                LOG.debug("Rest.route.decorator.handler, kwargs={kwargs}"
+                          .format(kwargs=kwargs))
 
                 _init_resp_type(file_upload)
 
@@ -85,6 +88,8 @@ class Rest(flask.Blueprint):
 
                 try:
                     return func(**kwargs)
+                except ex.Forbidden as e:
+                    return access_denied(e)
                 except ex.SaharaException as e:
                     return bad_request(e)
                 except Exception as e:
@@ -131,7 +136,8 @@ def render(res=None, resp_type=None, status=None, **kwargs):
         res.update(kwargs)
     elif kwargs:
         # can't merge kwargs into the non-dict res
-        abort_and_log(500, "Non-dict and non-empty kwargs passed to render")
+        abort_and_log(500,
+                      _("Non-dict and non-empty kwargs passed to render"))
 
     status_code = getattr(flask.request, 'status_code', None)
     if status:
@@ -153,7 +159,7 @@ def render(res=None, resp_type=None, status=None, **kwargs):
         resp_type = RT_XML
         serializer = wsgi.XMLDictSerializer()
     else:
-        abort_and_log(400, "Content type '%s' isn't supported" % resp_type)
+        abort_and_log(400, _("Content type '%s' isn't supported") % resp_type)
 
     body = serializer.serialize(res)
     resp_type = str(resp_type)
@@ -178,10 +184,11 @@ def request_data():
     if not content_type or content_type in RT_JSON:
         deserializer = wsgi.JSONDeserializer()
     elif content_type in RT_XML:
-        abort_and_log(400, "XML requests are not supported yet")
+        abort_and_log(400, _("XML requests are not supported yet"))
         # deserializer = XMLDeserializer()
     else:
-        abort_and_log(400, "Content type '%s' isn't supported" % content_type)
+        abort_and_log(400,
+                      _("Content type '%s' isn't supported") % content_type)
 
     # parsed request data to avoid unwanted re-parsings
     parsed_data = deserializer.deserialize(flask.request.data)['body']
@@ -195,8 +202,9 @@ def get_request_args():
 
 
 def abort_and_log(status_code, descr, exc=None):
-    LOG.error("Request aborted with status code %s and message '%s'",
-              status_code, descr)
+    LOG.error(_LE("Request aborted with status code {code} and "
+                  "message '{message}'").format(code=status_code,
+                                                message=descr))
 
     if exc is not None:
         LOG.error(traceback.format_exc())
@@ -218,8 +226,9 @@ def render_error_message(error_code, error_message, error_name):
 
 
 def internal_error(status_code, descr, exc=None):
-    LOG.error("Request aborted with status code %s and message '%s'",
-              status_code, descr)
+    LOG.error(_LE("Request aborted with status code {code} and "
+                  "message '{message}'").format(code=status_code,
+                                                message=descr))
 
     if exc is not None:
         LOG.error(traceback.format_exc())
@@ -234,9 +243,23 @@ def internal_error(status_code, descr, exc=None):
 def bad_request(error):
     error_code = 400
 
-    LOG.debug("Validation Error occurred: "
-              "error_code=%s, error_message=%s, error_name=%s",
-              error_code, error.message, error.code)
+    LOG.error(_LE("Validation Error occurred: "
+                  "error_code={code}, error_message={message}, "
+                  "error_name={name}").format(code=error_code,
+                                              message=error.message,
+                                              name=error.code))
+
+    return render_error_message(error_code, error.message, error.code)
+
+
+def access_denied(error):
+    error_code = 403
+
+    LOG.error(_LE("Access Denied: "
+                  "error_code={code}, error_message={message}, "
+                  "error_name={name}").format(code=error_code,
+                                              message=error.message,
+                                              name=error.code))
 
     return render_error_message(error_code, error.message, error.code)
 
@@ -244,8 +267,10 @@ def bad_request(error):
 def not_found(error):
     error_code = 404
 
-    LOG.debug("Not Found exception occurred: "
-              "error_code=%s, error_message=%s, error_name=%s",
-              error_code, error.message, error.code)
+    LOG.error(_LE("Not Found exception occurred: "
+                  "error_code={code}, error_message={message}, "
+                  "error_name={name}").format(code=error_code,
+                                              message=error.message,
+                                              name=error.code))
 
     return render_error_message(error_code, error.message, error.code)
