@@ -13,6 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import uuid
+
+import six
+
+from sahara.utils import files
+
 # job execution status
 JOB_STATUS_DONEWITHERROR = 'DONEWITHERROR'
 JOB_STATUS_FAILED = 'FAILED'
@@ -20,6 +26,7 @@ JOB_STATUS_KILLED = 'KILLED'
 JOB_STATUS_PENDING = 'PENDING'
 JOB_STATUS_RUNNING = 'RUNNING'
 JOB_STATUS_SUCCEEDED = 'SUCCEEDED'
+JOB_STATUS_TOBEKILLED = 'TOBEKILLED'
 # statuses for terminated jobs
 JOB_STATUSES_TERMINATED = [
     JOB_STATUS_DONEWITHERROR,
@@ -40,6 +47,8 @@ JOB_TYPE_SPARK = 'Spark'
 JOB_TYPE_MAPREDUCE_STREAMING = (JOB_TYPE_MAPREDUCE + JOB_TYPE_SEP +
                                 JOB_SUBTYPE_STREAMING)
 JOB_TYPE_PIG = 'Pig'
+JOB_TYPE_SHELL = 'Shell'
+
 # job type groupings available
 JOB_TYPES_ALL = [
     JOB_TYPE_HIVE,
@@ -47,9 +56,14 @@ JOB_TYPES_ALL = [
     JOB_TYPE_MAPREDUCE,
     JOB_TYPE_MAPREDUCE_STREAMING,
     JOB_TYPE_PIG,
+    JOB_TYPE_SHELL,
     JOB_TYPE_SPARK
 ]
 
+ADAPT_FOR_OOZIE = 'edp.java.adapt_for_oozie'
+
+ADAPT_SPARK_FOR_SWIFT = 'edp.spark.adapt_for_swift'
+
 
 def split_job_type(job_type):
     '''Split a job type string into a type and subtype
@@ -84,3 +98,21 @@ def compare_job_type(job_type, *args, **kwargs):
 
 def get_hive_shared_conf_path(hdfs_user):
     return "/user/%s/conf/hive-site.xml" % hdfs_user
+
+
+def is_adapt_for_oozie_enabled(configs):
+    return configs.get(ADAPT_FOR_OOZIE, False)
+
+
+def is_adapt_spark_for_swift_enabled(configs):
+    return configs.get(ADAPT_SPARK_FOR_SWIFT, False)
+
+
+def get_builtin_binaries(job, configs):
+    if job.type == JOB_TYPE_JAVA:
+        if is_adapt_for_oozie_enabled(configs):
+            path = 'service/edp/resources/edp-main-wrapper.jar'
+            name = 'builtin-%s.jar' % six.text_type(uuid.uuid4())
+            return [{'raw': files.get_file_text(path),
+                     'name': name}]
+    return []
