@@ -13,17 +13,22 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import re
+
+from oslo_log import log as logging
 import six
 
 from sahara import conductor as c
 from sahara import context
+from sahara import exceptions as e
 from sahara.i18n import _LI
-from sahara.openstack.common import log as logging
 from sahara.utils.notification import sender
 
 conductor = c.API
 LOG = logging.getLogger(__name__)
 
+NATURAL_SORT_RE = re.compile('([0-9]+)')
+
 
 def find_dict(iterable, **rules):
     """Search for dict in iterable of dicts using specified key-value rules."""
@@ -61,25 +66,55 @@ def get_by_id(lst, id):
     return None
 
 
-def change_cluster_status(cluster, status, status_description=None):
+# Taken from http://stackoverflow.com/questions/4836710/does-
+# python-have-a-built-in-function-for-string-natural-sort
+def natural_sort_key(s):
+    return [int(text) if text.isdigit() else text.lower()
+            for text in re.split(NATURAL_SORT_RE, s)]
+
+
+def change_cluster_status_description(cluster, status_description):
     if cluster is None:
         return None
+    try:
+        ctx = context.ctx()
+        return conductor.cluster_update(
+            ctx, cluster, {'status_description': status_description})
+    except e.NotFoundException:
+        return None
+
+
+def change_cluster_status(cluster, status, status_description=None):
+    ctx = context.ctx()
+
+    # Update cluster status. Race conditions with deletion are still possible,
+    # but this reduces probability at least.
+    cluster = conductor.cluster_get(ctx, cluster) if cluster else None
+
+    if status_description is not None:
+        change_cluster_status_description(cluster, status_description)
+
+    # 'Deleting' is final and can't be changed
+    if cluster is None or cluster.status == 'Deleting':
+        return cluster
 
     update_dict = {"status": status}
-    if status_description:
-        update_dict["status_description"] = status_description
+    cluster = conductor.cluster_update(ctx, cluster, update_dict)
+    conductor.cluster_provision_progress_update(ctx, cluster.id)
 
-    cluster = conductor.cluster_update(context.ctx(), cluster, update_dict)
+    LOG.info(_LI("Cluster status has been changed: id={id}, New status="
+                 "{status}").format(id=cluster.id, status=cluster.status))
 
-    LOG.info(_LI("Cluster status has been changed: id=%(id)s, New status="
-                 "%(status)s"), {'id': cluster.id, 'status': cluster.status})
-
-    sender.notify(context.ctx(), cluster.id, cluster.name, cluster.status,
+    sender.notify(ctx, cluster.id, cluster.name, cluster.status,
                   "update")
 
     return cluster
 
 
+def count_instances(cluster):
+    return sum([node_group.count for node_group in cluster.node_groups])
+
+
 def check_cluster_exists(cluster):
     ctx = context.ctx()
     # check if cluster still exists (it might have been removed)
@@ -121,8 +156,9 @@ def generate_instance_name(cluster_name, node_group_name, index):
     return ("%s-%s-%03d" % (cluster_name, node_group_name, index)).lower()
 
 
-def generate_auto_security_group_name(cluster_name, node_group_name):
-    return ("%s-%s" % (cluster_name, node_group_name)).lower()
+def generate_auto_security_group_name(node_group):
+    return ("%s-%s-%s" % (node_group.cluster.name, node_group.name,
+                          node_group.id[:8])).lower()
 
 
 def generate_aa_group_name(cluster_name):
