@@ -14,13 +14,31 @@
 # limitations under the License.
 
 from novaclient import exceptions as nova_ex
-from novaclient.v1_1 import client as nova_client
+from novaclient.v2 import client as nova_client
+from oslo_config import cfg
 
 from sahara import context
 import sahara.utils.openstack.base as base
 from sahara.utils.openstack import images
 
 
+opts = [
+    cfg.BoolOpt('api_insecure',
+                default=False,
+                help='Allow to perform insecure SSL requests to nova.'),
+    cfg.StrOpt('ca_file',
+               help='Location of ca certificates file to use for nova '
+                    'client requests.')
+]
+
+nova_group = cfg.OptGroup(name='nova',
+                          title='Nova client options')
+
+CONF = cfg.CONF
+CONF.register_group(nova_group)
+CONF.register_opts(opts, group=nova_group)
+
+
 def client():
     ctx = context.current()
     auth_url = base.retrieve_auth_url()
@@ -29,9 +47,11 @@ def client():
     nova = nova_client.Client(username=ctx.username,
                               api_key=None,
                               project_id=ctx.tenant_id,
-                              auth_url=auth_url)
+                              auth_url=auth_url,
+                              cacert=CONF.nova.ca_file,
+                              insecure=CONF.nova.api_insecure)
 
-    nova.client.auth_token = ctx.token
+    nova.client.auth_token = ctx.auth_token
     nova.client.management_url = compute_url
     nova.images = images.SaharaImageManager(nova)
     return nova
@@ -51,7 +71,7 @@ def get_images():
 
 def get_limits():
     limits = client().limits.get().absolute
-    return dict((l.name, l.value) for l in limits)
+    return {l.name: l.value for l in limits}
 
 
 def get_user_keypair(cluster):
