@@ -13,21 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import uuid
 
 from oslo_config import cfg
 from oslo_log import log as logging
-from oslo_utils import uuidutils
 import six
 
 from sahara import conductor as c
 from sahara import context
 from sahara import exceptions as ex
 from sahara.i18n import _
-from sahara.service.castellan import utils as key_manager
 from sahara.service.edp import job_utils
 from sahara.service import trusts as t
 from sahara.swift import utils as su
-from sahara.utils.openstack import base as b
 from sahara.utils.openstack import keystone as k
 
 
@@ -47,7 +45,7 @@ opts = [
                help='The domain Sahara will use to create new proxy users '
                     'for Swift object access.'),
     cfg.ListOpt('proxy_user_role_names',
-                default=['member'],
+                default=['Member'],
                 help='A list of the role names that the proxy user should '
                      'assume through trust for Swift object access.')
 ]
@@ -61,9 +59,9 @@ def create_proxy_user_for_job_execution(job_execution):
 
     '''
     username = 'job_{0}'.format(job_execution.id)
-    password = key_manager.store_secret(proxy_user_create(username))
-    current_user = k.auth()
-    proxy_user = k.auth_for_proxy(username, password)
+    password = proxy_user_create(username)
+    current_user = k.client()
+    proxy_user = k.client_for_proxy_user(username, password)
     trust_id = t.create_trust(trustor=current_user,
                               trustee=proxy_user,
                               role_names=CONF.proxy_user_role_names)
@@ -86,14 +84,13 @@ def delete_proxy_user_for_job_execution(job_execution):
     proxy_configs = job_execution.job_configs.get('proxy_configs')
     if proxy_configs is not None:
         proxy_username = proxy_configs.get('proxy_username')
+        proxy_password = proxy_configs.get('proxy_password')
         proxy_trust_id = proxy_configs.get('proxy_trust_id')
-        proxy_user = k.auth_for_proxy(proxy_username,
-                                      key_manager.get_secret(
-                                          proxy_configs.get('proxy_password')),
-                                      proxy_trust_id)
+        proxy_user = k.client_for_proxy_user(proxy_username,
+                                             proxy_password,
+                                             proxy_trust_id)
         t.delete_trust(proxy_user, proxy_trust_id)
         proxy_user_delete(proxy_username)
-        key_manager.delete_secret(proxy_configs.get('proxy_password'))
         update = job_execution.job_configs.to_dict()
         del update['proxy_configs']
         return update
@@ -109,9 +106,9 @@ def create_proxy_user_for_cluster(cluster):
     if cluster.cluster_configs.get('proxy_configs'):
         return cluster
     username = 'cluster_{0}'.format(cluster.id)
-    password = key_manager.store_secret(proxy_user_create(username))
-    current_user = k.auth()
-    proxy_user = k.auth_for_proxy(username, password)
+    password = proxy_user_create(username)
+    current_user = k.client()
+    proxy_user = k.client_for_proxy_user(username, password)
     trust_id = t.create_trust(trustor=current_user,
                               trustee=proxy_user,
                               role_names=CONF.proxy_user_role_names)
@@ -133,14 +130,13 @@ def delete_proxy_user_for_cluster(cluster):
     proxy_configs = cluster.cluster_configs.get('proxy_configs')
     if proxy_configs is not None:
         proxy_username = proxy_configs.get('proxy_username')
+        proxy_password = proxy_configs.get('proxy_password')
         proxy_trust_id = proxy_configs.get('proxy_trust_id')
-        proxy_user = k.auth_for_proxy(proxy_username,
-                                      key_manager.get_secret(
-                                          proxy_configs.get('proxy_password')),
-                                      proxy_trust_id)
+        proxy_user = k.client_for_proxy_user(proxy_username,
+                                             proxy_password,
+                                             proxy_trust_id)
         t.delete_trust(proxy_user, proxy_trust_id)
         proxy_user_delete(proxy_username)
-        key_manager.delete_secret(proxy_configs.get('proxy_password'))
         update = {'cluster_configs': cluster.cluster_configs.to_dict()}
         del update['cluster_configs']['proxy_configs']
         conductor.cluster_update(context.ctx(), cluster, update)
@@ -169,18 +165,16 @@ def domain_for_proxy():
 
     global PROXY_DOMAIN
     if not PROXY_DOMAIN:
-        domain_list = b.execute_with_retries(
-            admin.domains.list, name=CONF.proxy_user_domain_name)
+        domain_list = admin.domains.list(name=CONF.proxy_user_domain_name)
         if len(domain_list) == 0:
-            raise ex.NotFoundException(
-                value=CONF.proxy_user_domain_name,
-                message_template=_('Failed to find domain %s'))
+            raise ex.NotFoundException(value=CONF.proxy_user_domain_name,
+                                       message=_('Failed to find domain %s'))
         # the domain name should be globally unique in Keystone
         if len(domain_list) > 1:
-            raise ex.NotFoundException(
-                value=CONF.proxy_user_domain_name,
-                message_template=_('Unexpected results found when searching '
-                                   'for domain %s'))
+            raise ex.NotFoundException(value=CONF.proxy_user_domain_name,
+                                       message=_('Unexpected results found '
+                                                 'when searching for domain '
+                                                 '%s'))
         PROXY_DOMAIN = domain_list[0]
     return PROXY_DOMAIN
 
@@ -252,7 +246,7 @@ def proxy_domain_users_list():
     admin = k.client_for_admin()
     domain = domain_for_proxy()
     if domain:
-        return b.execute_with_retries(admin.users.list, domain=domain.id)
+        return admin.users.list(domain=domain.id)
     return []
 
 
@@ -267,9 +261,8 @@ def proxy_user_create(username):
     '''
     admin = k.client_for_admin()
     domain = domain_for_proxy()
-    password = uuidutils.generate_uuid()
-    b.execute_with_retries(
-        admin.users.create, name=username, password=password, domain=domain.id)
+    password = six.text_type(uuid.uuid4())
+    admin.users.create(name=username, password=password, domain=domain.id)
     LOG.debug('Created proxy user {username}'.format(username=username))
     return password
 
@@ -287,17 +280,14 @@ def proxy_user_delete(username=None, user_id=None):
     admin = k.client_for_admin()
     if not user_id:
         domain = domain_for_proxy()
-        user_list = b.execute_with_retries(
-            admin.users.list, domain=domain.id, name=username)
+        user_list = admin.users.list(domain=domain.id, name=username)
         if len(user_list) == 0:
-            raise ex.NotFoundException(
-                value=username,
-                message_template=_('Failed to find user %s'))
+            raise ex.NotFoundException(value=username,
+                                       message=_('Failed to find user %s'))
         if len(user_list) > 1:
-            raise ex.NotFoundException(
-                value=username,
-                message_template=_('Unexpected results found when searching '
-                                   'for user %s'))
+            raise ex.NotFoundException(value=username,
+                                       message=_('Unexpected results found '
+                                                 'when searching for user %s'))
         user_id = user_list[0].id
-    b.execute_with_retries(admin.users.delete, user_id)
+    admin.users.delete(user_id)
     LOG.debug('Deleted proxy user id {user_id}'.format(user_id=user_id))
