@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from oslo.serialization import jsonutils
+from oslo_serialization import jsonutils
 from sqlalchemy.ext import mutable
 from sqlalchemy import types as st
 
